=== modified file '.bzrignore'
--- .bzrignore	2012-09-23 20:28:39 +0000
+++ .bzrignore	2012-09-30 23:55:03 +0000
@@ -146,3 +146,4 @@
 util/.hg/
 util/.hgignore
 var
+man/*

=== modified file 'Makefile.am'
--- Makefile.am	2012-09-23 20:28:39 +0000
+++ Makefile.am	2012-09-30 23:55:03 +0000
@@ -45,6 +45,7 @@
 include tests/include.am
 include support/include.am
 include docs/include.am
+include man/include.am
 
 include m4/include.am
 

=== modified file 'bootstrap.sh'
--- bootstrap.sh	2012-09-30 03:02:24 +0000
+++ bootstrap.sh	2012-09-30 23:55:03 +0000
@@ -33,89 +33,121 @@
 
 die() { echo "$@"; exit 1; }
 
+command_exists () {
+  type "$1" &> /dev/null ;
+}
+
 run() {
+  echo $TESTS_ENVIRONMENT
   echo "\`$@' $ARGS"
   $@ $ARGS
 } 
 
-if [ -d .git ]
-then
-  AUTORECONF_FLAGS="--install --force --verbose -Wall -Werror"
-elif [ -d .bzr ]
-then
-  AUTORECONF_FLAGS="--install --force --verbose -Wall -Werror"
-elif [ -d .svn ]
-then
-  AUTORECONF_FLAGS="--install --force --verbose -Wall -Werror"
-elif [ -d .hg ]
-then
-  AUTORECONF_FLAGS="--install --force --verbose -Wall -Werror"
-else
-  AUTORECONF_FLAGS="--install --force --verbose -Wall"
-fi
-
-LIBTOOLIZE_FLAGS="--force --verbose"
-
-if [ $(uname) = "Darwin" ]
-then
-  LIBTOOLIZE=glibtoolize
-elif [ -z "$LIBTOOLIZE" ]
-then 
-  LIBTOOLIZE=libtoolize
-fi
-
-AUTORECONF=autoreconf
-
-# Set ENV DEBUG in order to enable debugging
-if [ -n "$DEBUG" ]
-then 
-  DEBUG="--enable-debug"
-fi
-
-# Set ENV ASSERT in order to enable assert
-if [ -n "$ASSERT" ]
-then 
-  ASSERT="--enable-assert"
-fi
-
-# Set ENV MAKE in order to override "make"
-if [ -z "$MAKE" ]
-then 
-  MAKE="make"
-fi
-
-# Set ENV MAKE_J in order to override "-j2"
-if [ -z "$MAKE_J" ]
-then
-  MAKE_J="-j2"
-fi
-
-# Set ENV PREFIX in order to set --prefix for ./configure
-if [ -n "$PREFIX" ]
-then 
-  PREFIX="--prefix=$PREFIX"
-fi
-
-if [ -f Makefile ]
-then
-  $MAKE $MAKE_J maintainer-clean
-fi
-
-run $LIBTOOLIZE $LIBTOOLIZE_FLAGS || die "Can't execute $LIBTOOLIZE"
-run $AUTORECONF $AUTORECONF_FLAGS || die "Can't execute $AUTORECONF"
-
-# If we are executing on OSX use CLANG, otherwise only use it if we find it in the ENV
-if [ $(uname) = "Darwin" ]
-then
-  CC=clang CXX=clang++ ./configure $DEBUG $ASSERT $PREFIX || die "configure failed to run"
-else
-  ./configure $DEBUG $ASSERT $PREFIX || die "configure failed to run"
-fi
-
-# Set ENV MAKE_TARGET in order to override default of "all"
-if [ -z "$MAKE_TARGET" ]
-then 
-  MAKE_TARGET="all"
-fi
-
-run $MAKE $MAKE_J $MAKE_TARGET || die "Can't execute make"
+bootstrap() {
+  if [ -d .git ]
+  then
+    AUTORECONF_FLAGS="--install --force --verbose -Wall -Werror"
+  elif [ -d .bzr ]
+  then
+    AUTORECONF_FLAGS="--install --force --verbose -Wall -Werror"
+  elif [ -d .svn ]
+  then
+    AUTORECONF_FLAGS="--install --force --verbose -Wall -Werror"
+  elif [ -d .hg ]
+  then
+    AUTORECONF_FLAGS="--install --force --verbose -Wall -Werror"
+  else
+    AUTORECONF_FLAGS="--install --force --verbose -Wall"
+  fi
+
+  LIBTOOLIZE_FLAGS="--force --verbose"
+
+  if [ $(uname) = "Darwin" ]
+  then
+    LIBTOOLIZE=glibtoolize
+  elif [ -z "$LIBTOOLIZE" ]
+  then 
+    LIBTOOLIZE=libtoolize
+  fi
+
+  AUTOMAKE=automake
+  AUTORECONF=autoreconf
+
+  AUTOMAKE_FLAGS=--add-missing
+
+
+  # Set ENV DEBUG in order to enable debugging
+  if [ -n "$DEBUG" ]
+  then 
+    DEBUG="--enable-debug"
+  fi
+
+  # Set ENV ASSERT in order to enable assert
+  if [ -n "$ASSERT" ]
+  then 
+    ASSERT="--enable-assert"
+  fi
+
+  # Set ENV VALGRIND in order to enable assert
+  if [ -n "$VALGRIND" ] && command_exists valgrind
+  then 
+    VALGRIND="valgrind --error-exitcode=1 --leak-check=yes --show-reachable=yes --track-fds=yes --malloc-fill=A5 --free-fill=DE"
+    TESTS_ENVIRONMENT="$VALGRIND"
+  fi
+
+  # Set ENV MAKE in order to override "make"
+  if [ -z "$MAKE" ]
+  then 
+    MAKE="make"
+  fi
+
+  # Set ENV MAKE_J in order to override "-j2"
+  if [ -z "$MAKE_J" ]
+  then
+    MAKE_J="-j2"
+  fi
+
+  # Set ENV PREFIX in order to set --prefix for ./configure
+  if [ -n "$PREFIX" ]
+  then 
+    PREFIX="--prefix=$PREFIX"
+  fi
+
+  if [ -f Makefile ]
+  then
+    $MAKE $MAKE_J maintainer-clean
+  fi
+
+  run $LIBTOOLIZE $LIBTOOLIZE_FLAGS || die "Can't execute $LIBTOOLIZE"
+  run $AUTOMAKE $AUTOMAKE_FLAGS || die "Can't execute $AUTORECONF"
+  run $AUTORECONF $AUTORECONF_FLAGS || die "Can't execute $AUTORECONF"
+
+  # If we are executing on OSX use CLANG, otherwise only use it if we find it in the ENV
+  if [ $(uname) = "Darwin" ]
+  then
+    CC=clang CXX=clang++ ./configure $DEBUG $ASSERT $PREFIX || die "configure failed to run"
+  else
+    ./configure $DEBUG $ASSERT $PREFIX || die "configure failed to run"
+  fi
+
+  if [[ -n "$TESTS_ENVIRONMENT" ]] && [[ -f libtool ]]
+  then
+    TESTS_ENVIRONMENT="./libtool --mode=execute $TESTS_ENVIRONMENT"
+    export TESTS_ENVIRONMENT
+  fi
+
+  if [ -f docs/conf.py ]
+  then 
+    run $MAKE $MAKE_J man || die "Can't execute make"
+  fi
+
+  # Set ENV MAKE_TARGET in order to override default of "all"
+  if [ -z "$MAKE_TARGET" ]
+  then 
+    MAKE_TARGET="all"
+  fi
+
+  run $MAKE $MAKE_J $MAKE_TARGET || die "Can't execute make"
+}
+
+bootstrap

=== modified file 'docs/include.am'
--- docs/include.am	2012-09-19 05:19:28 +0000
+++ docs/include.am	2012-09-30 23:55:03 +0000
@@ -16,170 +16,8 @@
 
 .PHONY: help clean html dirhtml singlehtml pickle json htmlhelp qthelp devhelp epub latex latexpdf text man changes linkcheck doctest
 
-man1_MANS+= \
-	    docs/man/gearadmin.1 \
-	    docs/man/gearman.1
-
-man8_MANS+= \
-	    docs/man/gearmand.8
-
-man3_MANS+= \
-	    docs/man/gearman_allocator_t.3 \
-	    docs/man/gearman_client_set_memory_allocators.3 \
-	    docs/man/gearman_worker_set_memory_allocators.3 \
-	    docs/man/gearman_actions_t.3 \
-	    docs/man/gearman_argument_make.3 \
-	    docs/man/gearman_argument_t.3 \
-	    docs/man/gearman_bugreport.3 \
-	    docs/man/gearman_client_add_options.3 \
-	    docs/man/gearman_client_add_server.3 \
-	    docs/man/gearman_client_add_servers.3 \
-	    docs/man/gearman_client_add_task.3 \
-	    docs/man/gearman_client_add_task_background.3 \
-	    docs/man/gearman_client_add_task_high.3 \
-	    docs/man/gearman_client_add_task_high_background.3 \
-	    docs/man/gearman_client_add_task_low.3 \
-	    docs/man/gearman_client_add_task_low_background.3 \
-	    docs/man/gearman_client_add_task_status.3 \
-	    docs/man/gearman_client_clear_fn.3 \
-	    docs/man/gearman_client_clone.3 \
-	    docs/man/gearman_client_context.3 \
-	    docs/man/gearman_client_create.3 \
-	    docs/man/gearman_client_do.3 \
-	    docs/man/gearman_client_do_background.3 \
-	    docs/man/gearman_client_do_high.3 \
-	    docs/man/gearman_client_do_high_background.3 \
-	    docs/man/gearman_client_do_job_handle.3 \
-	    docs/man/gearman_client_do_low.3 \
-	    docs/man/gearman_client_do_low_background.3 \
-	    docs/man/gearman_client_do_status.3 \
-	    docs/man/gearman_client_echo.3 \
-	    docs/man/gearman_client_errno.3 \
-	    docs/man/gearman_client_error.3 \
-	    docs/man/gearman_client_free.3 \
-	    docs/man/gearman_client_job_status.3 \
-	    docs/man/gearman_client_options.3 \
-	    docs/man/gearman_client_remove_options.3 \
-	    docs/man/gearman_client_remove_servers.3 \
-	    docs/man/gearman_client_run_tasks.3 \
-	    docs/man/gearman_client_set_complete_fn.3 \
-	    docs/man/gearman_client_set_context.3 \
-	    docs/man/gearman_client_set_created_fn.3 \
-	    docs/man/gearman_client_set_data_fn.3 \
-	    docs/man/gearman_client_set_exception_fn.3 \
-	    docs/man/gearman_client_set_fail_fn.3 \
-	    docs/man/gearman_client_set_log_fn.3 \
-	    docs/man/gearman_client_set_namespace.3 \
-	    docs/man/gearman_client_set_options.3 \
-	    docs/man/gearman_client_set_status_fn.3 \
-	    docs/man/gearman_client_set_task_context_free_fn.3 \
-	    docs/man/gearman_client_set_timeout.3 \
-	    docs/man/gearman_client_set_warning_fn.3 \
-	    docs/man/gearman_client_set_workload_fn.3 \
-	    docs/man/gearman_client_set_workload_free_fn.3 \
-	    docs/man/gearman_client_set_workload_malloc_fn.3 \
-	    docs/man/gearman_client_st.3 \
-	    docs/man/gearman_client_task_free_all.3 \
-	    docs/man/gearman_client_timeout.3 \
-	    docs/man/gearman_client_wait.3 \
-	    docs/man/gearman_continue.3 \
-	    docs/man/gearman_execute.3 \
-	    docs/man/gearman_failed.3 \
-	    docs/man/gearman_job_free.3 \
-	    docs/man/gearman_job_free_all.3 \
-	    docs/man/gearman_job_function_name.3 \
-	    docs/man/gearman_job_handle.3 \
-	    docs/man/gearman_job_handle_t.3 \
-	    docs/man/gearman_job_send_complete.3 \
-	    docs/man/gearman_job_send_data.3 \
-	    docs/man/gearman_job_send_exception.3 \
-	    docs/man/gearman_job_send_fail.3 \
-	    docs/man/gearman_job_send_status.3 \
-	    docs/man/gearman_job_send_warning.3 \
-	    docs/man/gearman_job_st.3 \
-	    docs/man/gearman_job_take_workload.3 \
-	    docs/man/gearman_job_unique.3 \
-	    docs/man/gearman_job_workload.3 \
-	    docs/man/gearman_job_workload_size.3 \
-	    docs/man/gearman_log_fn.3 \
-	    docs/man/gearman_parse_servers.3 \
-	    docs/man/gearman_result_boolean.3 \
-	    docs/man/gearman_result_integer.3 \
-	    docs/man/gearman_result_is_null.3 \
-	    docs/man/gearman_result_size.3 \
-	    docs/man/gearman_result_store_integer.3 \
-	    docs/man/gearman_result_store_string.3 \
-	    docs/man/gearman_result_store_value.3 \
-	    docs/man/gearman_result_string.3 \
-	    docs/man/gearman_return_t.3 \
-	    docs/man/gearman_strerror.3 \
-	    docs/man/gearman_string_t.3 \
-	    docs/man/gearman_success.3 \
-	    docs/man/gearman_task_context.3 \
-	    docs/man/gearman_task_data.3 \
-	    docs/man/gearman_task_data_size.3 \
-	    docs/man/gearman_task_denominator.3 \
-	    docs/man/gearman_task_error.3 \
-	    docs/man/gearman_task_free.3 \
-	    docs/man/gearman_task_function_name.3 \
-	    docs/man/gearman_task_give_workload.3 \
-	    docs/man/gearman_task_is_known.3 \
-	    docs/man/gearman_task_is_running.3 \
-	    docs/man/gearman_task_job_handle.3 \
-	    docs/man/gearman_task_numerator.3 \
-	    docs/man/gearman_task_recv_data.3 \
-	    docs/man/gearman_task_return.3 \
-	    docs/man/gearman_task_send_workload.3 \
-	    docs/man/gearman_task_set_context.3 \
-	    docs/man/gearman_task_st.3 \
-	    docs/man/gearman_task_take_data.3 \
-	    docs/man/gearman_task_unique.3 \
-	    docs/man/gearman_verbose_name.3 \
-	    docs/man/gearman_verbose_t.3 \
-	    docs/man/gearman_version.3 \
-	    docs/man/gearman_worker_add_function.3 \
-	    docs/man/gearman_worker_add_options.3 \
-	    docs/man/gearman_worker_add_server.3 \
-	    docs/man/gearman_worker_add_servers.3 \
-	    docs/man/gearman_worker_clone.3 \
-	    docs/man/gearman_worker_context.3 \
-	    docs/man/gearman_worker_create.3 \
-	    docs/man/gearman_worker_define_function.3 \
-	    docs/man/gearman_worker_echo.3 \
-	    docs/man/gearman_worker_errno.3 \
-	    docs/man/gearman_worker_error.3 \
-	    docs/man/gearman_worker_free.3 \
-	    docs/man/gearman_worker_function_exist.3 \
-	    docs/man/gearman_worker_grab_job.3 \
-	    docs/man/gearman_worker_options.3 \
-	    docs/man/gearman_worker_register.3 \
-	    docs/man/gearman_worker_remove_options.3 \
-	    docs/man/gearman_worker_remove_servers.3 \
-	    docs/man/gearman_worker_set_context.3 \
-	    docs/man/gearman_worker_set_log_fn.3 \
-	    docs/man/gearman_worker_set_namespace.3 \
-	    docs/man/gearman_worker_set_options.3 \
-	    docs/man/gearman_worker_set_timeout.3 \
-	    docs/man/gearman_worker_set_workload_free_fn.3 \
-	    docs/man/gearman_worker_set_workload_malloc_fn.3 \
-	    docs/man/gearman_worker_st.3 \
-	    docs/man/gearman_worker_timeout.3 \
-	    docs/man/gearman_worker_unregister.3 \
-	    docs/man/gearman_worker_unregister_all.3 \
-	    docs/man/gearman_worker_wait.3 \
-	    docs/man/gearman_worker_work.3 \
-	    docs/man/gearman_task_attr_init.3 \
-	    docs/man/gearman_task_attr_init_background.3 \
-	    docs/man/gearman_task_attr_init_epoch.3 \
-	    docs/man/gearman_task_attr_t.3 \
-	    docs/man/gearman_client_options_t.3 \
-	    docs/man/gearman_client_has_option.3 \
-	    docs/man/libgearman.3
-
 if HAVE_SPHINX
 
-docs: html man
-
 sphinx-help:
 	@echo "Please use \`make <target>' where <target> is one of"
 	@echo "  html       to make standalone HTML files"
@@ -274,10 +112,10 @@
 	@echo
 	@echo "Build finished. The text files are in $(SPHINX_BUILDDIR)/text."
 
-man: docs/conf.py
-	PYTHONPATH=${top_srcdir}/docs  $(SPHINXBUILD) -b man $(ALLSPHINXOPTS) $(SPHINX_BUILDDIR)/man
+man:
+	PYTHONPATH=${top_srcdir}/docs  $(SPHINXBUILD) -b man $(ALLSPHINXOPTS) ${top_srcdir}/man
 	@echo
-	@echo "Build finished. The manual pages are in $(SPHINX_BUILDDIR)/man."
+	@echo "Build finished. The manual pages are in ${top_srcdir}/man."
 
 changes: docs/conf.py
 	PYTHONPATH=${top_srcdir}/docs  $(SPHINXBUILD) -b changes $(ALLSPHINXOPTS) $(SPHINX_BUILDDIR)/changes
@@ -295,10 +133,6 @@
 	@echo "Testing of doctests in the sources finished, look at the " \
 	      "results in $(SPHINX_BUILDDIR)/doctest/output.txt."
 
-else
-
-docs:
-
 endif
 
 noinst_PROGRAMS+= \

=== removed directory 'docs/man'
=== removed file 'docs/man/gearadmin.1'
--- docs/man/gearadmin.1	2012-09-14 06:18:21 +0000
+++ docs/man/gearadmin.1	1970-01-01 00:00:00 +0000
@@ -1,102 +0,0 @@
-.TH "GEARADMIN" "1" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearadmin \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.sp
-Run Administrative commands against a server.
-.SH SYNOPSIS
-.INDENT 0.0
-.TP
-.B \-\-help
-Provice help about the program.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-\-create\-function
-Create a function from the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-h [ \-\-host ] arg (=localhost)i
-Connect to the host
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-p [ \-\-port ] arg (=4730)
-Port number or service to use for connection
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-\-drop\-function
-Drop a function from the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-\-server\-version
-Fetch the version number for the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-\-server\-verbose
-Fetch the verbose setting for the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-\-status
-Status for the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-\-workers
-Workers for the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-\-shutdown
-Shutdown server.
-.UNINDENT
-.SH DESCRIPTION
-.sp
-Command line tool for manipulating gearmand servers.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman.1'
--- docs/man/gearman.1	2012-09-14 06:18:21 +0000
+++ docs/man/gearman.1	1970-01-01 00:00:00 +0000
@@ -1,140 +0,0 @@
-.TH "GEARMAN" "1" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.sp
-Command line client for Gearmand
-.SH SYNOPSIS
-.sp
-\fBCommon options\fP
-.INDENT 0.0
-.TP
-.B \-f <function>
-Function name to use for jobs (can give many)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-h <host>
-Job server host
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-H
-Print this help menu
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-p <port>
-Gearman server port
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-t <timeout>
-Timeout in milliseconds
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-i <pidfile>
-Create a pidfile for the process
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-n
-In client mode run one job per line, in worker mode send data packet for each line
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-N
-Same as \-n, but strip off the newline
-.UNINDENT
-.sp
-\fBClient options\fP
-.INDENT 0.0
-.TP
-.B \-b
-Run jobs in the background
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-I
-Run jobs as high priority
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-L
-Run jobs as low priority
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-P
-Prefix all output lines with functions names
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-s
-Send job without reading from standard input
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-u <unique>
-Unique key to use for job
-.UNINDENT
-.sp
-\fIWorker options*\fP
-.INDENT 0.0
-.TP
-.B \-c <count>
-Number of jobs for worker to run before exiting
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-w
-Run in worker mode
-.UNINDENT
-.SH DESCRIPTION
-.sp
-With gearman you can run client and worker functions from the command line.
-.sp
-The environmental variable GEARMAN_SERVER can be used to specify multiple gearmand servers. Please see the c:func:\(aqgearman_client_add_servers\(aq for an explanation of the required syntax.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_actions_t.3'
--- docs/man/gearman_actions_t.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_actions_t.3	1970-01-01 00:00:00 +0000
@@ -1,161 +0,0 @@
-.TH "GEARMAN_ACTIONS_T" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_actions_t \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_actions_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_workload_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_created_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_data_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_warning_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_universal_status_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_exception_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_fail_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_complete_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_workload_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_created_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_created_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_data_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_data_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_warning_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_warning_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_status_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_universal_status_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_complete_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_complete_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_exception_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_exception_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_fail_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_fail_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_clear_fn(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_client_do_job_handle(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.sp
-Link to \-lgearman
-.SH DESCRIPTION
-.sp
-Callbacks for client execution task states.
-.sp
-\fI\%gearman_client_set_data_fn()\fP sets the callback function that will
-be called if server is to make a request to the client to provide more data.
-.sp
-\fI\%gearman_client_do_job_handle()\fP gest the job handle for the running task. This should be used between repeated
-\fBgearman_client_do()\fP (and related) calls to get information.
-.sp
-\fI\%gearman_client_clear_fn()\fP can be called to remove all existing
-\fI\%gearman_actions_t\fP that have been set.
-.sp
-\fI\%gearman_client_set_created_fn()\fP,
-\fI\%gearman_client_set_data_fn()\fP,
-\fI\%gearman_client_set_warning_fn()\fP,
-\fI\%gearman_client_set_status_fn()\fP,
-\fI\%gearman_client_set_complete_fn()\fP,
-\fI\%gearman_client_set_exception_fn()\fP, and
-\fI\%gearman_client_set_fail_fn()\fP, set callback functions for the
-different states of execution for a client request. Each request, ie
-a creation of \fBgearman_task_st\fP, keeps a copy of callbacks when it
-is created.
-.sp
-\fI\%gearman_client_set_exception_fn()\fP will only be called if exceptions are enabled on the server. You can do this by calling \fBgearman_client_set_server_option()\fP.
-.sp
-An example of this:
-.sp
-.nf
-.ft C
-const char *EXCEPTIONS="exceptions";
-gearman_client_set_server_option(client, EXCEPTIONS, strlen(EXCEPTIONS));
-.ft P
-.fi
-.SH RETURN VALUE
-.sp
-None
-.IP "See also"
-.RE
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error(3)\fP or \fIgearman_worker_error(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_allocator_t.3'
--- docs/man/gearman_allocator_t.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_allocator_t.3	1970-01-01 00:00:00 +0000
@@ -1,84 +0,0 @@
-.TH "GEARMAN_ALLOCATOR_T" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_allocator_t \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_allocator_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_malloc_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_realloc_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_calloc_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_set_memory_allocators(gearman_client_st\fI\ *\fP, \fI\%gearman_malloc_fn\fP\fI\ *malloc_fn\fP, \fI\%gearman_free_fn\fP\fI\ *free_fn\fP, \fI\%gearman_realloc_fn\fP\fI\ *realloc_fn\fP, \fI\%gearman_calloc_fn\fP\fI\ *calloc_fn\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_set_memory_allocators(gearman_worker_st\fI\ *\fP, \fI\%gearman_malloc_fn\fP\fI\ *malloc_fn\fP, \fI\%gearman_free_fn\fP\fI\ *free_fn\fP, \fI\%gearman_realloc_fn\fP\fI\ *realloc_fn\fP, \fI\%gearman_calloc_fn\fP\fI\ *calloc_fn\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Link to \-lgearman
-.SH DESCRIPTION
-.sp
-Install callbacks for custom allocation.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. You can use \fI\%gearman_client_set_memory_allocators()\fP and \fI\%gearman_worker_set_memory_allocators()\fP to set your own custom allocators.
-.SH RETURN VALUE
-.sp
-None
-.IP "See also"
-.RE
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_st(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_argument_make.3'
--- docs/man/gearman_argument_make.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_argument_make.3	1970-01-01 00:00:00 +0000
@@ -1,60 +0,0 @@
-.TH "GEARMAN_ARGUMENT_MAKE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_argument_make \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_argument_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_argument_t\fP gearman_argument_make(const char\fI\ *name\fP, const size_t\fI\ name_length\fP, const char\fI\ *value\fP, const size_t\fI\ value_size\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-The \fI\%gearman_argument_make()\fP function initializes \fI\%gearman_argument_t\fP.
-.sp
-\fI\%gearman_argument_t\fP is an abstraction used passing arguments too \fBgearman_execute()\fP. The arguments are not copied, so any object that is used to initialize \fI\%gearman_argument_t\fP must continue to exist throughout the lifetime/usage of the structure.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error()\fP or \fIgearman_worker_error()\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_argument_t.3'
--- docs/man/gearman_argument_t.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_argument_t.3	1970-01-01 00:00:00 +0000
@@ -1,60 +0,0 @@
-.TH "GEARMAN_ARGUMENT_T" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_argument_t \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_argument_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_argument_t\fP gearman_argument_make(const char\fI\ *name\fP, const size_t\fI\ name_length\fP, const char\fI\ *value\fP, const size_t\fI\ value_size\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-The \fI\%gearman_argument_make()\fP function initializes \fI\%gearman_argument_t\fP.
-.sp
-\fI\%gearman_argument_t\fP is an abstraction used passing arguments too \fBgearman_execute()\fP. The arguments are not copied, so any object that is used to initialize \fI\%gearman_argument_t\fP must continue to exist throughout the lifetime/usage of the structure.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error()\fP or \fIgearman_worker_error()\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_bugreport.3'
--- docs/man/gearman_bugreport.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_bugreport.3	1970-01-01 00:00:00 +0000
@@ -1,62 +0,0 @@
-.TH "GEARMAN_BUGREPORT" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_bugreport \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B const char *gearman_bugreport(void)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_bugreport()\fP returns the url to the bug tracking site for Gearmand
-.SH RETURN VALUE
-.sp
-URL
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.RE
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_add_options.3'
--- docs/man/gearman_client_add_options.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_add_options.3	1970-01-01 00:00:00 +0000
@@ -1,105 +0,0 @@
-.TH "GEARMAN_CLIENT_ADD_OPTIONS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_add_options \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_client_options_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_client_options_t\fP gearman_client_options(const gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_options(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_add_options(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_remove_options(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_client_has_option(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ option\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_options()\fP returns the \fI\%gearman_client_options_t\fP for \fBgearman_client_st\fP. You enable options via \fI\%gearman_client_add_options()\fP and disable options via \fI\%gearman_client_remove_options()\fP.
-.sp
-\fI\%gearman_client_set_options()\fP has been DEPRECATED.
-.sp
-The currently supported options are:
-.INDENT 0.0
-.TP
-.B GEARMAN_CLIENT_NON_BLOCKING
-.UNINDENT
-.sp
-Run the cient in a non\-blocking mode.
-.INDENT 0.0
-.TP
-.B GEARMAN_CLIENT_FREE_TASKS
-.UNINDENT
-.sp
-Automatically free task objects once they are complete.
-.INDENT 0.0
-.TP
-.B GEARMAN_CLIENT_UNBUFFERED_RESULT
-.UNINDENT
-.sp
-Allow the client to read data in chunks rather than have the library buffer
-the entire data result and pass that back.
-.SH RETURN VALUE
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_add_server.3'
--- docs/man/gearman_client_add_server.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_add_server.3	1970-01-01 00:00:00 +0000
@@ -1,78 +0,0 @@
-.TH "GEARMAN_CLIENT_ADD_SERVER" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_add_server \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_add_server(gearman_client_st\fI\ *client\fP, const char\fI\ *host\fP, in_port_t\fI\ port\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_add_servers(gearman_client_st\fI\ *client\fP, const char\fI\ *servers\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_remove_servers(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_add_server()\fP will add an additional \fBgearmand\fP server to the list of servers that the client will take work from.
-.sp
-\fI\%gearman_client_remove_servers()\fP will remove all servers from the \fBgearman_client_st\fP.
-.sp
-\fI\%gearman_client_add_servers()\fP takes a list of \fBgearmand\fP servers that will be parsed to provide servers for the client. The format for this is SERVER[:PORT][,SERVER[:PORT]]...
-.INDENT 0.0
-.TP
-.B Examples of this are::
-10.0.0.1,10.0.0.2,10.0.0.3
-localhost234,jobserver2.domain.com:7003,10.0.0.3
-.UNINDENT
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_add_server()\fP and \fI\%gearman_client_remove_servers()\fP return \fBgearman_return_t\fP.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.RE
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_st\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_add_servers.3'
--- docs/man/gearman_client_add_servers.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_add_servers.3	1970-01-01 00:00:00 +0000
@@ -1,78 +0,0 @@
-.TH "GEARMAN_CLIENT_ADD_SERVERS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_add_servers \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_add_server(gearman_client_st\fI\ *client\fP, const char\fI\ *host\fP, in_port_t\fI\ port\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_add_servers(gearman_client_st\fI\ *client\fP, const char\fI\ *servers\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_remove_servers(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_add_server()\fP will add an additional \fBgearmand\fP server to the list of servers that the client will take work from.
-.sp
-\fI\%gearman_client_remove_servers()\fP will remove all servers from the \fBgearman_client_st\fP.
-.sp
-\fI\%gearman_client_add_servers()\fP takes a list of \fBgearmand\fP servers that will be parsed to provide servers for the client. The format for this is SERVER[:PORT][,SERVER[:PORT]]...
-.INDENT 0.0
-.TP
-.B Examples of this are::
-10.0.0.1,10.0.0.2,10.0.0.3
-localhost234,jobserver2.domain.com:7003,10.0.0.3
-.UNINDENT
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_add_server()\fP and \fI\%gearman_client_remove_servers()\fP return \fBgearman_return_t\fP.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.RE
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_st\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_add_task.3'
--- docs/man/gearman_client_add_task.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_add_task.3	1970-01-01 00:00:00 +0000
@@ -1,74 +0,0 @@
-.TH "GEARMAN_CLIENT_ADD_TASK" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_add_task \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_client_add_task(gearman_client_st\fI\ *client\fP, gearman_task_st\fI\ *task\fP, void\fI\ *context\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_client_add_task_high(gearman_client_st\fI\ *client\fP, gearman_task_st\fI\ *task\fP, void\fI\ *context\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_client_add_task_low(gearman_client_st\fI\ *client\fP, gearman_task_st\fI\ *task\fP, void\fI\ *context\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_add_task()\fP creates a task and adds it to the given \fBgearman_client_st\fP. Execution of the task does now begin until \fBgearman_client_run_tasks()\fP is called.
-.sp
-If the unique value is not set, then a unique will be assigned.
-.sp
-\fI\%gearman_client_add_task_high()\fP and \fI\%gearman_client_add_task_low()\fP are identical to \fBgearman_client_do()\fP, only they set the priority to either high or low.
-.SH RETURN VALUE
-.sp
-The \fBgearman_task_st\fP is created and a pointer to it is returned. On error NULL is returned and ret_ptr is set with a \fBgearman_return_t\fP.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_add_task_background.3'
--- docs/man/gearman_client_add_task_background.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_add_task_background.3	1970-01-01 00:00:00 +0000
@@ -1,81 +0,0 @@
-.TH "GEARMAN_CLIENT_ADD_TASK_BACKGROUND" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_add_task_background \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_client_add_task_background(gearman_client_st\fI\ *client\fP, gearman_task_st\fI\ *task\fP, void\fI\ *context\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_client_add_task_high_background(gearman_client_st\fI\ *client\fP, gearman_task_st\fI\ *task\fP, void\fI\ *context\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_client_add_task_low_background(gearman_client_st\fI\ *client\fP, gearman_task_st\fI\ *task\fP, void\fI\ *context\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_add_task_background()\fP creates a background task and adds it ito the given \fBgearman_client_st\fP. Execution of the task does now begin until \fBgearman_client_run_tasks()\fP is called.
-.sp
-If the unique value is not set, then a unique will be assigned.
-.sp
-\fI\%gearman_client_add_task_high_background()\fP and \fI\%gearman_client_add_task_low_background()\fP are
-identical to \fBgearman_client_do()\fP, only they set the priority to
-either high or low.
-.IP Warning
-You may wish to avoid using \fI\%gearman_client_add_task_background()\fP with a stack based allocated
-\fBgearman_task_st\fP. The most common issues related to ABI safety involve stack allocated structures. If you use a stack based
-\fBgearman_task_st\fP you must free it with \fBgearman_task_free()\fP.
-.RE
-.SH RETURN VALUE
-.sp
-The \fBgearman_task_st\fP is created and a pointer to it is returned. On error NULL is returned and ret_ptr is set with a \fBgearman_return_t\fP.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.RE
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_task_st\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_add_task_high.3'
--- docs/man/gearman_client_add_task_high.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_add_task_high.3	1970-01-01 00:00:00 +0000
@@ -1,74 +0,0 @@
-.TH "GEARMAN_CLIENT_ADD_TASK_HIGH" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_add_task_high \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_client_add_task(gearman_client_st\fI\ *client\fP, gearman_task_st\fI\ *task\fP, void\fI\ *context\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_client_add_task_high(gearman_client_st\fI\ *client\fP, gearman_task_st\fI\ *task\fP, void\fI\ *context\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_client_add_task_low(gearman_client_st\fI\ *client\fP, gearman_task_st\fI\ *task\fP, void\fI\ *context\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_add_task()\fP creates a task and adds it to the given \fBgearman_client_st\fP. Execution of the task does now begin until \fBgearman_client_run_tasks()\fP is called.
-.sp
-If the unique value is not set, then a unique will be assigned.
-.sp
-\fI\%gearman_client_add_task_high()\fP and \fI\%gearman_client_add_task_low()\fP are identical to \fBgearman_client_do()\fP, only they set the priority to either high or low.
-.SH RETURN VALUE
-.sp
-The \fBgearman_task_st\fP is created and a pointer to it is returned. On error NULL is returned and ret_ptr is set with a \fBgearman_return_t\fP.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_add_task_high_background.3'
--- docs/man/gearman_client_add_task_high_background.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_add_task_high_background.3	1970-01-01 00:00:00 +0000
@@ -1,81 +0,0 @@
-.TH "GEARMAN_CLIENT_ADD_TASK_HIGH_BACKGROUND" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_add_task_high_background \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_client_add_task_background(gearman_client_st\fI\ *client\fP, gearman_task_st\fI\ *task\fP, void\fI\ *context\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_client_add_task_high_background(gearman_client_st\fI\ *client\fP, gearman_task_st\fI\ *task\fP, void\fI\ *context\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_client_add_task_low_background(gearman_client_st\fI\ *client\fP, gearman_task_st\fI\ *task\fP, void\fI\ *context\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_add_task_background()\fP creates a background task and adds it ito the given \fBgearman_client_st\fP. Execution of the task does now begin until \fBgearman_client_run_tasks()\fP is called.
-.sp
-If the unique value is not set, then a unique will be assigned.
-.sp
-\fI\%gearman_client_add_task_high_background()\fP and \fI\%gearman_client_add_task_low_background()\fP are
-identical to \fBgearman_client_do()\fP, only they set the priority to
-either high or low.
-.IP Warning
-You may wish to avoid using \fI\%gearman_client_add_task_background()\fP with a stack based allocated
-\fBgearman_task_st\fP. The most common issues related to ABI safety involve stack allocated structures. If you use a stack based
-\fBgearman_task_st\fP you must free it with \fBgearman_task_free()\fP.
-.RE
-.SH RETURN VALUE
-.sp
-The \fBgearman_task_st\fP is created and a pointer to it is returned. On error NULL is returned and ret_ptr is set with a \fBgearman_return_t\fP.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.RE
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_task_st\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_add_task_low.3'
--- docs/man/gearman_client_add_task_low.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_add_task_low.3	1970-01-01 00:00:00 +0000
@@ -1,74 +0,0 @@
-.TH "GEARMAN_CLIENT_ADD_TASK_LOW" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_add_task_low \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_client_add_task(gearman_client_st\fI\ *client\fP, gearman_task_st\fI\ *task\fP, void\fI\ *context\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_client_add_task_high(gearman_client_st\fI\ *client\fP, gearman_task_st\fI\ *task\fP, void\fI\ *context\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_client_add_task_low(gearman_client_st\fI\ *client\fP, gearman_task_st\fI\ *task\fP, void\fI\ *context\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_add_task()\fP creates a task and adds it to the given \fBgearman_client_st\fP. Execution of the task does now begin until \fBgearman_client_run_tasks()\fP is called.
-.sp
-If the unique value is not set, then a unique will be assigned.
-.sp
-\fI\%gearman_client_add_task_high()\fP and \fI\%gearman_client_add_task_low()\fP are identical to \fBgearman_client_do()\fP, only they set the priority to either high or low.
-.SH RETURN VALUE
-.sp
-The \fBgearman_task_st\fP is created and a pointer to it is returned. On error NULL is returned and ret_ptr is set with a \fBgearman_return_t\fP.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_add_task_low_background.3'
--- docs/man/gearman_client_add_task_low_background.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_add_task_low_background.3	1970-01-01 00:00:00 +0000
@@ -1,81 +0,0 @@
-.TH "GEARMAN_CLIENT_ADD_TASK_LOW_BACKGROUND" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_add_task_low_background \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_client_add_task_background(gearman_client_st\fI\ *client\fP, gearman_task_st\fI\ *task\fP, void\fI\ *context\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_client_add_task_high_background(gearman_client_st\fI\ *client\fP, gearman_task_st\fI\ *task\fP, void\fI\ *context\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_client_add_task_low_background(gearman_client_st\fI\ *client\fP, gearman_task_st\fI\ *task\fP, void\fI\ *context\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_add_task_background()\fP creates a background task and adds it ito the given \fBgearman_client_st\fP. Execution of the task does now begin until \fBgearman_client_run_tasks()\fP is called.
-.sp
-If the unique value is not set, then a unique will be assigned.
-.sp
-\fI\%gearman_client_add_task_high_background()\fP and \fI\%gearman_client_add_task_low_background()\fP are
-identical to \fBgearman_client_do()\fP, only they set the priority to
-either high or low.
-.IP Warning
-You may wish to avoid using \fI\%gearman_client_add_task_background()\fP with a stack based allocated
-\fBgearman_task_st\fP. The most common issues related to ABI safety involve stack allocated structures. If you use a stack based
-\fBgearman_task_st\fP you must free it with \fBgearman_task_free()\fP.
-.RE
-.SH RETURN VALUE
-.sp
-The \fBgearman_task_st\fP is created and a pointer to it is returned. On error NULL is returned and ret_ptr is set with a \fBgearman_return_t\fP.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.RE
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_task_st\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_add_task_status.3'
--- docs/man/gearman_client_add_task_status.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_add_task_status.3	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-.TH "GEARMAN_CLIENT_ADD_TASK_STATUS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_add_task_status \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_client_add_task_status(gearman_client_st\fI\ *client\fP, gearman_task_st\fI\ *task\fP, void\fI\ *context\fP, const char\fI\ *job_handle\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_add_task_status()\fP creates a \fBgearman_task_st\fP that can be used to monitor a previously created task.
-.IP Warning
-You may wish to avoid using \fBgearman_client_add_task()\fP with a
-stack based allocated \fBgearman_task_st\fP. The most common issues related to ABI safety involve
-stack allocated structures. If you use a stack based \fBgearman_task_st\fP you must free it with \fBgearman_task_free()\fP.
-.RE
-.SH RETURN VALUE
-.sp
-The \fBgearman_task_st\fP is created and a pointer to it is returned. On error NULL is returned and ret_ptr is set with a \fBgearman_return_t\fP.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_task_st(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_clear_fn.3'
--- docs/man/gearman_client_clear_fn.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_clear_fn.3	1970-01-01 00:00:00 +0000
@@ -1,161 +0,0 @@
-.TH "GEARMAN_CLIENT_CLEAR_FN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_clear_fn \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_actions_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_workload_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_created_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_data_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_warning_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_universal_status_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_exception_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_fail_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_complete_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_workload_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_created_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_created_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_data_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_data_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_warning_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_warning_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_status_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_universal_status_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_complete_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_complete_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_exception_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_exception_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_fail_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_fail_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_clear_fn(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_client_do_job_handle(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.sp
-Link to \-lgearman
-.SH DESCRIPTION
-.sp
-Callbacks for client execution task states.
-.sp
-\fI\%gearman_client_set_data_fn()\fP sets the callback function that will
-be called if server is to make a request to the client to provide more data.
-.sp
-\fI\%gearman_client_do_job_handle()\fP gest the job handle for the running task. This should be used between repeated
-\fBgearman_client_do()\fP (and related) calls to get information.
-.sp
-\fI\%gearman_client_clear_fn()\fP can be called to remove all existing
-\fI\%gearman_actions_t\fP that have been set.
-.sp
-\fI\%gearman_client_set_created_fn()\fP,
-\fI\%gearman_client_set_data_fn()\fP,
-\fI\%gearman_client_set_warning_fn()\fP,
-\fI\%gearman_client_set_status_fn()\fP,
-\fI\%gearman_client_set_complete_fn()\fP,
-\fI\%gearman_client_set_exception_fn()\fP, and
-\fI\%gearman_client_set_fail_fn()\fP, set callback functions for the
-different states of execution for a client request. Each request, ie
-a creation of \fBgearman_task_st\fP, keeps a copy of callbacks when it
-is created.
-.sp
-\fI\%gearman_client_set_exception_fn()\fP will only be called if exceptions are enabled on the server. You can do this by calling \fBgearman_client_set_server_option()\fP.
-.sp
-An example of this:
-.sp
-.nf
-.ft C
-const char *EXCEPTIONS="exceptions";
-gearman_client_set_server_option(client, EXCEPTIONS, strlen(EXCEPTIONS));
-.ft P
-.fi
-.SH RETURN VALUE
-.sp
-None
-.IP "See also"
-.RE
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error(3)\fP or \fIgearman_worker_error(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_clone.3'
--- docs/man/gearman_client_clone.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_clone.3	1970-01-01 00:00:00 +0000
@@ -1,93 +0,0 @@
-.TH "GEARMAN_CLIENT_CLONE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_clone \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_client_st *gearman_client_create(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_client_st *gearman_client_clone(gearman_client_st\fI\ *client\fP, const gearman_client_st\fI\ *from\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_free(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_create()\fP is used to create a c:type:\fIgearman_client_st\fP  structure that will then
-be used by other libgearman client functions to communicate with the server. You
-should either pass a statically declared \fBgearman_client_st\fP  to \fI\%gearman_client_create()\fP or
-a NULL. If a NULL passed in then a structure is allocated for you.
-.sp
-\fI\%gearman_client_clone()\fP is similar to \fI\%gearman_client_create()\fP but it copies the
-defaults and list of servers from the source \fBgearman_client_st\fP . If you pass a null as
-the argument for the source to clone, it is the same as a call to gearman_client_create.
-If the destination argument is NULL a \fBgearman_client_st\fP  will be allocated for you.
-.sp
-To clean up memory associated with a \fBgearman_client_st\fP  structure you should pass
-it to gearman_client_free when you are finished using it. \fI\%gearman_client_free()\fP is
-the only way to make sure all memory is deallocated when you finish using
-the structure.
-.IP Warning
-You may wish to avoid using \fI\%gearman_client_create()\fP or \fI\%gearman_client_clone()\fP with a
-stack based allocation, ie the first parameter. The most common issues related to ABI safety involve
-stack allocated structures.
-.RE
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_create\fP returns a pointer to the gearman_client_st
-that was created (or initialized). On an allocation failure, it returns
-NULL.
-.sp
-\fI\%gearman_client_clone\fP returns a pointer to the gearman_client_st that was created
-(or initialized). On an allocation failure, it returns NULL.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_strerror(3)\fP \fIgearman_client_st(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_context.3'
--- docs/man/gearman_client_context.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_context.3	1970-01-01 00:00:00 +0000
@@ -1,115 +0,0 @@
-.TH "GEARMAN_CLIENT_CONTEXT" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_context \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_client_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_client_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_client_context(const \fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_context(\fI\%gearman_client_st\fP\fI\ *client\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_malloc_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_task_free_all(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_task_context_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, \fI\%gearman_task_context_free_fn\fP\fI\ *function\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_st\fP is used for \fIclient\fP communication with the server.
-.sp
-\fI\%gearman_client_context()\fP and \fI\%gearman_client_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_client_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_client_timeout()\fP and \fI\%gearman_client_set_timeout()\fP get and set the current timeout value, in milliseconds, for the client.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_client_set_workload_malloc_fn()\fP and \fI\%gearman_client_set_workload_free_fn()\fP can be used to replace these with custom functions. (These have been deprecated, please see \fBgearman_allocator_t\fP for the updated interface.
-.sp
-\fI\%gearman_client_task_free_all()\fP is used to free all current \fBgearman_task_st\fP that have been created with the \fI\%gearman_client_st\fP.
-.IP Warning
-By calling \fI\%gearman_client_task_free_all()\fP you can end up with a SEGFAULT if you try to use any \fBgearman_task_st\fP that you have kept pointers too.
-.RE
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_timeout()\fP returns an integer representing the amount of time in milliseconds. A value of \-1 means an infinite timeout value. See \fIpoll(3)\fP for more details.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_create(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_create.3'
--- docs/man/gearman_client_create.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_create.3	1970-01-01 00:00:00 +0000
@@ -1,93 +0,0 @@
-.TH "GEARMAN_CLIENT_CREATE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_create \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_client_st *gearman_client_create(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_client_st *gearman_client_clone(gearman_client_st\fI\ *client\fP, const gearman_client_st\fI\ *from\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_free(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_create()\fP is used to create a c:type:\fIgearman_client_st\fP  structure that will then
-be used by other libgearman client functions to communicate with the server. You
-should either pass a statically declared \fBgearman_client_st\fP  to \fI\%gearman_client_create()\fP or
-a NULL. If a NULL passed in then a structure is allocated for you.
-.sp
-\fI\%gearman_client_clone()\fP is similar to \fI\%gearman_client_create()\fP but it copies the
-defaults and list of servers from the source \fBgearman_client_st\fP . If you pass a null as
-the argument for the source to clone, it is the same as a call to gearman_client_create.
-If the destination argument is NULL a \fBgearman_client_st\fP  will be allocated for you.
-.sp
-To clean up memory associated with a \fBgearman_client_st\fP  structure you should pass
-it to gearman_client_free when you are finished using it. \fI\%gearman_client_free()\fP is
-the only way to make sure all memory is deallocated when you finish using
-the structure.
-.IP Warning
-You may wish to avoid using \fI\%gearman_client_create()\fP or \fI\%gearman_client_clone()\fP with a
-stack based allocation, ie the first parameter. The most common issues related to ABI safety involve
-stack allocated structures.
-.RE
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_create\fP returns a pointer to the gearman_client_st
-that was created (or initialized). On an allocation failure, it returns
-NULL.
-.sp
-\fI\%gearman_client_clone\fP returns a pointer to the gearman_client_st that was created
-(or initialized). On an allocation failure, it returns NULL.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_strerror(3)\fP \fIgearman_client_st(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_do.3'
--- docs/man/gearman_client_do.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_do.3	1970-01-01 00:00:00 +0000
@@ -1,124 +0,0 @@
-.TH "GEARMAN_CLIENT_DO" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_do \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B void *gearman_client_do(gearman_client_st\fI\ *client\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, size_t\fI\ *result_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.sp
-Changed in version 0.21: \fBGEARMAN_PAUSE\fP will no longer be returned. A do operation will now run till completion or error.
-.INDENT 0.0
-.TP
-.B void *gearman_client_do_high(gearman_client_st\fI\ *client\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, size_t\fI\ *result_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_client_do_low(gearman_client_st\fI\ *client\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, size_t\fI\ *result_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_do()\fP executes a single request to the gearmand
-server and waits for a reply.
-.sp
-\fI\%gearman_client_do_high()\fP and \fI\%gearman_client_do_low()\fP are
-identical to \fI\%gearman_client_do()\fP, only they set the priority to
-either high or low.
-.sp
-All of the functions will block until either a response or an error is
-returned.
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_do()\fP returns a pointer to a value that the caller must release. If ret_ptr is provided any errors that have occurred will be stored in it. Since a NULL/zero value is a valid value, you will always need to check ret_ptr if you are concerned with errors.
-.SH EXAMPLE
-.sp
-.nf
-.ft C
-/*
-# Gearman server and library
-# Copyright (C) 2012 Data Differential, http://datadifferential.com/
-# All rights reserved.
-#
-# Use and distribution licensed under the BSD license.  See
-# the COPYING file in this directory for full text.
-*/
-
-#include <string.h>
-#include <stdlib.h>
-#include <libgearman/gearman.h>
-
-int main(void)
-{
-  gearman_client_st *client= gearman_client_create(NULL);
-
-  gearman_return_t ret= gearman_client_add_server(client, "localhost", 0);
-  if (gearman_failed(ret))
-  {
-    return EXIT_FAILURE;
-  }
-
-  size_t result_size;
-  gearman_return_t rc;
-  void *value= gearman_client_do(client, "reverse_function", "unique_value", 
-                                 "my string to reverse", strlen("my string to reverse"), 
-                                 &result_size, &rc);
-
-  if (gearman_success(rc))
-  {
-    // Make use of value
-  }
-  free(value);
-
-  gearman_client_free(client);
-
-  return 0;
-}
-
-.ft P
-.fi
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_strerror(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_do_background.3'
--- docs/man/gearman_client_do_background.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_do_background.3	1970-01-01 00:00:00 +0000
@@ -1,130 +0,0 @@
-.TH "GEARMAN_CLIENT_DO_BACKGROUND" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_do_background \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_priority_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_do_background(gearman_client_st\fI\ *client\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, char\fI\ *job_handle\fP)
-.UNINDENT
-.sp
-Changed in version 0.21: \fBGEARMAN_PAUSE\fP will no longer be returned. A do operation will now run until it has been submitted.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_do_high_background(gearman_client_st\fI\ *client\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_job_handle_t\fI\ job_handle\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_do_low_background(gearman_client_st\fI\ *client\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_job_handle_t\fI\ job_handle\fP)
-.UNINDENT
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_do_background()\fP executes a single request to the
-gearmand server and returns the status via \fBgearman_return_t\fP.
-.sp
-\fBgearman_client_add_task_high_background()\fP and \fBgearman_client_add_task_low_background()\fP are identical to
-\fI\%gearman_client_do_background()\fP, only they set the \fI\%gearman_priority_t\fP to either high or low.
-.sp
-If job_handle is not NULL, it will be populated with the name of the job_handle
-for the task created. The job handle needs to be the size of
-\fBGEARMAN_JOB_HANDLE_SIZE\fP. Please see \fBgearman_job_handle_t\fP for more information.
-.SH RETURN VALUE
-.sp
-\fBgearman_return_t\fP
-.SH EXAMPLE
-.sp
-.nf
-.ft C
-/*
-# Gearman server and library
-# Copyright (C) 2012 Data Differential, http://datadifferential.com/
-# All rights reserved.
-#
-# Use and distribution licensed under the BSD license.  See
-# the COPYING file in this directory for full text.
-*/
-
-#include <string.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <libgearman\-1.0/gearman.h>
-
-int main(void)
-{
-  gearman_client_st *client= gearman_client_create(NULL);
-
-  gearman_return_t ret= gearman_client_add_server(client, "localhost", 0);
-  if (gearman_failed(ret))
-  {
-    return EXIT_FAILURE;
-  }
-
-  gearman_job_handle_t job_handle;
-  gearman_return_t rc= gearman_client_do_background(client,
-                                                    "reverse_function",
-                                                    "unique_value",
-                                                    "my string to reverse", strlen("my string to reverse"),
-                                                    job_handle);
-
-  if (gearman_success(rc))
-  {
-    // Make use of value
-    printf("%s\en", job_handle);
-  }
-
-  gearman_client_free(client);
-
-  return 0;
-}
-
-.ft P
-.fi
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_strerror(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_do_high.3'
--- docs/man/gearman_client_do_high.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_do_high.3	1970-01-01 00:00:00 +0000
@@ -1,124 +0,0 @@
-.TH "GEARMAN_CLIENT_DO_HIGH" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_do_high \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B void *gearman_client_do(gearman_client_st\fI\ *client\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, size_t\fI\ *result_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.sp
-Changed in version 0.21: \fBGEARMAN_PAUSE\fP will no longer be returned. A do operation will now run till completion or error.
-.INDENT 0.0
-.TP
-.B void *gearman_client_do_high(gearman_client_st\fI\ *client\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, size_t\fI\ *result_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_client_do_low(gearman_client_st\fI\ *client\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, size_t\fI\ *result_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_do()\fP executes a single request to the gearmand
-server and waits for a reply.
-.sp
-\fI\%gearman_client_do_high()\fP and \fI\%gearman_client_do_low()\fP are
-identical to \fI\%gearman_client_do()\fP, only they set the priority to
-either high or low.
-.sp
-All of the functions will block until either a response or an error is
-returned.
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_do()\fP returns a pointer to a value that the caller must release. If ret_ptr is provided any errors that have occurred will be stored in it. Since a NULL/zero value is a valid value, you will always need to check ret_ptr if you are concerned with errors.
-.SH EXAMPLE
-.sp
-.nf
-.ft C
-/*
-# Gearman server and library
-# Copyright (C) 2012 Data Differential, http://datadifferential.com/
-# All rights reserved.
-#
-# Use and distribution licensed under the BSD license.  See
-# the COPYING file in this directory for full text.
-*/
-
-#include <string.h>
-#include <stdlib.h>
-#include <libgearman/gearman.h>
-
-int main(void)
-{
-  gearman_client_st *client= gearman_client_create(NULL);
-
-  gearman_return_t ret= gearman_client_add_server(client, "localhost", 0);
-  if (gearman_failed(ret))
-  {
-    return EXIT_FAILURE;
-  }
-
-  size_t result_size;
-  gearman_return_t rc;
-  void *value= gearman_client_do(client, "reverse_function", "unique_value", 
-                                 "my string to reverse", strlen("my string to reverse"), 
-                                 &result_size, &rc);
-
-  if (gearman_success(rc))
-  {
-    // Make use of value
-  }
-  free(value);
-
-  gearman_client_free(client);
-
-  return 0;
-}
-
-.ft P
-.fi
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_strerror(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_do_high_background.3'
--- docs/man/gearman_client_do_high_background.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_do_high_background.3	1970-01-01 00:00:00 +0000
@@ -1,130 +0,0 @@
-.TH "GEARMAN_CLIENT_DO_HIGH_BACKGROUND" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_do_high_background \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_priority_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_do_background(gearman_client_st\fI\ *client\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, char\fI\ *job_handle\fP)
-.UNINDENT
-.sp
-Changed in version 0.21: \fBGEARMAN_PAUSE\fP will no longer be returned. A do operation will now run until it has been submitted.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_do_high_background(gearman_client_st\fI\ *client\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_job_handle_t\fI\ job_handle\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_do_low_background(gearman_client_st\fI\ *client\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_job_handle_t\fI\ job_handle\fP)
-.UNINDENT
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_do_background()\fP executes a single request to the
-gearmand server and returns the status via \fBgearman_return_t\fP.
-.sp
-\fBgearman_client_add_task_high_background()\fP and \fBgearman_client_add_task_low_background()\fP are identical to
-\fI\%gearman_client_do_background()\fP, only they set the \fI\%gearman_priority_t\fP to either high or low.
-.sp
-If job_handle is not NULL, it will be populated with the name of the job_handle
-for the task created. The job handle needs to be the size of
-\fBGEARMAN_JOB_HANDLE_SIZE\fP. Please see \fBgearman_job_handle_t\fP for more information.
-.SH RETURN VALUE
-.sp
-\fBgearman_return_t\fP
-.SH EXAMPLE
-.sp
-.nf
-.ft C
-/*
-# Gearman server and library
-# Copyright (C) 2012 Data Differential, http://datadifferential.com/
-# All rights reserved.
-#
-# Use and distribution licensed under the BSD license.  See
-# the COPYING file in this directory for full text.
-*/
-
-#include <string.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <libgearman\-1.0/gearman.h>
-
-int main(void)
-{
-  gearman_client_st *client= gearman_client_create(NULL);
-
-  gearman_return_t ret= gearman_client_add_server(client, "localhost", 0);
-  if (gearman_failed(ret))
-  {
-    return EXIT_FAILURE;
-  }
-
-  gearman_job_handle_t job_handle;
-  gearman_return_t rc= gearman_client_do_background(client,
-                                                    "reverse_function",
-                                                    "unique_value",
-                                                    "my string to reverse", strlen("my string to reverse"),
-                                                    job_handle);
-
-  if (gearman_success(rc))
-  {
-    // Make use of value
-    printf("%s\en", job_handle);
-  }
-
-  gearman_client_free(client);
-
-  return 0;
-}
-
-.ft P
-.fi
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_strerror(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_do_job_handle.3'
--- docs/man/gearman_client_do_job_handle.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_do_job_handle.3	1970-01-01 00:00:00 +0000
@@ -1,115 +0,0 @@
-.TH "GEARMAN_CLIENT_DO_JOB_HANDLE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_do_job_handle \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_client_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_client_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_client_context(const \fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_context(\fI\%gearman_client_st\fP\fI\ *client\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_malloc_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_task_free_all(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_task_context_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, \fI\%gearman_task_context_free_fn\fP\fI\ *function\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_st\fP is used for \fIclient\fP communication with the server.
-.sp
-\fI\%gearman_client_context()\fP and \fI\%gearman_client_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_client_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_client_timeout()\fP and \fI\%gearman_client_set_timeout()\fP get and set the current timeout value, in milliseconds, for the client.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_client_set_workload_malloc_fn()\fP and \fI\%gearman_client_set_workload_free_fn()\fP can be used to replace these with custom functions. (These have been deprecated, please see \fBgearman_allocator_t\fP for the updated interface.
-.sp
-\fI\%gearman_client_task_free_all()\fP is used to free all current \fBgearman_task_st\fP that have been created with the \fI\%gearman_client_st\fP.
-.IP Warning
-By calling \fI\%gearman_client_task_free_all()\fP you can end up with a SEGFAULT if you try to use any \fBgearman_task_st\fP that you have kept pointers too.
-.RE
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_timeout()\fP returns an integer representing the amount of time in milliseconds. A value of \-1 means an infinite timeout value. See \fIpoll(3)\fP for more details.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_create(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_do_low.3'
--- docs/man/gearman_client_do_low.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_do_low.3	1970-01-01 00:00:00 +0000
@@ -1,124 +0,0 @@
-.TH "GEARMAN_CLIENT_DO_LOW" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_do_low \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B void *gearman_client_do(gearman_client_st\fI\ *client\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, size_t\fI\ *result_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.sp
-Changed in version 0.21: \fBGEARMAN_PAUSE\fP will no longer be returned. A do operation will now run till completion or error.
-.INDENT 0.0
-.TP
-.B void *gearman_client_do_high(gearman_client_st\fI\ *client\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, size_t\fI\ *result_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_client_do_low(gearman_client_st\fI\ *client\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, size_t\fI\ *result_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_do()\fP executes a single request to the gearmand
-server and waits for a reply.
-.sp
-\fI\%gearman_client_do_high()\fP and \fI\%gearman_client_do_low()\fP are
-identical to \fI\%gearman_client_do()\fP, only they set the priority to
-either high or low.
-.sp
-All of the functions will block until either a response or an error is
-returned.
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_do()\fP returns a pointer to a value that the caller must release. If ret_ptr is provided any errors that have occurred will be stored in it. Since a NULL/zero value is a valid value, you will always need to check ret_ptr if you are concerned with errors.
-.SH EXAMPLE
-.sp
-.nf
-.ft C
-/*
-# Gearman server and library
-# Copyright (C) 2012 Data Differential, http://datadifferential.com/
-# All rights reserved.
-#
-# Use and distribution licensed under the BSD license.  See
-# the COPYING file in this directory for full text.
-*/
-
-#include <string.h>
-#include <stdlib.h>
-#include <libgearman/gearman.h>
-
-int main(void)
-{
-  gearman_client_st *client= gearman_client_create(NULL);
-
-  gearman_return_t ret= gearman_client_add_server(client, "localhost", 0);
-  if (gearman_failed(ret))
-  {
-    return EXIT_FAILURE;
-  }
-
-  size_t result_size;
-  gearman_return_t rc;
-  void *value= gearman_client_do(client, "reverse_function", "unique_value", 
-                                 "my string to reverse", strlen("my string to reverse"), 
-                                 &result_size, &rc);
-
-  if (gearman_success(rc))
-  {
-    // Make use of value
-  }
-  free(value);
-
-  gearman_client_free(client);
-
-  return 0;
-}
-
-.ft P
-.fi
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_strerror(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_do_low_background.3'
--- docs/man/gearman_client_do_low_background.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_do_low_background.3	1970-01-01 00:00:00 +0000
@@ -1,130 +0,0 @@
-.TH "GEARMAN_CLIENT_DO_LOW_BACKGROUND" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_do_low_background \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_priority_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_do_background(gearman_client_st\fI\ *client\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, char\fI\ *job_handle\fP)
-.UNINDENT
-.sp
-Changed in version 0.21: \fBGEARMAN_PAUSE\fP will no longer be returned. A do operation will now run until it has been submitted.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_do_high_background(gearman_client_st\fI\ *client\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_job_handle_t\fI\ job_handle\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_do_low_background(gearman_client_st\fI\ *client\fP, const char\fI\ *function_name\fP, const char\fI\ *unique\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_job_handle_t\fI\ job_handle\fP)
-.UNINDENT
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_do_background()\fP executes a single request to the
-gearmand server and returns the status via \fBgearman_return_t\fP.
-.sp
-\fBgearman_client_add_task_high_background()\fP and \fBgearman_client_add_task_low_background()\fP are identical to
-\fI\%gearman_client_do_background()\fP, only they set the \fI\%gearman_priority_t\fP to either high or low.
-.sp
-If job_handle is not NULL, it will be populated with the name of the job_handle
-for the task created. The job handle needs to be the size of
-\fBGEARMAN_JOB_HANDLE_SIZE\fP. Please see \fBgearman_job_handle_t\fP for more information.
-.SH RETURN VALUE
-.sp
-\fBgearman_return_t\fP
-.SH EXAMPLE
-.sp
-.nf
-.ft C
-/*
-# Gearman server and library
-# Copyright (C) 2012 Data Differential, http://datadifferential.com/
-# All rights reserved.
-#
-# Use and distribution licensed under the BSD license.  See
-# the COPYING file in this directory for full text.
-*/
-
-#include <string.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <libgearman\-1.0/gearman.h>
-
-int main(void)
-{
-  gearman_client_st *client= gearman_client_create(NULL);
-
-  gearman_return_t ret= gearman_client_add_server(client, "localhost", 0);
-  if (gearman_failed(ret))
-  {
-    return EXIT_FAILURE;
-  }
-
-  gearman_job_handle_t job_handle;
-  gearman_return_t rc= gearman_client_do_background(client,
-                                                    "reverse_function",
-                                                    "unique_value",
-                                                    "my string to reverse", strlen("my string to reverse"),
-                                                    job_handle);
-
-  if (gearman_success(rc))
-  {
-    // Make use of value
-    printf("%s\en", job_handle);
-  }
-
-  gearman_client_free(client);
-
-  return 0;
-}
-
-.ft P
-.fi
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_strerror(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_do_status.3'
--- docs/man/gearman_client_do_status.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_do_status.3	1970-01-01 00:00:00 +0000
@@ -1,115 +0,0 @@
-.TH "GEARMAN_CLIENT_DO_STATUS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_do_status \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_client_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_client_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_client_context(const \fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_context(\fI\%gearman_client_st\fP\fI\ *client\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_malloc_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_task_free_all(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_task_context_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, \fI\%gearman_task_context_free_fn\fP\fI\ *function\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_st\fP is used for \fIclient\fP communication with the server.
-.sp
-\fI\%gearman_client_context()\fP and \fI\%gearman_client_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_client_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_client_timeout()\fP and \fI\%gearman_client_set_timeout()\fP get and set the current timeout value, in milliseconds, for the client.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_client_set_workload_malloc_fn()\fP and \fI\%gearman_client_set_workload_free_fn()\fP can be used to replace these with custom functions. (These have been deprecated, please see \fBgearman_allocator_t\fP for the updated interface.
-.sp
-\fI\%gearman_client_task_free_all()\fP is used to free all current \fBgearman_task_st\fP that have been created with the \fI\%gearman_client_st\fP.
-.IP Warning
-By calling \fI\%gearman_client_task_free_all()\fP you can end up with a SEGFAULT if you try to use any \fBgearman_task_st\fP that you have kept pointers too.
-.RE
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_timeout()\fP returns an integer representing the amount of time in milliseconds. A value of \-1 means an infinite timeout value. See \fIpoll(3)\fP for more details.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_create(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_echo.3'
--- docs/man/gearman_client_echo.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_echo.3	1970-01-01 00:00:00 +0000
@@ -1,64 +0,0 @@
-.TH "GEARMAN_CLIENT_ECHO" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_echo \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_echo(gearman_client_st\fI\ *client\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_echo(gearman_worker_st\fI\ *worker\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_echo()\fP and \fI\%gearman_worker_echo()\fP send a message to a \fBgearmand\fP server. The server will then respond with the message that it sent. These commands are just for testing the connection to the servers that were configure for the \fBgearman_client_st\fP and the \fBgearman_worker_st\fP that were used.
-.SH RETURN VALUE
-.sp
-\fBgearman_return_t\fP
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_errno.3'
--- docs/man/gearman_client_errno.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_errno.3	1970-01-01 00:00:00 +0000
@@ -1,66 +0,0 @@
-.TH "GEARMAN_CLIENT_ERRNO" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_errno \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B const char *gearman_client_error(const gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_client_errno(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.sp
-Ling with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_error()\fP and \fI\%gearman_client_errno()\fP report on the last errors that the client reported/stored in \fBgearman_client_st\fP. If you are interested in recording all errors please see \fBgearman_client_set_log_fn()\fP.
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_errno()\fP returns the last \fIerrno\fP that the client recorded.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_error.3'
--- docs/man/gearman_client_error.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_error.3	1970-01-01 00:00:00 +0000
@@ -1,66 +0,0 @@
-.TH "GEARMAN_CLIENT_ERROR" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_error \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B const char *gearman_client_error(const gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_client_errno(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.sp
-Ling with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_error()\fP and \fI\%gearman_client_errno()\fP report on the last errors that the client reported/stored in \fBgearman_client_st\fP. If you are interested in recording all errors please see \fBgearman_client_set_log_fn()\fP.
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_errno()\fP returns the last \fIerrno\fP that the client recorded.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_free.3'
--- docs/man/gearman_client_free.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_free.3	1970-01-01 00:00:00 +0000
@@ -1,93 +0,0 @@
-.TH "GEARMAN_CLIENT_FREE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_free \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_client_st *gearman_client_create(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_client_st *gearman_client_clone(gearman_client_st\fI\ *client\fP, const gearman_client_st\fI\ *from\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_free(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_create()\fP is used to create a c:type:\fIgearman_client_st\fP  structure that will then
-be used by other libgearman client functions to communicate with the server. You
-should either pass a statically declared \fBgearman_client_st\fP  to \fI\%gearman_client_create()\fP or
-a NULL. If a NULL passed in then a structure is allocated for you.
-.sp
-\fI\%gearman_client_clone()\fP is similar to \fI\%gearman_client_create()\fP but it copies the
-defaults and list of servers from the source \fBgearman_client_st\fP . If you pass a null as
-the argument for the source to clone, it is the same as a call to gearman_client_create.
-If the destination argument is NULL a \fBgearman_client_st\fP  will be allocated for you.
-.sp
-To clean up memory associated with a \fBgearman_client_st\fP  structure you should pass
-it to gearman_client_free when you are finished using it. \fI\%gearman_client_free()\fP is
-the only way to make sure all memory is deallocated when you finish using
-the structure.
-.IP Warning
-You may wish to avoid using \fI\%gearman_client_create()\fP or \fI\%gearman_client_clone()\fP with a
-stack based allocation, ie the first parameter. The most common issues related to ABI safety involve
-stack allocated structures.
-.RE
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_create\fP returns a pointer to the gearman_client_st
-that was created (or initialized). On an allocation failure, it returns
-NULL.
-.sp
-\fI\%gearman_client_clone\fP returns a pointer to the gearman_client_st that was created
-(or initialized). On an allocation failure, it returns NULL.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_strerror(3)\fP \fIgearman_client_st(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_has_option.3'
--- docs/man/gearman_client_has_option.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_has_option.3	1970-01-01 00:00:00 +0000
@@ -1,105 +0,0 @@
-.TH "GEARMAN_CLIENT_HAS_OPTION" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_has_option \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_client_options_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_client_options_t\fP gearman_client_options(const gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_options(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_add_options(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_remove_options(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_client_has_option(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ option\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_options()\fP returns the \fI\%gearman_client_options_t\fP for \fBgearman_client_st\fP. You enable options via \fI\%gearman_client_add_options()\fP and disable options via \fI\%gearman_client_remove_options()\fP.
-.sp
-\fI\%gearman_client_set_options()\fP has been DEPRECATED.
-.sp
-The currently supported options are:
-.INDENT 0.0
-.TP
-.B GEARMAN_CLIENT_NON_BLOCKING
-.UNINDENT
-.sp
-Run the cient in a non\-blocking mode.
-.INDENT 0.0
-.TP
-.B GEARMAN_CLIENT_FREE_TASKS
-.UNINDENT
-.sp
-Automatically free task objects once they are complete.
-.INDENT 0.0
-.TP
-.B GEARMAN_CLIENT_UNBUFFERED_RESULT
-.UNINDENT
-.sp
-Allow the client to read data in chunks rather than have the library buffer
-the entire data result and pass that back.
-.SH RETURN VALUE
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_job_status.3'
--- docs/man/gearman_client_job_status.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_job_status.3	1970-01-01 00:00:00 +0000
@@ -1,69 +0,0 @@
-.TH "GEARMAN_CLIENT_JOB_STATUS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_job_status \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_job_status(gearman_client_st\fI\ *client\fP, gearman_job_handle_t\fI\ job_handle\fP, bool\fI\ *is_known\fP, bool\fI\ *is_running\fP, uint32_t\fI\ *numerator\fP, uint32_t\fI\ *denominator\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_job_status()\fP is used to find the status of a job via its \fBgearman_job_handle_t\fP. The arguments is_known, is_running, numerator, and denominator are all optional. Unless a Gearman worker has sent numerator/denominator via \fBgearman_job_send_status()\fP, those values will be zero.
-.sp
-If the arguments is_known and is_running are ommitted then the function returns state data via \fBgearman_return_t\fP.
-.SH RETURN VALUE
-.sp
-\fBgearman_return_t\fP will be returned. \fBGEARMAN_SUCCESS\fP will be returned upon success of the status being updated.
-If the arguments is_known and is_running are omitted then \fI\%gearman_client_job_status()\fP will return \fBGEARMAN_JOB_EXISTS\fP if the \fBgearman_job_handle_t\fP is known on the server, and
-\fBGEARMAN_IN_PROGRESS\fP if it is running. Knowing whether the job is running or not has higher precedence. \fBgearman_continue()\fP can be used for loops where you want to exit from the loop once the job has been completed.
-.IP Warning
-For loops you should always check \fBgearman_return_t\fP with \fBgearman_continue()\fP even if you specifiy the argument is_known or is_running. A non\-blocking IO call can return something other then \fBGEARMAN_SUCCESS\fP, in some cases you will want to treat those values not as errors.
-.RE
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_st(3)\fP \fIgearman_job_handle_t(3)\fP \fIgearman_continue(3\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_options.3'
--- docs/man/gearman_client_options.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_options.3	1970-01-01 00:00:00 +0000
@@ -1,105 +0,0 @@
-.TH "GEARMAN_CLIENT_OPTIONS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_options \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_client_options_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_client_options_t\fP gearman_client_options(const gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_options(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_add_options(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_remove_options(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_client_has_option(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ option\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_options()\fP returns the \fI\%gearman_client_options_t\fP for \fBgearman_client_st\fP. You enable options via \fI\%gearman_client_add_options()\fP and disable options via \fI\%gearman_client_remove_options()\fP.
-.sp
-\fI\%gearman_client_set_options()\fP has been DEPRECATED.
-.sp
-The currently supported options are:
-.INDENT 0.0
-.TP
-.B GEARMAN_CLIENT_NON_BLOCKING
-.UNINDENT
-.sp
-Run the cient in a non\-blocking mode.
-.INDENT 0.0
-.TP
-.B GEARMAN_CLIENT_FREE_TASKS
-.UNINDENT
-.sp
-Automatically free task objects once they are complete.
-.INDENT 0.0
-.TP
-.B GEARMAN_CLIENT_UNBUFFERED_RESULT
-.UNINDENT
-.sp
-Allow the client to read data in chunks rather than have the library buffer
-the entire data result and pass that back.
-.SH RETURN VALUE
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_options_t.3'
--- docs/man/gearman_client_options_t.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_options_t.3	1970-01-01 00:00:00 +0000
@@ -1,105 +0,0 @@
-.TH "GEARMAN_CLIENT_OPTIONS_T" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_options_t \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_client_options_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_client_options_t\fP gearman_client_options(const gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_options(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_add_options(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_remove_options(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_client_has_option(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ option\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_options()\fP returns the \fI\%gearman_client_options_t\fP for \fBgearman_client_st\fP. You enable options via \fI\%gearman_client_add_options()\fP and disable options via \fI\%gearman_client_remove_options()\fP.
-.sp
-\fI\%gearman_client_set_options()\fP has been DEPRECATED.
-.sp
-The currently supported options are:
-.INDENT 0.0
-.TP
-.B GEARMAN_CLIENT_NON_BLOCKING
-.UNINDENT
-.sp
-Run the cient in a non\-blocking mode.
-.INDENT 0.0
-.TP
-.B GEARMAN_CLIENT_FREE_TASKS
-.UNINDENT
-.sp
-Automatically free task objects once they are complete.
-.INDENT 0.0
-.TP
-.B GEARMAN_CLIENT_UNBUFFERED_RESULT
-.UNINDENT
-.sp
-Allow the client to read data in chunks rather than have the library buffer
-the entire data result and pass that back.
-.SH RETURN VALUE
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_remove_options.3'
--- docs/man/gearman_client_remove_options.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_remove_options.3	1970-01-01 00:00:00 +0000
@@ -1,105 +0,0 @@
-.TH "GEARMAN_CLIENT_REMOVE_OPTIONS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_remove_options \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_client_options_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_client_options_t\fP gearman_client_options(const gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_options(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_add_options(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_remove_options(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_client_has_option(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ option\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_options()\fP returns the \fI\%gearman_client_options_t\fP for \fBgearman_client_st\fP. You enable options via \fI\%gearman_client_add_options()\fP and disable options via \fI\%gearman_client_remove_options()\fP.
-.sp
-\fI\%gearman_client_set_options()\fP has been DEPRECATED.
-.sp
-The currently supported options are:
-.INDENT 0.0
-.TP
-.B GEARMAN_CLIENT_NON_BLOCKING
-.UNINDENT
-.sp
-Run the cient in a non\-blocking mode.
-.INDENT 0.0
-.TP
-.B GEARMAN_CLIENT_FREE_TASKS
-.UNINDENT
-.sp
-Automatically free task objects once they are complete.
-.INDENT 0.0
-.TP
-.B GEARMAN_CLIENT_UNBUFFERED_RESULT
-.UNINDENT
-.sp
-Allow the client to read data in chunks rather than have the library buffer
-the entire data result and pass that back.
-.SH RETURN VALUE
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_remove_servers.3'
--- docs/man/gearman_client_remove_servers.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_remove_servers.3	1970-01-01 00:00:00 +0000
@@ -1,78 +0,0 @@
-.TH "GEARMAN_CLIENT_REMOVE_SERVERS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_remove_servers \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_add_server(gearman_client_st\fI\ *client\fP, const char\fI\ *host\fP, in_port_t\fI\ port\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_add_servers(gearman_client_st\fI\ *client\fP, const char\fI\ *servers\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_remove_servers(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_add_server()\fP will add an additional \fBgearmand\fP server to the list of servers that the client will take work from.
-.sp
-\fI\%gearman_client_remove_servers()\fP will remove all servers from the \fBgearman_client_st\fP.
-.sp
-\fI\%gearman_client_add_servers()\fP takes a list of \fBgearmand\fP servers that will be parsed to provide servers for the client. The format for this is SERVER[:PORT][,SERVER[:PORT]]...
-.INDENT 0.0
-.TP
-.B Examples of this are::
-10.0.0.1,10.0.0.2,10.0.0.3
-localhost234,jobserver2.domain.com:7003,10.0.0.3
-.UNINDENT
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_add_server()\fP and \fI\%gearman_client_remove_servers()\fP return \fBgearman_return_t\fP.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.RE
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_st\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_run_tasks.3'
--- docs/man/gearman_client_run_tasks.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_run_tasks.3	1970-01-01 00:00:00 +0000
@@ -1,74 +0,0 @@
-.TH "GEARMAN_CLIENT_RUN_TASKS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_run_tasks \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_run_tasks(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_run_tasks()\fP executes one or more tasks that have
-been added via \fBgearman_client_add_task()\fP,
-\fBgearman_client_add_task_status()\fP or
-\fBgearman_client_add_task_background()\fP.
-.sp
-\fI\%gearman_client_run_tasks()\fP can also be used with
-\fBgearman_execute()\fP if either non\-blocking or background tasks were
-created with it.
-.SH RETURN VALUE
-.sp
-\fBgearman_return_t\fP
-.sp
-If \fBGEARMAN_PAUSE\fP is returned one of the tasks has "paused" in
-order to give the caller an opportunity to take some actions (like read
-data, handle an exception, etc...). See \fBgearman_task_st\fP for more
-information about the state of a task.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_set_complete_fn.3'
--- docs/man/gearman_client_set_complete_fn.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_set_complete_fn.3	1970-01-01 00:00:00 +0000
@@ -1,161 +0,0 @@
-.TH "GEARMAN_CLIENT_SET_COMPLETE_FN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_set_complete_fn \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_actions_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_workload_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_created_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_data_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_warning_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_universal_status_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_exception_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_fail_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_complete_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_workload_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_created_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_created_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_data_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_data_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_warning_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_warning_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_status_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_universal_status_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_complete_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_complete_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_exception_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_exception_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_fail_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_fail_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_clear_fn(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_client_do_job_handle(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.sp
-Link to \-lgearman
-.SH DESCRIPTION
-.sp
-Callbacks for client execution task states.
-.sp
-\fI\%gearman_client_set_data_fn()\fP sets the callback function that will
-be called if server is to make a request to the client to provide more data.
-.sp
-\fI\%gearman_client_do_job_handle()\fP gest the job handle for the running task. This should be used between repeated
-\fBgearman_client_do()\fP (and related) calls to get information.
-.sp
-\fI\%gearman_client_clear_fn()\fP can be called to remove all existing
-\fI\%gearman_actions_t\fP that have been set.
-.sp
-\fI\%gearman_client_set_created_fn()\fP,
-\fI\%gearman_client_set_data_fn()\fP,
-\fI\%gearman_client_set_warning_fn()\fP,
-\fI\%gearman_client_set_status_fn()\fP,
-\fI\%gearman_client_set_complete_fn()\fP,
-\fI\%gearman_client_set_exception_fn()\fP, and
-\fI\%gearman_client_set_fail_fn()\fP, set callback functions for the
-different states of execution for a client request. Each request, ie
-a creation of \fBgearman_task_st\fP, keeps a copy of callbacks when it
-is created.
-.sp
-\fI\%gearman_client_set_exception_fn()\fP will only be called if exceptions are enabled on the server. You can do this by calling \fBgearman_client_set_server_option()\fP.
-.sp
-An example of this:
-.sp
-.nf
-.ft C
-const char *EXCEPTIONS="exceptions";
-gearman_client_set_server_option(client, EXCEPTIONS, strlen(EXCEPTIONS));
-.ft P
-.fi
-.SH RETURN VALUE
-.sp
-None
-.IP "See also"
-.RE
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error(3)\fP or \fIgearman_worker_error(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_set_context.3'
--- docs/man/gearman_client_set_context.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_set_context.3	1970-01-01 00:00:00 +0000
@@ -1,161 +0,0 @@
-.TH "GEARMAN_CLIENT_SET_CONTEXT" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_set_context \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_actions_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_workload_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_created_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_data_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_warning_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_universal_status_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_exception_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_fail_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_complete_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_workload_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_created_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_created_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_data_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_data_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_warning_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_warning_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_status_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_universal_status_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_complete_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_complete_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_exception_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_exception_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_fail_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_fail_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_clear_fn(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_client_do_job_handle(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.sp
-Link to \-lgearman
-.SH DESCRIPTION
-.sp
-Callbacks for client execution task states.
-.sp
-\fI\%gearman_client_set_data_fn()\fP sets the callback function that will
-be called if server is to make a request to the client to provide more data.
-.sp
-\fI\%gearman_client_do_job_handle()\fP gest the job handle for the running task. This should be used between repeated
-\fBgearman_client_do()\fP (and related) calls to get information.
-.sp
-\fI\%gearman_client_clear_fn()\fP can be called to remove all existing
-\fI\%gearman_actions_t\fP that have been set.
-.sp
-\fI\%gearman_client_set_created_fn()\fP,
-\fI\%gearman_client_set_data_fn()\fP,
-\fI\%gearman_client_set_warning_fn()\fP,
-\fI\%gearman_client_set_status_fn()\fP,
-\fI\%gearman_client_set_complete_fn()\fP,
-\fI\%gearman_client_set_exception_fn()\fP, and
-\fI\%gearman_client_set_fail_fn()\fP, set callback functions for the
-different states of execution for a client request. Each request, ie
-a creation of \fBgearman_task_st\fP, keeps a copy of callbacks when it
-is created.
-.sp
-\fI\%gearman_client_set_exception_fn()\fP will only be called if exceptions are enabled on the server. You can do this by calling \fBgearman_client_set_server_option()\fP.
-.sp
-An example of this:
-.sp
-.nf
-.ft C
-const char *EXCEPTIONS="exceptions";
-gearman_client_set_server_option(client, EXCEPTIONS, strlen(EXCEPTIONS));
-.ft P
-.fi
-.SH RETURN VALUE
-.sp
-None
-.IP "See also"
-.RE
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error(3)\fP or \fIgearman_worker_error(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_set_created_fn.3'
--- docs/man/gearman_client_set_created_fn.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_set_created_fn.3	1970-01-01 00:00:00 +0000
@@ -1,161 +0,0 @@
-.TH "GEARMAN_CLIENT_SET_CREATED_FN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_set_created_fn \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_actions_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_workload_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_created_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_data_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_warning_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_universal_status_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_exception_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_fail_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_complete_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_workload_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_created_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_created_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_data_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_data_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_warning_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_warning_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_status_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_universal_status_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_complete_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_complete_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_exception_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_exception_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_fail_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_fail_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_clear_fn(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_client_do_job_handle(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.sp
-Link to \-lgearman
-.SH DESCRIPTION
-.sp
-Callbacks for client execution task states.
-.sp
-\fI\%gearman_client_set_data_fn()\fP sets the callback function that will
-be called if server is to make a request to the client to provide more data.
-.sp
-\fI\%gearman_client_do_job_handle()\fP gest the job handle for the running task. This should be used between repeated
-\fBgearman_client_do()\fP (and related) calls to get information.
-.sp
-\fI\%gearman_client_clear_fn()\fP can be called to remove all existing
-\fI\%gearman_actions_t\fP that have been set.
-.sp
-\fI\%gearman_client_set_created_fn()\fP,
-\fI\%gearman_client_set_data_fn()\fP,
-\fI\%gearman_client_set_warning_fn()\fP,
-\fI\%gearman_client_set_status_fn()\fP,
-\fI\%gearman_client_set_complete_fn()\fP,
-\fI\%gearman_client_set_exception_fn()\fP, and
-\fI\%gearman_client_set_fail_fn()\fP, set callback functions for the
-different states of execution for a client request. Each request, ie
-a creation of \fBgearman_task_st\fP, keeps a copy of callbacks when it
-is created.
-.sp
-\fI\%gearman_client_set_exception_fn()\fP will only be called if exceptions are enabled on the server. You can do this by calling \fBgearman_client_set_server_option()\fP.
-.sp
-An example of this:
-.sp
-.nf
-.ft C
-const char *EXCEPTIONS="exceptions";
-gearman_client_set_server_option(client, EXCEPTIONS, strlen(EXCEPTIONS));
-.ft P
-.fi
-.SH RETURN VALUE
-.sp
-None
-.IP "See also"
-.RE
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error(3)\fP or \fIgearman_worker_error(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_set_data_fn.3'
--- docs/man/gearman_client_set_data_fn.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_set_data_fn.3	1970-01-01 00:00:00 +0000
@@ -1,161 +0,0 @@
-.TH "GEARMAN_CLIENT_SET_DATA_FN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_set_data_fn \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_actions_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_workload_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_created_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_data_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_warning_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_universal_status_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_exception_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_fail_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_complete_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_workload_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_created_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_created_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_data_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_data_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_warning_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_warning_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_status_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_universal_status_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_complete_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_complete_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_exception_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_exception_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_fail_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_fail_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_clear_fn(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_client_do_job_handle(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.sp
-Link to \-lgearman
-.SH DESCRIPTION
-.sp
-Callbacks for client execution task states.
-.sp
-\fI\%gearman_client_set_data_fn()\fP sets the callback function that will
-be called if server is to make a request to the client to provide more data.
-.sp
-\fI\%gearman_client_do_job_handle()\fP gest the job handle for the running task. This should be used between repeated
-\fBgearman_client_do()\fP (and related) calls to get information.
-.sp
-\fI\%gearman_client_clear_fn()\fP can be called to remove all existing
-\fI\%gearman_actions_t\fP that have been set.
-.sp
-\fI\%gearman_client_set_created_fn()\fP,
-\fI\%gearman_client_set_data_fn()\fP,
-\fI\%gearman_client_set_warning_fn()\fP,
-\fI\%gearman_client_set_status_fn()\fP,
-\fI\%gearman_client_set_complete_fn()\fP,
-\fI\%gearman_client_set_exception_fn()\fP, and
-\fI\%gearman_client_set_fail_fn()\fP, set callback functions for the
-different states of execution for a client request. Each request, ie
-a creation of \fBgearman_task_st\fP, keeps a copy of callbacks when it
-is created.
-.sp
-\fI\%gearman_client_set_exception_fn()\fP will only be called if exceptions are enabled on the server. You can do this by calling \fBgearman_client_set_server_option()\fP.
-.sp
-An example of this:
-.sp
-.nf
-.ft C
-const char *EXCEPTIONS="exceptions";
-gearman_client_set_server_option(client, EXCEPTIONS, strlen(EXCEPTIONS));
-.ft P
-.fi
-.SH RETURN VALUE
-.sp
-None
-.IP "See also"
-.RE
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error(3)\fP or \fIgearman_worker_error(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_set_exception_fn.3'
--- docs/man/gearman_client_set_exception_fn.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_set_exception_fn.3	1970-01-01 00:00:00 +0000
@@ -1,161 +0,0 @@
-.TH "GEARMAN_CLIENT_SET_EXCEPTION_FN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_set_exception_fn \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_actions_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_workload_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_created_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_data_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_warning_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_universal_status_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_exception_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_fail_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_complete_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_workload_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_created_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_created_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_data_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_data_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_warning_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_warning_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_status_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_universal_status_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_complete_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_complete_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_exception_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_exception_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_fail_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_fail_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_clear_fn(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_client_do_job_handle(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.sp
-Link to \-lgearman
-.SH DESCRIPTION
-.sp
-Callbacks for client execution task states.
-.sp
-\fI\%gearman_client_set_data_fn()\fP sets the callback function that will
-be called if server is to make a request to the client to provide more data.
-.sp
-\fI\%gearman_client_do_job_handle()\fP gest the job handle for the running task. This should be used between repeated
-\fBgearman_client_do()\fP (and related) calls to get information.
-.sp
-\fI\%gearman_client_clear_fn()\fP can be called to remove all existing
-\fI\%gearman_actions_t\fP that have been set.
-.sp
-\fI\%gearman_client_set_created_fn()\fP,
-\fI\%gearman_client_set_data_fn()\fP,
-\fI\%gearman_client_set_warning_fn()\fP,
-\fI\%gearman_client_set_status_fn()\fP,
-\fI\%gearman_client_set_complete_fn()\fP,
-\fI\%gearman_client_set_exception_fn()\fP, and
-\fI\%gearman_client_set_fail_fn()\fP, set callback functions for the
-different states of execution for a client request. Each request, ie
-a creation of \fBgearman_task_st\fP, keeps a copy of callbacks when it
-is created.
-.sp
-\fI\%gearman_client_set_exception_fn()\fP will only be called if exceptions are enabled on the server. You can do this by calling \fBgearman_client_set_server_option()\fP.
-.sp
-An example of this:
-.sp
-.nf
-.ft C
-const char *EXCEPTIONS="exceptions";
-gearman_client_set_server_option(client, EXCEPTIONS, strlen(EXCEPTIONS));
-.ft P
-.fi
-.SH RETURN VALUE
-.sp
-None
-.IP "See also"
-.RE
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error(3)\fP or \fIgearman_worker_error(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_set_fail_fn.3'
--- docs/man/gearman_client_set_fail_fn.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_set_fail_fn.3	1970-01-01 00:00:00 +0000
@@ -1,161 +0,0 @@
-.TH "GEARMAN_CLIENT_SET_FAIL_FN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_set_fail_fn \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_actions_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_workload_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_created_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_data_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_warning_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_universal_status_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_exception_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_fail_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_complete_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_workload_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_created_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_created_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_data_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_data_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_warning_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_warning_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_status_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_universal_status_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_complete_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_complete_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_exception_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_exception_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_fail_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_fail_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_clear_fn(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_client_do_job_handle(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.sp
-Link to \-lgearman
-.SH DESCRIPTION
-.sp
-Callbacks for client execution task states.
-.sp
-\fI\%gearman_client_set_data_fn()\fP sets the callback function that will
-be called if server is to make a request to the client to provide more data.
-.sp
-\fI\%gearman_client_do_job_handle()\fP gest the job handle for the running task. This should be used between repeated
-\fBgearman_client_do()\fP (and related) calls to get information.
-.sp
-\fI\%gearman_client_clear_fn()\fP can be called to remove all existing
-\fI\%gearman_actions_t\fP that have been set.
-.sp
-\fI\%gearman_client_set_created_fn()\fP,
-\fI\%gearman_client_set_data_fn()\fP,
-\fI\%gearman_client_set_warning_fn()\fP,
-\fI\%gearman_client_set_status_fn()\fP,
-\fI\%gearman_client_set_complete_fn()\fP,
-\fI\%gearman_client_set_exception_fn()\fP, and
-\fI\%gearman_client_set_fail_fn()\fP, set callback functions for the
-different states of execution for a client request. Each request, ie
-a creation of \fBgearman_task_st\fP, keeps a copy of callbacks when it
-is created.
-.sp
-\fI\%gearman_client_set_exception_fn()\fP will only be called if exceptions are enabled on the server. You can do this by calling \fBgearman_client_set_server_option()\fP.
-.sp
-An example of this:
-.sp
-.nf
-.ft C
-const char *EXCEPTIONS="exceptions";
-gearman_client_set_server_option(client, EXCEPTIONS, strlen(EXCEPTIONS));
-.ft P
-.fi
-.SH RETURN VALUE
-.sp
-None
-.IP "See also"
-.RE
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error(3)\fP or \fIgearman_worker_error(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_set_log_fn.3'
--- docs/man/gearman_client_set_log_fn.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_set_log_fn.3	1970-01-01 00:00:00 +0000
@@ -1,64 +0,0 @@
-.TH "GEARMAN_CLIENT_SET_LOG_FN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_set_log_fn \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B void gearman_client_set_log_fn(gearman_worker_st\fI\ *worker\fP, gearman_log_fn\fI\ *function\fP, void\fI\ *context\fP, gearman_verbose_t\fI\ verbose\fP)
-.UNINDENT
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_set_log_fn()\fP is similar to \fBgearman_worker_set_log_fn()\fP but it used with clients, aka, \fBgearman_client_st\fP.
-\fI\%gearman_client_set_log_fn()\fP allows you to register a callback that will be passed all error messages that are givin to the client.
-.sp
-See \fBgearman_log_fn\fP for more information on the callback.
-.sp
-See \fBgearman_verbose_t\fP for more information on logging levels.
-.SH RETURN VALUE
-.sp
-None
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_log_fn(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_set_memory_allocators.3'
--- docs/man/gearman_client_set_memory_allocators.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_set_memory_allocators.3	1970-01-01 00:00:00 +0000
@@ -1,84 +0,0 @@
-.TH "GEARMAN_CLIENT_SET_MEMORY_ALLOCATORS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_set_memory_allocators \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_allocator_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_malloc_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_realloc_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_calloc_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_set_memory_allocators(gearman_client_st\fI\ *\fP, \fI\%gearman_malloc_fn\fP\fI\ *malloc_fn\fP, \fI\%gearman_free_fn\fP\fI\ *free_fn\fP, \fI\%gearman_realloc_fn\fP\fI\ *realloc_fn\fP, \fI\%gearman_calloc_fn\fP\fI\ *calloc_fn\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_set_memory_allocators(gearman_worker_st\fI\ *\fP, \fI\%gearman_malloc_fn\fP\fI\ *malloc_fn\fP, \fI\%gearman_free_fn\fP\fI\ *free_fn\fP, \fI\%gearman_realloc_fn\fP\fI\ *realloc_fn\fP, \fI\%gearman_calloc_fn\fP\fI\ *calloc_fn\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Link to \-lgearman
-.SH DESCRIPTION
-.sp
-Install callbacks for custom allocation.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. You can use \fI\%gearman_client_set_memory_allocators()\fP and \fI\%gearman_worker_set_memory_allocators()\fP to set your own custom allocators.
-.SH RETURN VALUE
-.sp
-None
-.IP "See also"
-.RE
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_st(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_set_namespace.3'
--- docs/man/gearman_client_set_namespace.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_set_namespace.3	1970-01-01 00:00:00 +0000
@@ -1,69 +0,0 @@
-.TH "GEARMAN_CLIENT_SET_NAMESPACE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_set_namespace \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B void gearman_client_set_namespace(gearman_client_st\fI\ *self\fP, const char\fI\ *namespace_key\fP, size_t\fI\ namespace_key_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_namespace(gearman_worker_st\fI\ *self\fP, const char\fI\ *namespace_key\fP, size_t\fI\ namespace_key_size\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-gearman_client_set_namespace() and gearman_worker_set_namespace() set
-a "namespace" for a given set of functions. Only clients and workers sharing
-a namespace_key can see one anothers workloads and functions.
-.sp
-By setting namespace_key to NULL you can disable the namespace.
-.SH RETURN
-.sp
-None
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_set_options.3'
--- docs/man/gearman_client_set_options.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_set_options.3	1970-01-01 00:00:00 +0000
@@ -1,105 +0,0 @@
-.TH "GEARMAN_CLIENT_SET_OPTIONS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_set_options \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_client_options_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_client_options_t\fP gearman_client_options(const gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_options(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_add_options(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_remove_options(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_client_has_option(gearman_client_st\fI\ *client\fP, \fI\%gearman_client_options_t\fP\fI\ option\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_options()\fP returns the \fI\%gearman_client_options_t\fP for \fBgearman_client_st\fP. You enable options via \fI\%gearman_client_add_options()\fP and disable options via \fI\%gearman_client_remove_options()\fP.
-.sp
-\fI\%gearman_client_set_options()\fP has been DEPRECATED.
-.sp
-The currently supported options are:
-.INDENT 0.0
-.TP
-.B GEARMAN_CLIENT_NON_BLOCKING
-.UNINDENT
-.sp
-Run the cient in a non\-blocking mode.
-.INDENT 0.0
-.TP
-.B GEARMAN_CLIENT_FREE_TASKS
-.UNINDENT
-.sp
-Automatically free task objects once they are complete.
-.INDENT 0.0
-.TP
-.B GEARMAN_CLIENT_UNBUFFERED_RESULT
-.UNINDENT
-.sp
-Allow the client to read data in chunks rather than have the library buffer
-the entire data result and pass that back.
-.SH RETURN VALUE
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_set_status_fn.3'
--- docs/man/gearman_client_set_status_fn.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_set_status_fn.3	1970-01-01 00:00:00 +0000
@@ -1,161 +0,0 @@
-.TH "GEARMAN_CLIENT_SET_STATUS_FN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_set_status_fn \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_actions_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_workload_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_created_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_data_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_warning_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_universal_status_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_exception_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_fail_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_complete_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_workload_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_created_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_created_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_data_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_data_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_warning_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_warning_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_status_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_universal_status_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_complete_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_complete_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_exception_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_exception_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_fail_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_fail_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_clear_fn(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_client_do_job_handle(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.sp
-Link to \-lgearman
-.SH DESCRIPTION
-.sp
-Callbacks for client execution task states.
-.sp
-\fI\%gearman_client_set_data_fn()\fP sets the callback function that will
-be called if server is to make a request to the client to provide more data.
-.sp
-\fI\%gearman_client_do_job_handle()\fP gest the job handle for the running task. This should be used between repeated
-\fBgearman_client_do()\fP (and related) calls to get information.
-.sp
-\fI\%gearman_client_clear_fn()\fP can be called to remove all existing
-\fI\%gearman_actions_t\fP that have been set.
-.sp
-\fI\%gearman_client_set_created_fn()\fP,
-\fI\%gearman_client_set_data_fn()\fP,
-\fI\%gearman_client_set_warning_fn()\fP,
-\fI\%gearman_client_set_status_fn()\fP,
-\fI\%gearman_client_set_complete_fn()\fP,
-\fI\%gearman_client_set_exception_fn()\fP, and
-\fI\%gearman_client_set_fail_fn()\fP, set callback functions for the
-different states of execution for a client request. Each request, ie
-a creation of \fBgearman_task_st\fP, keeps a copy of callbacks when it
-is created.
-.sp
-\fI\%gearman_client_set_exception_fn()\fP will only be called if exceptions are enabled on the server. You can do this by calling \fBgearman_client_set_server_option()\fP.
-.sp
-An example of this:
-.sp
-.nf
-.ft C
-const char *EXCEPTIONS="exceptions";
-gearman_client_set_server_option(client, EXCEPTIONS, strlen(EXCEPTIONS));
-.ft P
-.fi
-.SH RETURN VALUE
-.sp
-None
-.IP "See also"
-.RE
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error(3)\fP or \fIgearman_worker_error(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_set_task_context_free_fn.3'
--- docs/man/gearman_client_set_task_context_free_fn.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_set_task_context_free_fn.3	1970-01-01 00:00:00 +0000
@@ -1,115 +0,0 @@
-.TH "GEARMAN_CLIENT_SET_TASK_CONTEXT_FREE_FN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_set_task_context_free_fn \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_client_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_client_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_client_context(const \fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_context(\fI\%gearman_client_st\fP\fI\ *client\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_malloc_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_task_free_all(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_task_context_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, \fI\%gearman_task_context_free_fn\fP\fI\ *function\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_st\fP is used for \fIclient\fP communication with the server.
-.sp
-\fI\%gearman_client_context()\fP and \fI\%gearman_client_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_client_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_client_timeout()\fP and \fI\%gearman_client_set_timeout()\fP get and set the current timeout value, in milliseconds, for the client.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_client_set_workload_malloc_fn()\fP and \fI\%gearman_client_set_workload_free_fn()\fP can be used to replace these with custom functions. (These have been deprecated, please see \fBgearman_allocator_t\fP for the updated interface.
-.sp
-\fI\%gearman_client_task_free_all()\fP is used to free all current \fBgearman_task_st\fP that have been created with the \fI\%gearman_client_st\fP.
-.IP Warning
-By calling \fI\%gearman_client_task_free_all()\fP you can end up with a SEGFAULT if you try to use any \fBgearman_task_st\fP that you have kept pointers too.
-.RE
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_timeout()\fP returns an integer representing the amount of time in milliseconds. A value of \-1 means an infinite timeout value. See \fIpoll(3)\fP for more details.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_create(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_set_timeout.3'
--- docs/man/gearman_client_set_timeout.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_set_timeout.3	1970-01-01 00:00:00 +0000
@@ -1,115 +0,0 @@
-.TH "GEARMAN_CLIENT_SET_TIMEOUT" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_set_timeout \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_client_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_client_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_client_context(const \fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_context(\fI\%gearman_client_st\fP\fI\ *client\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_malloc_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_task_free_all(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_task_context_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, \fI\%gearman_task_context_free_fn\fP\fI\ *function\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_st\fP is used for \fIclient\fP communication with the server.
-.sp
-\fI\%gearman_client_context()\fP and \fI\%gearman_client_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_client_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_client_timeout()\fP and \fI\%gearman_client_set_timeout()\fP get and set the current timeout value, in milliseconds, for the client.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_client_set_workload_malloc_fn()\fP and \fI\%gearman_client_set_workload_free_fn()\fP can be used to replace these with custom functions. (These have been deprecated, please see \fBgearman_allocator_t\fP for the updated interface.
-.sp
-\fI\%gearman_client_task_free_all()\fP is used to free all current \fBgearman_task_st\fP that have been created with the \fI\%gearman_client_st\fP.
-.IP Warning
-By calling \fI\%gearman_client_task_free_all()\fP you can end up with a SEGFAULT if you try to use any \fBgearman_task_st\fP that you have kept pointers too.
-.RE
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_timeout()\fP returns an integer representing the amount of time in milliseconds. A value of \-1 means an infinite timeout value. See \fIpoll(3)\fP for more details.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_create(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_set_warning_fn.3'
--- docs/man/gearman_client_set_warning_fn.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_set_warning_fn.3	1970-01-01 00:00:00 +0000
@@ -1,161 +0,0 @@
-.TH "GEARMAN_CLIENT_SET_WARNING_FN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_set_warning_fn \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_actions_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_workload_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_created_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_data_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_warning_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_universal_status_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_exception_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_fail_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_complete_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_workload_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_created_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_created_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_data_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_data_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_warning_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_warning_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_status_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_universal_status_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_complete_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_complete_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_exception_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_exception_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_fail_fn(gearman_client_st\fI\ *client\fP, \fI\%gearman_fail_fn\fP\fI\ *function\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_clear_fn(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_client_do_job_handle(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.sp
-Link to \-lgearman
-.SH DESCRIPTION
-.sp
-Callbacks for client execution task states.
-.sp
-\fI\%gearman_client_set_data_fn()\fP sets the callback function that will
-be called if server is to make a request to the client to provide more data.
-.sp
-\fI\%gearman_client_do_job_handle()\fP gest the job handle for the running task. This should be used between repeated
-\fBgearman_client_do()\fP (and related) calls to get information.
-.sp
-\fI\%gearman_client_clear_fn()\fP can be called to remove all existing
-\fI\%gearman_actions_t\fP that have been set.
-.sp
-\fI\%gearman_client_set_created_fn()\fP,
-\fI\%gearman_client_set_data_fn()\fP,
-\fI\%gearman_client_set_warning_fn()\fP,
-\fI\%gearman_client_set_status_fn()\fP,
-\fI\%gearman_client_set_complete_fn()\fP,
-\fI\%gearman_client_set_exception_fn()\fP, and
-\fI\%gearman_client_set_fail_fn()\fP, set callback functions for the
-different states of execution for a client request. Each request, ie
-a creation of \fBgearman_task_st\fP, keeps a copy of callbacks when it
-is created.
-.sp
-\fI\%gearman_client_set_exception_fn()\fP will only be called if exceptions are enabled on the server. You can do this by calling \fBgearman_client_set_server_option()\fP.
-.sp
-An example of this:
-.sp
-.nf
-.ft C
-const char *EXCEPTIONS="exceptions";
-gearman_client_set_server_option(client, EXCEPTIONS, strlen(EXCEPTIONS));
-.ft P
-.fi
-.SH RETURN VALUE
-.sp
-None
-.IP "See also"
-.RE
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error(3)\fP or \fIgearman_worker_error(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_set_workload_fn.3'
--- docs/man/gearman_client_set_workload_fn.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_set_workload_fn.3	1970-01-01 00:00:00 +0000
@@ -1,115 +0,0 @@
-.TH "GEARMAN_CLIENT_SET_WORKLOAD_FN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_set_workload_fn \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_client_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_client_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_client_context(const \fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_context(\fI\%gearman_client_st\fP\fI\ *client\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_malloc_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_task_free_all(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_task_context_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, \fI\%gearman_task_context_free_fn\fP\fI\ *function\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_st\fP is used for \fIclient\fP communication with the server.
-.sp
-\fI\%gearman_client_context()\fP and \fI\%gearman_client_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_client_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_client_timeout()\fP and \fI\%gearman_client_set_timeout()\fP get and set the current timeout value, in milliseconds, for the client.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_client_set_workload_malloc_fn()\fP and \fI\%gearman_client_set_workload_free_fn()\fP can be used to replace these with custom functions. (These have been deprecated, please see \fBgearman_allocator_t\fP for the updated interface.
-.sp
-\fI\%gearman_client_task_free_all()\fP is used to free all current \fBgearman_task_st\fP that have been created with the \fI\%gearman_client_st\fP.
-.IP Warning
-By calling \fI\%gearman_client_task_free_all()\fP you can end up with a SEGFAULT if you try to use any \fBgearman_task_st\fP that you have kept pointers too.
-.RE
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_timeout()\fP returns an integer representing the amount of time in milliseconds. A value of \-1 means an infinite timeout value. See \fIpoll(3)\fP for more details.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_create(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_set_workload_free_fn.3'
--- docs/man/gearman_client_set_workload_free_fn.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_set_workload_free_fn.3	1970-01-01 00:00:00 +0000
@@ -1,115 +0,0 @@
-.TH "GEARMAN_CLIENT_SET_WORKLOAD_FREE_FN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_set_workload_free_fn \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_client_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_client_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_client_context(const \fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_context(\fI\%gearman_client_st\fP\fI\ *client\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_malloc_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_task_free_all(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_task_context_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, \fI\%gearman_task_context_free_fn\fP\fI\ *function\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_st\fP is used for \fIclient\fP communication with the server.
-.sp
-\fI\%gearman_client_context()\fP and \fI\%gearman_client_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_client_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_client_timeout()\fP and \fI\%gearman_client_set_timeout()\fP get and set the current timeout value, in milliseconds, for the client.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_client_set_workload_malloc_fn()\fP and \fI\%gearman_client_set_workload_free_fn()\fP can be used to replace these with custom functions. (These have been deprecated, please see \fBgearman_allocator_t\fP for the updated interface.
-.sp
-\fI\%gearman_client_task_free_all()\fP is used to free all current \fBgearman_task_st\fP that have been created with the \fI\%gearman_client_st\fP.
-.IP Warning
-By calling \fI\%gearman_client_task_free_all()\fP you can end up with a SEGFAULT if you try to use any \fBgearman_task_st\fP that you have kept pointers too.
-.RE
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_timeout()\fP returns an integer representing the amount of time in milliseconds. A value of \-1 means an infinite timeout value. See \fIpoll(3)\fP for more details.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_create(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_set_workload_malloc_fn.3'
--- docs/man/gearman_client_set_workload_malloc_fn.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_set_workload_malloc_fn.3	1970-01-01 00:00:00 +0000
@@ -1,115 +0,0 @@
-.TH "GEARMAN_CLIENT_SET_WORKLOAD_MALLOC_FN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_set_workload_malloc_fn \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_client_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_client_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_client_context(const \fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_context(\fI\%gearman_client_st\fP\fI\ *client\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_malloc_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_task_free_all(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_task_context_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, \fI\%gearman_task_context_free_fn\fP\fI\ *function\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_st\fP is used for \fIclient\fP communication with the server.
-.sp
-\fI\%gearman_client_context()\fP and \fI\%gearman_client_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_client_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_client_timeout()\fP and \fI\%gearman_client_set_timeout()\fP get and set the current timeout value, in milliseconds, for the client.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_client_set_workload_malloc_fn()\fP and \fI\%gearman_client_set_workload_free_fn()\fP can be used to replace these with custom functions. (These have been deprecated, please see \fBgearman_allocator_t\fP for the updated interface.
-.sp
-\fI\%gearman_client_task_free_all()\fP is used to free all current \fBgearman_task_st\fP that have been created with the \fI\%gearman_client_st\fP.
-.IP Warning
-By calling \fI\%gearman_client_task_free_all()\fP you can end up with a SEGFAULT if you try to use any \fBgearman_task_st\fP that you have kept pointers too.
-.RE
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_timeout()\fP returns an integer representing the amount of time in milliseconds. A value of \-1 means an infinite timeout value. See \fIpoll(3)\fP for more details.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_create(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_st.3'
--- docs/man/gearman_client_st.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_st.3	1970-01-01 00:00:00 +0000
@@ -1,115 +0,0 @@
-.TH "GEARMAN_CLIENT_ST" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_st \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_client_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_client_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_client_context(const \fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_context(\fI\%gearman_client_st\fP\fI\ *client\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_malloc_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_task_free_all(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_task_context_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, \fI\%gearman_task_context_free_fn\fP\fI\ *function\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_st\fP is used for \fIclient\fP communication with the server.
-.sp
-\fI\%gearman_client_context()\fP and \fI\%gearman_client_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_client_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_client_timeout()\fP and \fI\%gearman_client_set_timeout()\fP get and set the current timeout value, in milliseconds, for the client.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_client_set_workload_malloc_fn()\fP and \fI\%gearman_client_set_workload_free_fn()\fP can be used to replace these with custom functions. (These have been deprecated, please see \fBgearman_allocator_t\fP for the updated interface.
-.sp
-\fI\%gearman_client_task_free_all()\fP is used to free all current \fBgearman_task_st\fP that have been created with the \fI\%gearman_client_st\fP.
-.IP Warning
-By calling \fI\%gearman_client_task_free_all()\fP you can end up with a SEGFAULT if you try to use any \fBgearman_task_st\fP that you have kept pointers too.
-.RE
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_timeout()\fP returns an integer representing the amount of time in milliseconds. A value of \-1 means an infinite timeout value. See \fIpoll(3)\fP for more details.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_create(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_task_free_all.3'
--- docs/man/gearman_client_task_free_all.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_task_free_all.3	1970-01-01 00:00:00 +0000
@@ -1,115 +0,0 @@
-.TH "GEARMAN_CLIENT_TASK_FREE_ALL" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_task_free_all \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_client_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_client_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_client_context(const \fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_context(\fI\%gearman_client_st\fP\fI\ *client\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_malloc_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_task_free_all(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_task_context_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, \fI\%gearman_task_context_free_fn\fP\fI\ *function\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_st\fP is used for \fIclient\fP communication with the server.
-.sp
-\fI\%gearman_client_context()\fP and \fI\%gearman_client_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_client_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_client_timeout()\fP and \fI\%gearman_client_set_timeout()\fP get and set the current timeout value, in milliseconds, for the client.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_client_set_workload_malloc_fn()\fP and \fI\%gearman_client_set_workload_free_fn()\fP can be used to replace these with custom functions. (These have been deprecated, please see \fBgearman_allocator_t\fP for the updated interface.
-.sp
-\fI\%gearman_client_task_free_all()\fP is used to free all current \fBgearman_task_st\fP that have been created with the \fI\%gearman_client_st\fP.
-.IP Warning
-By calling \fI\%gearman_client_task_free_all()\fP you can end up with a SEGFAULT if you try to use any \fBgearman_task_st\fP that you have kept pointers too.
-.RE
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_timeout()\fP returns an integer representing the amount of time in milliseconds. A value of \-1 means an infinite timeout value. See \fIpoll(3)\fP for more details.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_create(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_timeout.3'
--- docs/man/gearman_client_timeout.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_timeout.3	1970-01-01 00:00:00 +0000
@@ -1,115 +0,0 @@
-.TH "GEARMAN_CLIENT_TIMEOUT" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_timeout \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_client_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_client_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_timeout(\fI\%gearman_client_st\fP\fI\ *client\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_client_context(const \fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_context(\fI\%gearman_client_st\fP\fI\ *client\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_malloc_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_set_workload_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.23: Use \fBgearman_allocator_t\fP
-.INDENT 0.0
-.TP
-.B void gearman_client_task_free_all(\fI\%gearman_client_st\fP\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_client_set_task_context_free_fn(\fI\%gearman_client_st\fP\fI\ *client\fP, \fI\%gearman_task_context_free_fn\fP\fI\ *function\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_st\fP is used for \fIclient\fP communication with the server.
-.sp
-\fI\%gearman_client_context()\fP and \fI\%gearman_client_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_client_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_client_timeout()\fP and \fI\%gearman_client_set_timeout()\fP get and set the current timeout value, in milliseconds, for the client.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_client_set_workload_malloc_fn()\fP and \fI\%gearman_client_set_workload_free_fn()\fP can be used to replace these with custom functions. (These have been deprecated, please see \fBgearman_allocator_t\fP for the updated interface.
-.sp
-\fI\%gearman_client_task_free_all()\fP is used to free all current \fBgearman_task_st\fP that have been created with the \fI\%gearman_client_st\fP.
-.IP Warning
-By calling \fI\%gearman_client_task_free_all()\fP you can end up with a SEGFAULT if you try to use any \fBgearman_task_st\fP that you have kept pointers too.
-.RE
-.SH RETURN VALUE
-.sp
-\fI\%gearman_client_timeout()\fP returns an integer representing the amount of time in milliseconds. A value of \-1 means an infinite timeout value. See \fIpoll(3)\fP for more details.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_create(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_client_wait.3'
--- docs/man/gearman_client_wait.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_client_wait.3	1970-01-01 00:00:00 +0000
@@ -1,61 +0,0 @@
-.TH "GEARMAN_CLIENT_WAIT" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_client_wait \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_wait(gearman_client_st\fI\ *client\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-Calling \fI\%gearman_client_wait()\fP causes the calling code to sleep until either the timeout in \fBgearman_client_st\fP is reached or \fBgearmand\fP responds to the client.
-.SH RETURN VALUE
-.sp
-\fBgearman_return_t\fP
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_continue.3'
--- docs/man/gearman_continue.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_continue.3	1970-01-01 00:00:00 +0000
@@ -1,339 +0,0 @@
-.TH "GEARMAN_CONTINUE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_continue \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_return_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_strerror(\fI\%gearman_return_t\fP\fI\ rc\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_success(\fI\%gearman_return_t\fP\fI\ rc\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_failed(\fI\%gearman_return_t\fP\fI\ rc\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_continue(\fI\%gearman_return_t\fP\fI\ rc\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_return_t\fP is used as a return/error type for all calls using \fBgearman_client_st\fP and \fBgearman_worker_st\fP.
-\fI\%GEARMAN_SUCCESS\fP is returned upon success, otherwise an error is returned. \fI\%gearman_failed()\fP can be used to see if the return value is a failing value.
-You can print a text version of the error message with \fI\%gearman_strerror()\fP.
-.sp
-\fI\%gearman_success()\fP return true if \fI\%GEARMAN_SUCCESS\fP or if
-\fI\%GEARMAN_NO_PENDING_TASKS\fP tests true.
-.sp
-\fI\%gearman_failed()\fP return true if any value other then \fI\%GEARMAN_SUCCESS\fP was provided.
-.sp
-\fI\%gearman_continue()\fP returns true if any error related to non\-blocking IO
-occurred. This should be used for testing loops.
-.SS Possible values of \fI\%gearman_return_t\fP:
-.INDENT 0.0
-.TP
-.B GEARMAN_SUCCESS
-Success
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_PENDING_TASKS
-\fBgearman_client_run_tasks()\fP was called and it has completed all tasks assigned to the client.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_IO_WAIT
-Blocking IO was found. gearman_continue() can be used to test for this.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_ERRNO
-System error occurred. Use either \fBgearman_client_errno()\fP or \fBgearman_worker_errno()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_ACTIVE_FDS
-No active connections were available.  gearman_continue() can be used to test for this.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_GETADDRINFO
-Name resolution failed for a host.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_SERVERS
-No servers have been provided for the client/worker.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_LOST_CONNECTION
-Connection was lost to the given server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_MEMORY_ALLOCATION_FAILURE
-Memory allocation failed.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_SERVER_ERROR
-An error occurred on the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NOT_CONNECTED
-Client/Worker is not currently connected to the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_COULD_NOT_CONNECT
-Server name was valid, but a connection could not be made.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_ECHO_DATA_CORRUPTION
-Either \fBgearman_client_echo()\fP or \fBgearman_worker_echo()\fP echo
-was unsuccessful because the data was returned from \fBgearmand\fP
-corrupted.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_UNKNOWN_STATE
-The gearman_return_t was never set.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_FLUSH_DATA
-Internal state, should never be seen by either client or worker.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_SEND_BUFFER_TOO_SMALL
-Send buffer was too small.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_TIMEOUT
-A timeout occurred when making a request to the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_ARGUMENT_TOO_LARGE
-Argument was too large for the current buffer.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_ARGUMENT
-One of the arguments to the given API call was invalid. EINVAL will be set if \fBgearman_client_error()\fP or \fBgearman_worker_error()\fP were not settable. This can also be returned if \fBGEARMAN_CLIENT_UNBUFFERED_RESULT\fP was set, but the client is not handling the data correctly.
-.UNINDENT
-.SS CLIENT ONLY
-.INDENT 0.0
-.TP
-.B GEARMAN_NEED_WORKLOAD_FN
-A client was asked for work, but no \fBgearman_workload_fn\fP callback was specified. See \fBgearman_client_set_workload_fn()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_FAIL
-A task has failed, and the worker has exited with an error or it called \fBgearman_job_send_fail()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_IN_PROGRESS
-\fBgearman_client_job_status()\fP has been called for a \fBgearman_job_handle_t\fP and the Job is currently being run by a worker.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_JOB_EXISTS
-\fBgearman_client_job_status()\fP has been called for a \fBgearman_job_handle_t\fP and the Job is currently known by a server, but is not being run by a worker.
-.UNINDENT
-.SS WORKER ONLY
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_FUNCTION_NAME
-A worker was sent a request for a job that it did not have a valid function for.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_WORKER_FUNCTION
-No callback was provided by the worker for a given function.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_REGISTERED_FUNCTION
-A request for removing a given function from a worker was invalid since that function did not exist.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_REGISTERED_FUNCTIONS
-The worker has not registered any functions.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_JOBS
-No jobs were found for the worker.
-.UNINDENT
-.SS WORKER TO CLIENT
-.sp
-Client which have registed a custom \fBgearman_actions_t\fP may use these
-value as return values to the calling client.
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_DATA
-Worker has sent a chunked piece of data to the client via \fBgearman_job_send_data()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_WARNING
-Worker has issued a warning to the client via \fBgearman_job_send_warning()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_STATUS
-Status has been updated by the worker via \fBgearman_job_send_status()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_EXCEPTION
-Worker has sent an exception the client via \fBgearman_job_send_exception()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_FAIL
-A task has failed, and the worker has exited with an error or it called \fBgearman_job_send_fail()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_ERROR
-A task has had an error and will be retried.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_PAUSE
-Used only in custom application for client return based on \fI\%GEARMAN_WORK_DATA\fP, \fI\%GEARMAN_WORK_WARNING\fP, \fI\%GEARMAN_WORK_EXCEPTION\fP, \fI\%GEARMAN_WORK_FAIL\fP, or \fI\%GEARMAN_WORK_STATUS\fP. \fI\%gearman_continue()\fP can be used to check for this value.
-.UNINDENT
-.SS WORKER TO CLIENT
-.sp
-Any function defined by \fBgearman_worker_define_function()\fP may, and can only, return the following \fI\%gearman_return_t\fP values.
-.INDENT 0.0
-.TP
-.B GEARMAN_SUCCESS
-The function successfully completed the job.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_FATAL
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_FAIL
-The function failed to complete the job. \fI\%GEARMAN_FATAL\fP is the deprecated name for \fI\%GEARMAN_FAIL\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_ERROR
-A task has had an error and will be retried.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_SHUTDOWN
-\fI\%GEARMAN_SHUTDOWN\fP is a special case. If it is returned the client will be sent \fI\%GEARMAN_SUCCESS\fP, but \fBgearman_worker_work()\fP will exit with \fI\%GEARMAN_SHUTDOWN\fP.
-.UNINDENT
-.SS TASK ONLY
-.INDENT 0.0
-.TP
-.B GEARMAN_NOT_FLUSHING
-\fBgearman_task_send_workload()\fP failed, it was not in the correct state.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_DATA_TOO_LARGE
-\fBgearman_task_send_workload()\fP failed, the data was too large to be sent.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_UNKNOWN_OPTION
-Default state of task return value.
-.UNINDENT
-.SS PROTOCOL
-.sp
-If any of these errors occurred the connection will be dropped/reset.
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_MAGIC
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_COMMAND
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_PACKET
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_UNEXPECTED_PACKET
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_TOO_MANY_ARGS
-.UNINDENT
-.SS DEPRECATED
-.INDENT 0.0
-.TP
-.B GEARMAN_IGNORE_PACKET
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_MAX_RETURN
-.UNINDENT
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error()\fP or \fIgearman_worker_error()\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_execute.3'
--- docs/man/gearman_execute.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_execute.3	1970-01-01 00:00:00 +0000
@@ -1,144 +0,0 @@
-.TH "GEARMAN_EXECUTE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_execute \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_execute(gearman_client_st\fI\ *client\fP, const char\fI\ *function_name\fP, size_t\fI\ function_name_length\fP, const char\fI\ *unique\fP, size_t\fI\ unique_length\fP, gearman_work_t\fI\ *workload\fP, gearman_argument_t\fI\ *arguments\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_task_st *gearman_execute_by_partition(gearman_client_st\fI\ *client\fP, const char\fI\ *partition_function\fP, const size_t\fI\ partition_function_length\fP, const char\fI\ *function_name\fP, const size_t\fI\ function_name_length\fP, const char\fI\ *unique_str\fP, const size_t\fI\ unique_length\fP, gearman_work_t\fI\ *workload\fP, gearman_argument_t\fI\ *arguments\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_execute()\fP is used to create a new \fBgearman_task_st\fP that is executed against the function that is found via the function_name argument.
-.sp
-\fBgearman_work_t\fP can be used to describe the work that will be
-executed, it is built with \fBgearman_argument_make()\fP.  The argument
-unique_str is optional, but if supplied it is used for coalescence by
-\fBgearmand\fP.
-.sp
-\fBgearman_argument_t\fP is the work that the \fIclient\fP will send
-the to the server
-.sp
-If \fI\%gearman_execute()\fP is given a \fBgearman_work_t\fP that has been built with a reducer, it takes the \fBgearman_argument_t\fP and executs it against a \fIfunction\fP as it normally would, but it tells the function to then process the results through a \fIreducer\fP function that the \fBgearman_work_t\fP was created with.
-.sp
-What is happening is that the function is mappping/splitting work up into units, and then sending each of them to the reducer function. Once all work is completed, the \fImapper\fP function will aggregate the work via an aggregator function, \fBgearman_aggregator_fn\fP, and return a result.
-.sp
-If any of the units of work error, the job will be aborted. The resulting value will be stored in the \fBgearman_task_st\fP.
-.sp
-The result can be obtained from the task by calling
-\fBgearman_task_result()\fP to gain the \fBgearman_result_st\fP.
-.SH RETURN VALUE
-.sp
-\fI\%gearman_execute()\fP returns a c:type:\fIgearman_task_st\fP.
-.SH EXAMPLE
-.sp
-.nf
-.ft C
-/*
-  Example code to show how to send a string to a function called "reverse" and print the results.
-*/
-
-/*
-# Gearman server and library
-# Copyright (C) 2012 Data Differential, http://datadifferential.com/
-# All rights reserved.
-#
-# Use and distribution licensed under the BSD license.  See
-# the COPYING file in this directory for full text.
-*/
-
-#include <string.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <libgearman/gearman.h>
-
-int main(void)
-{
-  gearman_client_st *client= gearman_client_create(NULL);
-
-  gearman_return_t ret= gearman_client_add_server(client, "localhost", 0);
-  if (gearman_failed(ret))
-  {
-    return EXIT_FAILURE;
-  }
-
-  gearman_argument_t value= gearman_argument_make(0, 0, "Reverse Me", strlen("Reverse Me"));
-
-  gearman_task_st *task= gearman_execute(client, 
-                                         "reverse", strlen("reverse"),  // function
-                                         NULL, 0,  // no unique value provided
-                                         NULL, 
-                                         &value, 0);
-
-  if (task == NULL) // If gearman_execute() can return NULL on error
-  {
-    fprintf(stderr, "Error: %s\en", gearman_client_error(client));
-    gearman_client_free(client);
-    return EXIT_FAILURE;
-  }
-
-  // Make sure the task was run successfully
-  if (gearman_success(gearman_task_return(task)))
-  {
-    // Make use of value
-    gearman_result_st *result= gearman_task_result(task);
-    printf("%.*s\en", (int)gearman_result_size(result), gearman_result_value(result));
-  }
-
-  gearman_client_free(client);
-
-  return EXIT_SUCCESS;
-}
-
-.ft P
-.fi
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_failed.3'
--- docs/man/gearman_failed.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_failed.3	1970-01-01 00:00:00 +0000
@@ -1,339 +0,0 @@
-.TH "GEARMAN_FAILED" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_failed \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_return_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_strerror(\fI\%gearman_return_t\fP\fI\ rc\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_success(\fI\%gearman_return_t\fP\fI\ rc\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_failed(\fI\%gearman_return_t\fP\fI\ rc\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_continue(\fI\%gearman_return_t\fP\fI\ rc\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_return_t\fP is used as a return/error type for all calls using \fBgearman_client_st\fP and \fBgearman_worker_st\fP.
-\fI\%GEARMAN_SUCCESS\fP is returned upon success, otherwise an error is returned. \fI\%gearman_failed()\fP can be used to see if the return value is a failing value.
-You can print a text version of the error message with \fI\%gearman_strerror()\fP.
-.sp
-\fI\%gearman_success()\fP return true if \fI\%GEARMAN_SUCCESS\fP or if
-\fI\%GEARMAN_NO_PENDING_TASKS\fP tests true.
-.sp
-\fI\%gearman_failed()\fP return true if any value other then \fI\%GEARMAN_SUCCESS\fP was provided.
-.sp
-\fI\%gearman_continue()\fP returns true if any error related to non\-blocking IO
-occurred. This should be used for testing loops.
-.SS Possible values of \fI\%gearman_return_t\fP:
-.INDENT 0.0
-.TP
-.B GEARMAN_SUCCESS
-Success
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_PENDING_TASKS
-\fBgearman_client_run_tasks()\fP was called and it has completed all tasks assigned to the client.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_IO_WAIT
-Blocking IO was found. gearman_continue() can be used to test for this.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_ERRNO
-System error occurred. Use either \fBgearman_client_errno()\fP or \fBgearman_worker_errno()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_ACTIVE_FDS
-No active connections were available.  gearman_continue() can be used to test for this.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_GETADDRINFO
-Name resolution failed for a host.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_SERVERS
-No servers have been provided for the client/worker.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_LOST_CONNECTION
-Connection was lost to the given server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_MEMORY_ALLOCATION_FAILURE
-Memory allocation failed.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_SERVER_ERROR
-An error occurred on the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NOT_CONNECTED
-Client/Worker is not currently connected to the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_COULD_NOT_CONNECT
-Server name was valid, but a connection could not be made.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_ECHO_DATA_CORRUPTION
-Either \fBgearman_client_echo()\fP or \fBgearman_worker_echo()\fP echo
-was unsuccessful because the data was returned from \fBgearmand\fP
-corrupted.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_UNKNOWN_STATE
-The gearman_return_t was never set.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_FLUSH_DATA
-Internal state, should never be seen by either client or worker.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_SEND_BUFFER_TOO_SMALL
-Send buffer was too small.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_TIMEOUT
-A timeout occurred when making a request to the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_ARGUMENT_TOO_LARGE
-Argument was too large for the current buffer.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_ARGUMENT
-One of the arguments to the given API call was invalid. EINVAL will be set if \fBgearman_client_error()\fP or \fBgearman_worker_error()\fP were not settable. This can also be returned if \fBGEARMAN_CLIENT_UNBUFFERED_RESULT\fP was set, but the client is not handling the data correctly.
-.UNINDENT
-.SS CLIENT ONLY
-.INDENT 0.0
-.TP
-.B GEARMAN_NEED_WORKLOAD_FN
-A client was asked for work, but no \fBgearman_workload_fn\fP callback was specified. See \fBgearman_client_set_workload_fn()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_FAIL
-A task has failed, and the worker has exited with an error or it called \fBgearman_job_send_fail()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_IN_PROGRESS
-\fBgearman_client_job_status()\fP has been called for a \fBgearman_job_handle_t\fP and the Job is currently being run by a worker.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_JOB_EXISTS
-\fBgearman_client_job_status()\fP has been called for a \fBgearman_job_handle_t\fP and the Job is currently known by a server, but is not being run by a worker.
-.UNINDENT
-.SS WORKER ONLY
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_FUNCTION_NAME
-A worker was sent a request for a job that it did not have a valid function for.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_WORKER_FUNCTION
-No callback was provided by the worker for a given function.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_REGISTERED_FUNCTION
-A request for removing a given function from a worker was invalid since that function did not exist.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_REGISTERED_FUNCTIONS
-The worker has not registered any functions.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_JOBS
-No jobs were found for the worker.
-.UNINDENT
-.SS WORKER TO CLIENT
-.sp
-Client which have registed a custom \fBgearman_actions_t\fP may use these
-value as return values to the calling client.
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_DATA
-Worker has sent a chunked piece of data to the client via \fBgearman_job_send_data()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_WARNING
-Worker has issued a warning to the client via \fBgearman_job_send_warning()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_STATUS
-Status has been updated by the worker via \fBgearman_job_send_status()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_EXCEPTION
-Worker has sent an exception the client via \fBgearman_job_send_exception()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_FAIL
-A task has failed, and the worker has exited with an error or it called \fBgearman_job_send_fail()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_ERROR
-A task has had an error and will be retried.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_PAUSE
-Used only in custom application for client return based on \fI\%GEARMAN_WORK_DATA\fP, \fI\%GEARMAN_WORK_WARNING\fP, \fI\%GEARMAN_WORK_EXCEPTION\fP, \fI\%GEARMAN_WORK_FAIL\fP, or \fI\%GEARMAN_WORK_STATUS\fP. \fI\%gearman_continue()\fP can be used to check for this value.
-.UNINDENT
-.SS WORKER TO CLIENT
-.sp
-Any function defined by \fBgearman_worker_define_function()\fP may, and can only, return the following \fI\%gearman_return_t\fP values.
-.INDENT 0.0
-.TP
-.B GEARMAN_SUCCESS
-The function successfully completed the job.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_FATAL
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_FAIL
-The function failed to complete the job. \fI\%GEARMAN_FATAL\fP is the deprecated name for \fI\%GEARMAN_FAIL\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_ERROR
-A task has had an error and will be retried.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_SHUTDOWN
-\fI\%GEARMAN_SHUTDOWN\fP is a special case. If it is returned the client will be sent \fI\%GEARMAN_SUCCESS\fP, but \fBgearman_worker_work()\fP will exit with \fI\%GEARMAN_SHUTDOWN\fP.
-.UNINDENT
-.SS TASK ONLY
-.INDENT 0.0
-.TP
-.B GEARMAN_NOT_FLUSHING
-\fBgearman_task_send_workload()\fP failed, it was not in the correct state.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_DATA_TOO_LARGE
-\fBgearman_task_send_workload()\fP failed, the data was too large to be sent.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_UNKNOWN_OPTION
-Default state of task return value.
-.UNINDENT
-.SS PROTOCOL
-.sp
-If any of these errors occurred the connection will be dropped/reset.
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_MAGIC
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_COMMAND
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_PACKET
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_UNEXPECTED_PACKET
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_TOO_MANY_ARGS
-.UNINDENT
-.SS DEPRECATED
-.INDENT 0.0
-.TP
-.B GEARMAN_IGNORE_PACKET
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_MAX_RETURN
-.UNINDENT
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error()\fP or \fIgearman_worker_error()\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_job_free.3'
--- docs/man/gearman_job_free.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_job_free.3	1970-01-01 00:00:00 +0000
@@ -1,129 +0,0 @@
-.TH "GEARMAN_JOB_FREE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_job_free \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_job_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_data(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *data\fP, size_t\fI\ data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_warning(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *warning\fP, size_t\fI\ warning_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_status(\fI\%gearman_job_st\fP\fI\ *job\fP, uint32_t\fI\ numerator\fP, uint32_t\fI\ denominator\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_complete(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *result\fP, size_t\fI\ result_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_exception(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *exception\fP, size_t\fI\ exception_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_fail(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_handle(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_function_name(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_unique(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_job_workload(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_job_workload_size(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_job_take_workload(\fI\%gearman_job_st\fP\fI\ *job\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_job_st\fP are passed to worker functions to represent jobs that are being run by \fBgearman_worker_work()\fP.
-.sp
-\fI\%gearman_job_free()\fP is used to free a job. This only needs to be
-done if a task was created with a preallocated structure.
-.sp
-\fI\%gearman_job_handle()\fP returns the job handle(see \fBgearman_job_handle_t\fP for more information).
-.sp
-\fI\%gearman_job_function_name()\fP return the name of the function that the
-job was set to execute against.
-.sp
-\fI\%gearman_job_unique()\fP return the unique value that was used for \fI\%gearman_job_st\fP.
-.sp
-returns the \fI\%gearman_job_st\fP workload. The size of it can be determined with \fI\%gearman_job_workload_size()\fP.
-\fI\%gearman_job_take_workload()\fP is the same as \fI\%gearman_job_workload()\fP with the exception that the result must be
-\fIfree(3)\fP by the caller.
-.SH RETURN VALUE
-.sp
-A value of \fBgearman_return_t\fP  is returned.  On success that value
-will be :c:type::\fIGEARMAN_SUCCESS\fP.  Use \fBgearman_strerror()\fP to
-translate this value to a printable string.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_job_free_all.3'
--- docs/man/gearman_job_free_all.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_job_free_all.3	1970-01-01 00:00:00 +0000
@@ -1,129 +0,0 @@
-.TH "GEARMAN_JOB_FREE_ALL" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_job_free_all \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_job_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_data(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *data\fP, size_t\fI\ data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_warning(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *warning\fP, size_t\fI\ warning_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_status(\fI\%gearman_job_st\fP\fI\ *job\fP, uint32_t\fI\ numerator\fP, uint32_t\fI\ denominator\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_complete(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *result\fP, size_t\fI\ result_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_exception(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *exception\fP, size_t\fI\ exception_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_fail(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_handle(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_function_name(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_unique(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_job_workload(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_job_workload_size(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_job_take_workload(\fI\%gearman_job_st\fP\fI\ *job\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_job_st\fP are passed to worker functions to represent jobs that are being run by \fBgearman_worker_work()\fP.
-.sp
-\fI\%gearman_job_free()\fP is used to free a job. This only needs to be
-done if a task was created with a preallocated structure.
-.sp
-\fI\%gearman_job_handle()\fP returns the job handle(see \fBgearman_job_handle_t\fP for more information).
-.sp
-\fI\%gearman_job_function_name()\fP return the name of the function that the
-job was set to execute against.
-.sp
-\fI\%gearman_job_unique()\fP return the unique value that was used for \fI\%gearman_job_st\fP.
-.sp
-returns the \fI\%gearman_job_st\fP workload. The size of it can be determined with \fI\%gearman_job_workload_size()\fP.
-\fI\%gearman_job_take_workload()\fP is the same as \fI\%gearman_job_workload()\fP with the exception that the result must be
-\fIfree(3)\fP by the caller.
-.SH RETURN VALUE
-.sp
-A value of \fBgearman_return_t\fP  is returned.  On success that value
-will be :c:type::\fIGEARMAN_SUCCESS\fP.  Use \fBgearman_strerror()\fP to
-translate this value to a printable string.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_job_function_name.3'
--- docs/man/gearman_job_function_name.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_job_function_name.3	1970-01-01 00:00:00 +0000
@@ -1,129 +0,0 @@
-.TH "GEARMAN_JOB_FUNCTION_NAME" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_job_function_name \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_job_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_data(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *data\fP, size_t\fI\ data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_warning(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *warning\fP, size_t\fI\ warning_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_status(\fI\%gearman_job_st\fP\fI\ *job\fP, uint32_t\fI\ numerator\fP, uint32_t\fI\ denominator\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_complete(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *result\fP, size_t\fI\ result_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_exception(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *exception\fP, size_t\fI\ exception_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_fail(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_handle(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_function_name(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_unique(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_job_workload(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_job_workload_size(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_job_take_workload(\fI\%gearman_job_st\fP\fI\ *job\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_job_st\fP are passed to worker functions to represent jobs that are being run by \fBgearman_worker_work()\fP.
-.sp
-\fI\%gearman_job_free()\fP is used to free a job. This only needs to be
-done if a task was created with a preallocated structure.
-.sp
-\fI\%gearman_job_handle()\fP returns the job handle(see \fBgearman_job_handle_t\fP for more information).
-.sp
-\fI\%gearman_job_function_name()\fP return the name of the function that the
-job was set to execute against.
-.sp
-\fI\%gearman_job_unique()\fP return the unique value that was used for \fI\%gearman_job_st\fP.
-.sp
-returns the \fI\%gearman_job_st\fP workload. The size of it can be determined with \fI\%gearman_job_workload_size()\fP.
-\fI\%gearman_job_take_workload()\fP is the same as \fI\%gearman_job_workload()\fP with the exception that the result must be
-\fIfree(3)\fP by the caller.
-.SH RETURN VALUE
-.sp
-A value of \fBgearman_return_t\fP  is returned.  On success that value
-will be :c:type::\fIGEARMAN_SUCCESS\fP.  Use \fBgearman_strerror()\fP to
-translate this value to a printable string.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_job_handle.3'
--- docs/man/gearman_job_handle.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_job_handle.3	1970-01-01 00:00:00 +0000
@@ -1,129 +0,0 @@
-.TH "GEARMAN_JOB_HANDLE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_job_handle \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_job_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_data(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *data\fP, size_t\fI\ data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_warning(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *warning\fP, size_t\fI\ warning_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_status(\fI\%gearman_job_st\fP\fI\ *job\fP, uint32_t\fI\ numerator\fP, uint32_t\fI\ denominator\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_complete(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *result\fP, size_t\fI\ result_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_exception(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *exception\fP, size_t\fI\ exception_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_fail(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_handle(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_function_name(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_unique(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_job_workload(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_job_workload_size(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_job_take_workload(\fI\%gearman_job_st\fP\fI\ *job\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_job_st\fP are passed to worker functions to represent jobs that are being run by \fBgearman_worker_work()\fP.
-.sp
-\fI\%gearman_job_free()\fP is used to free a job. This only needs to be
-done if a task was created with a preallocated structure.
-.sp
-\fI\%gearman_job_handle()\fP returns the job handle(see \fBgearman_job_handle_t\fP for more information).
-.sp
-\fI\%gearman_job_function_name()\fP return the name of the function that the
-job was set to execute against.
-.sp
-\fI\%gearman_job_unique()\fP return the unique value that was used for \fI\%gearman_job_st\fP.
-.sp
-returns the \fI\%gearman_job_st\fP workload. The size of it can be determined with \fI\%gearman_job_workload_size()\fP.
-\fI\%gearman_job_take_workload()\fP is the same as \fI\%gearman_job_workload()\fP with the exception that the result must be
-\fIfree(3)\fP by the caller.
-.SH RETURN VALUE
-.sp
-A value of \fBgearman_return_t\fP  is returned.  On success that value
-will be :c:type::\fIGEARMAN_SUCCESS\fP.  Use \fBgearman_strerror()\fP to
-translate this value to a printable string.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_job_handle_t.3'
--- docs/man/gearman_job_handle_t.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_job_handle_t.3	1970-01-01 00:00:00 +0000
@@ -1,64 +0,0 @@
-.TH "GEARMAN_JOB_HANDLE_T" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_job_handle_t \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_job_handle_t
-.UNINDENT
-.SH DESCRIPTION
-.sp
-A \fI\%gearman_job_handle_t\fP represents a "job handle". A job handle is
-a text string that represents the name of a task (in truth
-gearman_job_handle_t is a typedef\(aqed
-char[\fBGEARMAN_JOB_HANDLE_SIZE\fP]).
-.sp
-\fBgearman_client_job_status()\fP use handles to find the status of tasks. When passed to \fBgearman_client_do_background()\fP it will be populated with the job handle.
-.SH RETURN VALUE
-.sp
-None.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fBgearman_job_st\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_job_send_complete.3'
--- docs/man/gearman_job_send_complete.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_job_send_complete.3	1970-01-01 00:00:00 +0000
@@ -1,129 +0,0 @@
-.TH "GEARMAN_JOB_SEND_COMPLETE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_job_send_complete \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_job_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_data(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *data\fP, size_t\fI\ data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_warning(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *warning\fP, size_t\fI\ warning_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_status(\fI\%gearman_job_st\fP\fI\ *job\fP, uint32_t\fI\ numerator\fP, uint32_t\fI\ denominator\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_complete(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *result\fP, size_t\fI\ result_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_exception(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *exception\fP, size_t\fI\ exception_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_fail(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_handle(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_function_name(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_unique(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_job_workload(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_job_workload_size(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_job_take_workload(\fI\%gearman_job_st\fP\fI\ *job\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_job_st\fP are passed to worker functions to represent jobs that are being run by \fBgearman_worker_work()\fP.
-.sp
-\fI\%gearman_job_free()\fP is used to free a job. This only needs to be
-done if a task was created with a preallocated structure.
-.sp
-\fI\%gearman_job_handle()\fP returns the job handle(see \fBgearman_job_handle_t\fP for more information).
-.sp
-\fI\%gearman_job_function_name()\fP return the name of the function that the
-job was set to execute against.
-.sp
-\fI\%gearman_job_unique()\fP return the unique value that was used for \fI\%gearman_job_st\fP.
-.sp
-returns the \fI\%gearman_job_st\fP workload. The size of it can be determined with \fI\%gearman_job_workload_size()\fP.
-\fI\%gearman_job_take_workload()\fP is the same as \fI\%gearman_job_workload()\fP with the exception that the result must be
-\fIfree(3)\fP by the caller.
-.SH RETURN VALUE
-.sp
-A value of \fBgearman_return_t\fP  is returned.  On success that value
-will be :c:type::\fIGEARMAN_SUCCESS\fP.  Use \fBgearman_strerror()\fP to
-translate this value to a printable string.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_job_send_data.3'
--- docs/man/gearman_job_send_data.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_job_send_data.3	1970-01-01 00:00:00 +0000
@@ -1,129 +0,0 @@
-.TH "GEARMAN_JOB_SEND_DATA" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_job_send_data \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_job_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_data(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *data\fP, size_t\fI\ data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_warning(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *warning\fP, size_t\fI\ warning_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_status(\fI\%gearman_job_st\fP\fI\ *job\fP, uint32_t\fI\ numerator\fP, uint32_t\fI\ denominator\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_complete(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *result\fP, size_t\fI\ result_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_exception(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *exception\fP, size_t\fI\ exception_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_fail(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_handle(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_function_name(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_unique(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_job_workload(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_job_workload_size(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_job_take_workload(\fI\%gearman_job_st\fP\fI\ *job\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_job_st\fP are passed to worker functions to represent jobs that are being run by \fBgearman_worker_work()\fP.
-.sp
-\fI\%gearman_job_free()\fP is used to free a job. This only needs to be
-done if a task was created with a preallocated structure.
-.sp
-\fI\%gearman_job_handle()\fP returns the job handle(see \fBgearman_job_handle_t\fP for more information).
-.sp
-\fI\%gearman_job_function_name()\fP return the name of the function that the
-job was set to execute against.
-.sp
-\fI\%gearman_job_unique()\fP return the unique value that was used for \fI\%gearman_job_st\fP.
-.sp
-returns the \fI\%gearman_job_st\fP workload. The size of it can be determined with \fI\%gearman_job_workload_size()\fP.
-\fI\%gearman_job_take_workload()\fP is the same as \fI\%gearman_job_workload()\fP with the exception that the result must be
-\fIfree(3)\fP by the caller.
-.SH RETURN VALUE
-.sp
-A value of \fBgearman_return_t\fP  is returned.  On success that value
-will be :c:type::\fIGEARMAN_SUCCESS\fP.  Use \fBgearman_strerror()\fP to
-translate this value to a printable string.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_job_send_exception.3'
--- docs/man/gearman_job_send_exception.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_job_send_exception.3	1970-01-01 00:00:00 +0000
@@ -1,129 +0,0 @@
-.TH "GEARMAN_JOB_SEND_EXCEPTION" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_job_send_exception \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_job_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_data(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *data\fP, size_t\fI\ data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_warning(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *warning\fP, size_t\fI\ warning_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_status(\fI\%gearman_job_st\fP\fI\ *job\fP, uint32_t\fI\ numerator\fP, uint32_t\fI\ denominator\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_complete(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *result\fP, size_t\fI\ result_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_exception(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *exception\fP, size_t\fI\ exception_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_fail(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_handle(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_function_name(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_unique(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_job_workload(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_job_workload_size(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_job_take_workload(\fI\%gearman_job_st\fP\fI\ *job\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_job_st\fP are passed to worker functions to represent jobs that are being run by \fBgearman_worker_work()\fP.
-.sp
-\fI\%gearman_job_free()\fP is used to free a job. This only needs to be
-done if a task was created with a preallocated structure.
-.sp
-\fI\%gearman_job_handle()\fP returns the job handle(see \fBgearman_job_handle_t\fP for more information).
-.sp
-\fI\%gearman_job_function_name()\fP return the name of the function that the
-job was set to execute against.
-.sp
-\fI\%gearman_job_unique()\fP return the unique value that was used for \fI\%gearman_job_st\fP.
-.sp
-returns the \fI\%gearman_job_st\fP workload. The size of it can be determined with \fI\%gearman_job_workload_size()\fP.
-\fI\%gearman_job_take_workload()\fP is the same as \fI\%gearman_job_workload()\fP with the exception that the result must be
-\fIfree(3)\fP by the caller.
-.SH RETURN VALUE
-.sp
-A value of \fBgearman_return_t\fP  is returned.  On success that value
-will be :c:type::\fIGEARMAN_SUCCESS\fP.  Use \fBgearman_strerror()\fP to
-translate this value to a printable string.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_job_send_fail.3'
--- docs/man/gearman_job_send_fail.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_job_send_fail.3	1970-01-01 00:00:00 +0000
@@ -1,129 +0,0 @@
-.TH "GEARMAN_JOB_SEND_FAIL" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_job_send_fail \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_job_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_data(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *data\fP, size_t\fI\ data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_warning(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *warning\fP, size_t\fI\ warning_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_status(\fI\%gearman_job_st\fP\fI\ *job\fP, uint32_t\fI\ numerator\fP, uint32_t\fI\ denominator\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_complete(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *result\fP, size_t\fI\ result_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_exception(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *exception\fP, size_t\fI\ exception_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_fail(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_handle(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_function_name(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_unique(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_job_workload(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_job_workload_size(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_job_take_workload(\fI\%gearman_job_st\fP\fI\ *job\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_job_st\fP are passed to worker functions to represent jobs that are being run by \fBgearman_worker_work()\fP.
-.sp
-\fI\%gearman_job_free()\fP is used to free a job. This only needs to be
-done if a task was created with a preallocated structure.
-.sp
-\fI\%gearman_job_handle()\fP returns the job handle(see \fBgearman_job_handle_t\fP for more information).
-.sp
-\fI\%gearman_job_function_name()\fP return the name of the function that the
-job was set to execute against.
-.sp
-\fI\%gearman_job_unique()\fP return the unique value that was used for \fI\%gearman_job_st\fP.
-.sp
-returns the \fI\%gearman_job_st\fP workload. The size of it can be determined with \fI\%gearman_job_workload_size()\fP.
-\fI\%gearman_job_take_workload()\fP is the same as \fI\%gearman_job_workload()\fP with the exception that the result must be
-\fIfree(3)\fP by the caller.
-.SH RETURN VALUE
-.sp
-A value of \fBgearman_return_t\fP  is returned.  On success that value
-will be :c:type::\fIGEARMAN_SUCCESS\fP.  Use \fBgearman_strerror()\fP to
-translate this value to a printable string.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_job_send_status.3'
--- docs/man/gearman_job_send_status.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_job_send_status.3	1970-01-01 00:00:00 +0000
@@ -1,129 +0,0 @@
-.TH "GEARMAN_JOB_SEND_STATUS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_job_send_status \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_job_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_data(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *data\fP, size_t\fI\ data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_warning(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *warning\fP, size_t\fI\ warning_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_status(\fI\%gearman_job_st\fP\fI\ *job\fP, uint32_t\fI\ numerator\fP, uint32_t\fI\ denominator\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_complete(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *result\fP, size_t\fI\ result_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_exception(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *exception\fP, size_t\fI\ exception_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_fail(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_handle(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_function_name(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_unique(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_job_workload(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_job_workload_size(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_job_take_workload(\fI\%gearman_job_st\fP\fI\ *job\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_job_st\fP are passed to worker functions to represent jobs that are being run by \fBgearman_worker_work()\fP.
-.sp
-\fI\%gearman_job_free()\fP is used to free a job. This only needs to be
-done if a task was created with a preallocated structure.
-.sp
-\fI\%gearman_job_handle()\fP returns the job handle(see \fBgearman_job_handle_t\fP for more information).
-.sp
-\fI\%gearman_job_function_name()\fP return the name of the function that the
-job was set to execute against.
-.sp
-\fI\%gearman_job_unique()\fP return the unique value that was used for \fI\%gearman_job_st\fP.
-.sp
-returns the \fI\%gearman_job_st\fP workload. The size of it can be determined with \fI\%gearman_job_workload_size()\fP.
-\fI\%gearman_job_take_workload()\fP is the same as \fI\%gearman_job_workload()\fP with the exception that the result must be
-\fIfree(3)\fP by the caller.
-.SH RETURN VALUE
-.sp
-A value of \fBgearman_return_t\fP  is returned.  On success that value
-will be :c:type::\fIGEARMAN_SUCCESS\fP.  Use \fBgearman_strerror()\fP to
-translate this value to a printable string.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_job_send_warning.3'
--- docs/man/gearman_job_send_warning.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_job_send_warning.3	1970-01-01 00:00:00 +0000
@@ -1,129 +0,0 @@
-.TH "GEARMAN_JOB_SEND_WARNING" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_job_send_warning \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_job_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_data(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *data\fP, size_t\fI\ data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_warning(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *warning\fP, size_t\fI\ warning_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_status(\fI\%gearman_job_st\fP\fI\ *job\fP, uint32_t\fI\ numerator\fP, uint32_t\fI\ denominator\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_complete(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *result\fP, size_t\fI\ result_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_exception(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *exception\fP, size_t\fI\ exception_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_fail(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_handle(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_function_name(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_unique(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_job_workload(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_job_workload_size(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_job_take_workload(\fI\%gearman_job_st\fP\fI\ *job\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_job_st\fP are passed to worker functions to represent jobs that are being run by \fBgearman_worker_work()\fP.
-.sp
-\fI\%gearman_job_free()\fP is used to free a job. This only needs to be
-done if a task was created with a preallocated structure.
-.sp
-\fI\%gearman_job_handle()\fP returns the job handle(see \fBgearman_job_handle_t\fP for more information).
-.sp
-\fI\%gearman_job_function_name()\fP return the name of the function that the
-job was set to execute against.
-.sp
-\fI\%gearman_job_unique()\fP return the unique value that was used for \fI\%gearman_job_st\fP.
-.sp
-returns the \fI\%gearman_job_st\fP workload. The size of it can be determined with \fI\%gearman_job_workload_size()\fP.
-\fI\%gearman_job_take_workload()\fP is the same as \fI\%gearman_job_workload()\fP with the exception that the result must be
-\fIfree(3)\fP by the caller.
-.SH RETURN VALUE
-.sp
-A value of \fBgearman_return_t\fP  is returned.  On success that value
-will be :c:type::\fIGEARMAN_SUCCESS\fP.  Use \fBgearman_strerror()\fP to
-translate this value to a printable string.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_job_st.3'
--- docs/man/gearman_job_st.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_job_st.3	1970-01-01 00:00:00 +0000
@@ -1,129 +0,0 @@
-.TH "GEARMAN_JOB_ST" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_job_st \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_job_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_data(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *data\fP, size_t\fI\ data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_warning(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *warning\fP, size_t\fI\ warning_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_status(\fI\%gearman_job_st\fP\fI\ *job\fP, uint32_t\fI\ numerator\fP, uint32_t\fI\ denominator\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_complete(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *result\fP, size_t\fI\ result_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_exception(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *exception\fP, size_t\fI\ exception_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_fail(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_handle(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_function_name(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_unique(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_job_workload(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_job_workload_size(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_job_take_workload(\fI\%gearman_job_st\fP\fI\ *job\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_job_st\fP are passed to worker functions to represent jobs that are being run by \fBgearman_worker_work()\fP.
-.sp
-\fI\%gearman_job_free()\fP is used to free a job. This only needs to be
-done if a task was created with a preallocated structure.
-.sp
-\fI\%gearman_job_handle()\fP returns the job handle(see \fBgearman_job_handle_t\fP for more information).
-.sp
-\fI\%gearman_job_function_name()\fP return the name of the function that the
-job was set to execute against.
-.sp
-\fI\%gearman_job_unique()\fP return the unique value that was used for \fI\%gearman_job_st\fP.
-.sp
-returns the \fI\%gearman_job_st\fP workload. The size of it can be determined with \fI\%gearman_job_workload_size()\fP.
-\fI\%gearman_job_take_workload()\fP is the same as \fI\%gearman_job_workload()\fP with the exception that the result must be
-\fIfree(3)\fP by the caller.
-.SH RETURN VALUE
-.sp
-A value of \fBgearman_return_t\fP  is returned.  On success that value
-will be :c:type::\fIGEARMAN_SUCCESS\fP.  Use \fBgearman_strerror()\fP to
-translate this value to a printable string.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_job_take_workload.3'
--- docs/man/gearman_job_take_workload.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_job_take_workload.3	1970-01-01 00:00:00 +0000
@@ -1,129 +0,0 @@
-.TH "GEARMAN_JOB_TAKE_WORKLOAD" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_job_take_workload \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_job_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_data(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *data\fP, size_t\fI\ data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_warning(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *warning\fP, size_t\fI\ warning_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_status(\fI\%gearman_job_st\fP\fI\ *job\fP, uint32_t\fI\ numerator\fP, uint32_t\fI\ denominator\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_complete(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *result\fP, size_t\fI\ result_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_exception(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *exception\fP, size_t\fI\ exception_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_fail(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_handle(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_function_name(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_unique(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_job_workload(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_job_workload_size(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_job_take_workload(\fI\%gearman_job_st\fP\fI\ *job\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_job_st\fP are passed to worker functions to represent jobs that are being run by \fBgearman_worker_work()\fP.
-.sp
-\fI\%gearman_job_free()\fP is used to free a job. This only needs to be
-done if a task was created with a preallocated structure.
-.sp
-\fI\%gearman_job_handle()\fP returns the job handle(see \fBgearman_job_handle_t\fP for more information).
-.sp
-\fI\%gearman_job_function_name()\fP return the name of the function that the
-job was set to execute against.
-.sp
-\fI\%gearman_job_unique()\fP return the unique value that was used for \fI\%gearman_job_st\fP.
-.sp
-returns the \fI\%gearman_job_st\fP workload. The size of it can be determined with \fI\%gearman_job_workload_size()\fP.
-\fI\%gearman_job_take_workload()\fP is the same as \fI\%gearman_job_workload()\fP with the exception that the result must be
-\fIfree(3)\fP by the caller.
-.SH RETURN VALUE
-.sp
-A value of \fBgearman_return_t\fP  is returned.  On success that value
-will be :c:type::\fIGEARMAN_SUCCESS\fP.  Use \fBgearman_strerror()\fP to
-translate this value to a printable string.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_job_unique.3'
--- docs/man/gearman_job_unique.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_job_unique.3	1970-01-01 00:00:00 +0000
@@ -1,129 +0,0 @@
-.TH "GEARMAN_JOB_UNIQUE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_job_unique \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_job_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_data(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *data\fP, size_t\fI\ data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_warning(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *warning\fP, size_t\fI\ warning_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_status(\fI\%gearman_job_st\fP\fI\ *job\fP, uint32_t\fI\ numerator\fP, uint32_t\fI\ denominator\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_complete(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *result\fP, size_t\fI\ result_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_exception(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *exception\fP, size_t\fI\ exception_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_fail(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_handle(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_function_name(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_unique(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_job_workload(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_job_workload_size(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_job_take_workload(\fI\%gearman_job_st\fP\fI\ *job\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_job_st\fP are passed to worker functions to represent jobs that are being run by \fBgearman_worker_work()\fP.
-.sp
-\fI\%gearman_job_free()\fP is used to free a job. This only needs to be
-done if a task was created with a preallocated structure.
-.sp
-\fI\%gearman_job_handle()\fP returns the job handle(see \fBgearman_job_handle_t\fP for more information).
-.sp
-\fI\%gearman_job_function_name()\fP return the name of the function that the
-job was set to execute against.
-.sp
-\fI\%gearman_job_unique()\fP return the unique value that was used for \fI\%gearman_job_st\fP.
-.sp
-returns the \fI\%gearman_job_st\fP workload. The size of it can be determined with \fI\%gearman_job_workload_size()\fP.
-\fI\%gearman_job_take_workload()\fP is the same as \fI\%gearman_job_workload()\fP with the exception that the result must be
-\fIfree(3)\fP by the caller.
-.SH RETURN VALUE
-.sp
-A value of \fBgearman_return_t\fP  is returned.  On success that value
-will be :c:type::\fIGEARMAN_SUCCESS\fP.  Use \fBgearman_strerror()\fP to
-translate this value to a printable string.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_job_workload.3'
--- docs/man/gearman_job_workload.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_job_workload.3	1970-01-01 00:00:00 +0000
@@ -1,129 +0,0 @@
-.TH "GEARMAN_JOB_WORKLOAD" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_job_workload \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_job_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_data(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *data\fP, size_t\fI\ data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_warning(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *warning\fP, size_t\fI\ warning_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_status(\fI\%gearman_job_st\fP\fI\ *job\fP, uint32_t\fI\ numerator\fP, uint32_t\fI\ denominator\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_complete(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *result\fP, size_t\fI\ result_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_exception(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *exception\fP, size_t\fI\ exception_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_fail(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_handle(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_function_name(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_unique(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_job_workload(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_job_workload_size(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_job_take_workload(\fI\%gearman_job_st\fP\fI\ *job\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_job_st\fP are passed to worker functions to represent jobs that are being run by \fBgearman_worker_work()\fP.
-.sp
-\fI\%gearman_job_free()\fP is used to free a job. This only needs to be
-done if a task was created with a preallocated structure.
-.sp
-\fI\%gearman_job_handle()\fP returns the job handle(see \fBgearman_job_handle_t\fP for more information).
-.sp
-\fI\%gearman_job_function_name()\fP return the name of the function that the
-job was set to execute against.
-.sp
-\fI\%gearman_job_unique()\fP return the unique value that was used for \fI\%gearman_job_st\fP.
-.sp
-returns the \fI\%gearman_job_st\fP workload. The size of it can be determined with \fI\%gearman_job_workload_size()\fP.
-\fI\%gearman_job_take_workload()\fP is the same as \fI\%gearman_job_workload()\fP with the exception that the result must be
-\fIfree(3)\fP by the caller.
-.SH RETURN VALUE
-.sp
-A value of \fBgearman_return_t\fP  is returned.  On success that value
-will be :c:type::\fIGEARMAN_SUCCESS\fP.  Use \fBgearman_strerror()\fP to
-translate this value to a printable string.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_job_workload_size.3'
--- docs/man/gearman_job_workload_size.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_job_workload_size.3	1970-01-01 00:00:00 +0000
@@ -1,129 +0,0 @@
-.TH "GEARMAN_JOB_WORKLOAD_SIZE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_job_workload_size \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_job_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_data(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *data\fP, size_t\fI\ data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_warning(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *warning\fP, size_t\fI\ warning_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_status(\fI\%gearman_job_st\fP\fI\ *job\fP, uint32_t\fI\ numerator\fP, uint32_t\fI\ denominator\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_complete(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *result\fP, size_t\fI\ result_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_exception(\fI\%gearman_job_st\fP\fI\ *job\fP, const void\fI\ *exception\fP, size_t\fI\ exception_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_job_send_fail(\fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_handle(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_function_name(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_job_unique(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_job_workload(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_job_workload_size(const \fI\%gearman_job_st\fP\fI\ *job\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_job_take_workload(\fI\%gearman_job_st\fP\fI\ *job\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_job_st\fP are passed to worker functions to represent jobs that are being run by \fBgearman_worker_work()\fP.
-.sp
-\fI\%gearman_job_free()\fP is used to free a job. This only needs to be
-done if a task was created with a preallocated structure.
-.sp
-\fI\%gearman_job_handle()\fP returns the job handle(see \fBgearman_job_handle_t\fP for more information).
-.sp
-\fI\%gearman_job_function_name()\fP return the name of the function that the
-job was set to execute against.
-.sp
-\fI\%gearman_job_unique()\fP return the unique value that was used for \fI\%gearman_job_st\fP.
-.sp
-returns the \fI\%gearman_job_st\fP workload. The size of it can be determined with \fI\%gearman_job_workload_size()\fP.
-\fI\%gearman_job_take_workload()\fP is the same as \fI\%gearman_job_workload()\fP with the exception that the result must be
-\fIfree(3)\fP by the caller.
-.SH RETURN VALUE
-.sp
-A value of \fBgearman_return_t\fP  is returned.  On success that value
-will be :c:type::\fIGEARMAN_SUCCESS\fP.  Use \fBgearman_strerror()\fP to
-translate this value to a printable string.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_log_fn.3'
--- docs/man/gearman_log_fn.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_log_fn.3	1970-01-01 00:00:00 +0000
@@ -1,65 +0,0 @@
-.TH "GEARMAN_LOG_FN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_log_fn \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_log_fn
-.UNINDENT
-.SH DESCRIPTION
-.sp
-:c:type:gearman_log_fn is defined as:
-.sp
-.nf
-.ft C
-void (gearman_log_fn)(const char *line, gearman_verbose_t verbose, void *context)
-.ft P
-.fi
-.SH RETURN VALUE
-.sp
-None
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_set_log_fn(3)\fP \fIgearman_worker_set_log_fn(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_parse_servers.3'
--- docs/man/gearman_parse_servers.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_parse_servers.3	1970-01-01 00:00:00 +0000
@@ -1,67 +0,0 @@
-.TH "GEARMAN_PARSE_SERVERS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_parse_servers \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_parse_server_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_parse_servers(const char\fI\ *servers\fP, \fI\%gearman_parse_server_fn\fP\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_parse_servers()\fP parses a list of servers and call the \fI\%gearman_parse_server_fn()\fP for each server.
-.SH RETURN VALUE
-.sp
-A value of type \fBgearman_return_t\fP  is returned.
-On success that value will be \fBGEARMAN_SUCCESS\fP.
-Use gearman_strerror to translate this value to a printable string.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_result_boolean.3'
--- docs/man/gearman_result_boolean.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_result_boolean.3	1970-01-01 00:00:00 +0000
@@ -1,98 +0,0 @@
-.TH "GEARMAN_RESULT_BOOLEAN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_result_boolean \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_result_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_result_st\fP *gearman_task_result(gearman_task_st\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int64_t gearman_result_integer(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_result_boolean(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_string_t gearman_result_string(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_result_store_string(\fI\%gearman_result_st\fP\fI\ *self\fP, gearman_string_t\fI\ arg\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_result_store_integer(\fI\%gearman_result_st\fP\fI\ *self\fP, int64_t\fI\ value\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_result_store_value(\fI\%gearman_result_st\fP\fI\ *self\fP, const void\fI\ *value\fP, size_t\fI\ size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_result_size(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_result_value(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_result_is_null(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-The \fI\%gearman_result_st\fP type represents a result set. \fBgearman_aggregator_fn\fP is passed on these types which it uses to create a final result that is returned to the client.
-.sp
-\fI\%gearman_task_result()\fP returns \fI\%gearman_result_st\fP from a \fBgearman_task_st\fP.
-.sp
-A \fI\%gearman_result_st\fP can return the resulting value as either a char pointer, boolean, \fBgearman_string_t\fP, or int64_t.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error()\fP or \fIgearman_worker_error()\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_result_integer.3'
--- docs/man/gearman_result_integer.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_result_integer.3	1970-01-01 00:00:00 +0000
@@ -1,98 +0,0 @@
-.TH "GEARMAN_RESULT_INTEGER" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_result_integer \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_result_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_result_st\fP *gearman_task_result(gearman_task_st\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int64_t gearman_result_integer(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_result_boolean(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_string_t gearman_result_string(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_result_store_string(\fI\%gearman_result_st\fP\fI\ *self\fP, gearman_string_t\fI\ arg\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_result_store_integer(\fI\%gearman_result_st\fP\fI\ *self\fP, int64_t\fI\ value\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_result_store_value(\fI\%gearman_result_st\fP\fI\ *self\fP, const void\fI\ *value\fP, size_t\fI\ size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_result_size(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_result_value(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_result_is_null(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-The \fI\%gearman_result_st\fP type represents a result set. \fBgearman_aggregator_fn\fP is passed on these types which it uses to create a final result that is returned to the client.
-.sp
-\fI\%gearman_task_result()\fP returns \fI\%gearman_result_st\fP from a \fBgearman_task_st\fP.
-.sp
-A \fI\%gearman_result_st\fP can return the resulting value as either a char pointer, boolean, \fBgearman_string_t\fP, or int64_t.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error()\fP or \fIgearman_worker_error()\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_result_is_null.3'
--- docs/man/gearman_result_is_null.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_result_is_null.3	1970-01-01 00:00:00 +0000
@@ -1,98 +0,0 @@
-.TH "GEARMAN_RESULT_IS_NULL" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_result_is_null \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_result_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_result_st\fP *gearman_task_result(gearman_task_st\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int64_t gearman_result_integer(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_result_boolean(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_string_t gearman_result_string(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_result_store_string(\fI\%gearman_result_st\fP\fI\ *self\fP, gearman_string_t\fI\ arg\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_result_store_integer(\fI\%gearman_result_st\fP\fI\ *self\fP, int64_t\fI\ value\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_result_store_value(\fI\%gearman_result_st\fP\fI\ *self\fP, const void\fI\ *value\fP, size_t\fI\ size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_result_size(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_result_value(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_result_is_null(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-The \fI\%gearman_result_st\fP type represents a result set. \fBgearman_aggregator_fn\fP is passed on these types which it uses to create a final result that is returned to the client.
-.sp
-\fI\%gearman_task_result()\fP returns \fI\%gearman_result_st\fP from a \fBgearman_task_st\fP.
-.sp
-A \fI\%gearman_result_st\fP can return the resulting value as either a char pointer, boolean, \fBgearman_string_t\fP, or int64_t.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error()\fP or \fIgearman_worker_error()\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_result_size.3'
--- docs/man/gearman_result_size.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_result_size.3	1970-01-01 00:00:00 +0000
@@ -1,98 +0,0 @@
-.TH "GEARMAN_RESULT_SIZE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_result_size \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_result_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_result_st\fP *gearman_task_result(gearman_task_st\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int64_t gearman_result_integer(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_result_boolean(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_string_t gearman_result_string(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_result_store_string(\fI\%gearman_result_st\fP\fI\ *self\fP, gearman_string_t\fI\ arg\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_result_store_integer(\fI\%gearman_result_st\fP\fI\ *self\fP, int64_t\fI\ value\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_result_store_value(\fI\%gearman_result_st\fP\fI\ *self\fP, const void\fI\ *value\fP, size_t\fI\ size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_result_size(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_result_value(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_result_is_null(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-The \fI\%gearman_result_st\fP type represents a result set. \fBgearman_aggregator_fn\fP is passed on these types which it uses to create a final result that is returned to the client.
-.sp
-\fI\%gearman_task_result()\fP returns \fI\%gearman_result_st\fP from a \fBgearman_task_st\fP.
-.sp
-A \fI\%gearman_result_st\fP can return the resulting value as either a char pointer, boolean, \fBgearman_string_t\fP, or int64_t.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error()\fP or \fIgearman_worker_error()\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_result_store_integer.3'
--- docs/man/gearman_result_store_integer.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_result_store_integer.3	1970-01-01 00:00:00 +0000
@@ -1,98 +0,0 @@
-.TH "GEARMAN_RESULT_STORE_INTEGER" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_result_store_integer \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_result_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_result_st\fP *gearman_task_result(gearman_task_st\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int64_t gearman_result_integer(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_result_boolean(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_string_t gearman_result_string(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_result_store_string(\fI\%gearman_result_st\fP\fI\ *self\fP, gearman_string_t\fI\ arg\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_result_store_integer(\fI\%gearman_result_st\fP\fI\ *self\fP, int64_t\fI\ value\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_result_store_value(\fI\%gearman_result_st\fP\fI\ *self\fP, const void\fI\ *value\fP, size_t\fI\ size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_result_size(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_result_value(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_result_is_null(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-The \fI\%gearman_result_st\fP type represents a result set. \fBgearman_aggregator_fn\fP is passed on these types which it uses to create a final result that is returned to the client.
-.sp
-\fI\%gearman_task_result()\fP returns \fI\%gearman_result_st\fP from a \fBgearman_task_st\fP.
-.sp
-A \fI\%gearman_result_st\fP can return the resulting value as either a char pointer, boolean, \fBgearman_string_t\fP, or int64_t.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error()\fP or \fIgearman_worker_error()\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_result_store_string.3'
--- docs/man/gearman_result_store_string.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_result_store_string.3	1970-01-01 00:00:00 +0000
@@ -1,98 +0,0 @@
-.TH "GEARMAN_RESULT_STORE_STRING" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_result_store_string \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_result_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_result_st\fP *gearman_task_result(gearman_task_st\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int64_t gearman_result_integer(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_result_boolean(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_string_t gearman_result_string(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_result_store_string(\fI\%gearman_result_st\fP\fI\ *self\fP, gearman_string_t\fI\ arg\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_result_store_integer(\fI\%gearman_result_st\fP\fI\ *self\fP, int64_t\fI\ value\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_result_store_value(\fI\%gearman_result_st\fP\fI\ *self\fP, const void\fI\ *value\fP, size_t\fI\ size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_result_size(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_result_value(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_result_is_null(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-The \fI\%gearman_result_st\fP type represents a result set. \fBgearman_aggregator_fn\fP is passed on these types which it uses to create a final result that is returned to the client.
-.sp
-\fI\%gearman_task_result()\fP returns \fI\%gearman_result_st\fP from a \fBgearman_task_st\fP.
-.sp
-A \fI\%gearman_result_st\fP can return the resulting value as either a char pointer, boolean, \fBgearman_string_t\fP, or int64_t.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error()\fP or \fIgearman_worker_error()\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_result_store_value.3'
--- docs/man/gearman_result_store_value.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_result_store_value.3	1970-01-01 00:00:00 +0000
@@ -1,98 +0,0 @@
-.TH "GEARMAN_RESULT_STORE_VALUE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_result_store_value \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_result_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_result_st\fP *gearman_task_result(gearman_task_st\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int64_t gearman_result_integer(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_result_boolean(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_string_t gearman_result_string(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_result_store_string(\fI\%gearman_result_st\fP\fI\ *self\fP, gearman_string_t\fI\ arg\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_result_store_integer(\fI\%gearman_result_st\fP\fI\ *self\fP, int64_t\fI\ value\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_result_store_value(\fI\%gearman_result_st\fP\fI\ *self\fP, const void\fI\ *value\fP, size_t\fI\ size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_result_size(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_result_value(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_result_is_null(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-The \fI\%gearman_result_st\fP type represents a result set. \fBgearman_aggregator_fn\fP is passed on these types which it uses to create a final result that is returned to the client.
-.sp
-\fI\%gearman_task_result()\fP returns \fI\%gearman_result_st\fP from a \fBgearman_task_st\fP.
-.sp
-A \fI\%gearman_result_st\fP can return the resulting value as either a char pointer, boolean, \fBgearman_string_t\fP, or int64_t.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error()\fP or \fIgearman_worker_error()\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_result_string.3'
--- docs/man/gearman_result_string.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_result_string.3	1970-01-01 00:00:00 +0000
@@ -1,98 +0,0 @@
-.TH "GEARMAN_RESULT_STRING" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_result_string \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_result_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_result_st\fP *gearman_task_result(gearman_task_st\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int64_t gearman_result_integer(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_result_boolean(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_string_t gearman_result_string(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_result_store_string(\fI\%gearman_result_st\fP\fI\ *self\fP, gearman_string_t\fI\ arg\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_result_store_integer(\fI\%gearman_result_st\fP\fI\ *self\fP, int64_t\fI\ value\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_result_store_value(\fI\%gearman_result_st\fP\fI\ *self\fP, const void\fI\ *value\fP, size_t\fI\ size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_result_size(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_result_value(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_result_is_null(const \fI\%gearman_result_st\fP\fI\ *self\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-The \fI\%gearman_result_st\fP type represents a result set. \fBgearman_aggregator_fn\fP is passed on these types which it uses to create a final result that is returned to the client.
-.sp
-\fI\%gearman_task_result()\fP returns \fI\%gearman_result_st\fP from a \fBgearman_task_st\fP.
-.sp
-A \fI\%gearman_result_st\fP can return the resulting value as either a char pointer, boolean, \fBgearman_string_t\fP, or int64_t.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error()\fP or \fIgearman_worker_error()\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_return_t.3'
--- docs/man/gearman_return_t.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_return_t.3	1970-01-01 00:00:00 +0000
@@ -1,339 +0,0 @@
-.TH "GEARMAN_RETURN_T" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_return_t \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_return_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_strerror(\fI\%gearman_return_t\fP\fI\ rc\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_success(\fI\%gearman_return_t\fP\fI\ rc\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_failed(\fI\%gearman_return_t\fP\fI\ rc\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_continue(\fI\%gearman_return_t\fP\fI\ rc\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_return_t\fP is used as a return/error type for all calls using \fBgearman_client_st\fP and \fBgearman_worker_st\fP.
-\fI\%GEARMAN_SUCCESS\fP is returned upon success, otherwise an error is returned. \fI\%gearman_failed()\fP can be used to see if the return value is a failing value.
-You can print a text version of the error message with \fI\%gearman_strerror()\fP.
-.sp
-\fI\%gearman_success()\fP return true if \fI\%GEARMAN_SUCCESS\fP or if
-\fI\%GEARMAN_NO_PENDING_TASKS\fP tests true.
-.sp
-\fI\%gearman_failed()\fP return true if any value other then \fI\%GEARMAN_SUCCESS\fP was provided.
-.sp
-\fI\%gearman_continue()\fP returns true if any error related to non\-blocking IO
-occurred. This should be used for testing loops.
-.SS Possible values of \fI\%gearman_return_t\fP:
-.INDENT 0.0
-.TP
-.B GEARMAN_SUCCESS
-Success
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_PENDING_TASKS
-\fBgearman_client_run_tasks()\fP was called and it has completed all tasks assigned to the client.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_IO_WAIT
-Blocking IO was found. gearman_continue() can be used to test for this.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_ERRNO
-System error occurred. Use either \fBgearman_client_errno()\fP or \fBgearman_worker_errno()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_ACTIVE_FDS
-No active connections were available.  gearman_continue() can be used to test for this.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_GETADDRINFO
-Name resolution failed for a host.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_SERVERS
-No servers have been provided for the client/worker.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_LOST_CONNECTION
-Connection was lost to the given server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_MEMORY_ALLOCATION_FAILURE
-Memory allocation failed.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_SERVER_ERROR
-An error occurred on the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NOT_CONNECTED
-Client/Worker is not currently connected to the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_COULD_NOT_CONNECT
-Server name was valid, but a connection could not be made.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_ECHO_DATA_CORRUPTION
-Either \fBgearman_client_echo()\fP or \fBgearman_worker_echo()\fP echo
-was unsuccessful because the data was returned from \fBgearmand\fP
-corrupted.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_UNKNOWN_STATE
-The gearman_return_t was never set.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_FLUSH_DATA
-Internal state, should never be seen by either client or worker.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_SEND_BUFFER_TOO_SMALL
-Send buffer was too small.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_TIMEOUT
-A timeout occurred when making a request to the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_ARGUMENT_TOO_LARGE
-Argument was too large for the current buffer.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_ARGUMENT
-One of the arguments to the given API call was invalid. EINVAL will be set if \fBgearman_client_error()\fP or \fBgearman_worker_error()\fP were not settable. This can also be returned if \fBGEARMAN_CLIENT_UNBUFFERED_RESULT\fP was set, but the client is not handling the data correctly.
-.UNINDENT
-.SS CLIENT ONLY
-.INDENT 0.0
-.TP
-.B GEARMAN_NEED_WORKLOAD_FN
-A client was asked for work, but no \fBgearman_workload_fn\fP callback was specified. See \fBgearman_client_set_workload_fn()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_FAIL
-A task has failed, and the worker has exited with an error or it called \fBgearman_job_send_fail()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_IN_PROGRESS
-\fBgearman_client_job_status()\fP has been called for a \fBgearman_job_handle_t\fP and the Job is currently being run by a worker.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_JOB_EXISTS
-\fBgearman_client_job_status()\fP has been called for a \fBgearman_job_handle_t\fP and the Job is currently known by a server, but is not being run by a worker.
-.UNINDENT
-.SS WORKER ONLY
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_FUNCTION_NAME
-A worker was sent a request for a job that it did not have a valid function for.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_WORKER_FUNCTION
-No callback was provided by the worker for a given function.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_REGISTERED_FUNCTION
-A request for removing a given function from a worker was invalid since that function did not exist.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_REGISTERED_FUNCTIONS
-The worker has not registered any functions.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_JOBS
-No jobs were found for the worker.
-.UNINDENT
-.SS WORKER TO CLIENT
-.sp
-Client which have registed a custom \fBgearman_actions_t\fP may use these
-value as return values to the calling client.
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_DATA
-Worker has sent a chunked piece of data to the client via \fBgearman_job_send_data()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_WARNING
-Worker has issued a warning to the client via \fBgearman_job_send_warning()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_STATUS
-Status has been updated by the worker via \fBgearman_job_send_status()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_EXCEPTION
-Worker has sent an exception the client via \fBgearman_job_send_exception()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_FAIL
-A task has failed, and the worker has exited with an error or it called \fBgearman_job_send_fail()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_ERROR
-A task has had an error and will be retried.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_PAUSE
-Used only in custom application for client return based on \fI\%GEARMAN_WORK_DATA\fP, \fI\%GEARMAN_WORK_WARNING\fP, \fI\%GEARMAN_WORK_EXCEPTION\fP, \fI\%GEARMAN_WORK_FAIL\fP, or \fI\%GEARMAN_WORK_STATUS\fP. \fI\%gearman_continue()\fP can be used to check for this value.
-.UNINDENT
-.SS WORKER TO CLIENT
-.sp
-Any function defined by \fBgearman_worker_define_function()\fP may, and can only, return the following \fI\%gearman_return_t\fP values.
-.INDENT 0.0
-.TP
-.B GEARMAN_SUCCESS
-The function successfully completed the job.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_FATAL
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_FAIL
-The function failed to complete the job. \fI\%GEARMAN_FATAL\fP is the deprecated name for \fI\%GEARMAN_FAIL\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_ERROR
-A task has had an error and will be retried.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_SHUTDOWN
-\fI\%GEARMAN_SHUTDOWN\fP is a special case. If it is returned the client will be sent \fI\%GEARMAN_SUCCESS\fP, but \fBgearman_worker_work()\fP will exit with \fI\%GEARMAN_SHUTDOWN\fP.
-.UNINDENT
-.SS TASK ONLY
-.INDENT 0.0
-.TP
-.B GEARMAN_NOT_FLUSHING
-\fBgearman_task_send_workload()\fP failed, it was not in the correct state.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_DATA_TOO_LARGE
-\fBgearman_task_send_workload()\fP failed, the data was too large to be sent.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_UNKNOWN_OPTION
-Default state of task return value.
-.UNINDENT
-.SS PROTOCOL
-.sp
-If any of these errors occurred the connection will be dropped/reset.
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_MAGIC
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_COMMAND
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_PACKET
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_UNEXPECTED_PACKET
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_TOO_MANY_ARGS
-.UNINDENT
-.SS DEPRECATED
-.INDENT 0.0
-.TP
-.B GEARMAN_IGNORE_PACKET
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_MAX_RETURN
-.UNINDENT
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error()\fP or \fIgearman_worker_error()\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_strerror.3'
--- docs/man/gearman_strerror.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_strerror.3	1970-01-01 00:00:00 +0000
@@ -1,339 +0,0 @@
-.TH "GEARMAN_STRERROR" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_strerror \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_return_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_strerror(\fI\%gearman_return_t\fP\fI\ rc\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_success(\fI\%gearman_return_t\fP\fI\ rc\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_failed(\fI\%gearman_return_t\fP\fI\ rc\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_continue(\fI\%gearman_return_t\fP\fI\ rc\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_return_t\fP is used as a return/error type for all calls using \fBgearman_client_st\fP and \fBgearman_worker_st\fP.
-\fI\%GEARMAN_SUCCESS\fP is returned upon success, otherwise an error is returned. \fI\%gearman_failed()\fP can be used to see if the return value is a failing value.
-You can print a text version of the error message with \fI\%gearman_strerror()\fP.
-.sp
-\fI\%gearman_success()\fP return true if \fI\%GEARMAN_SUCCESS\fP or if
-\fI\%GEARMAN_NO_PENDING_TASKS\fP tests true.
-.sp
-\fI\%gearman_failed()\fP return true if any value other then \fI\%GEARMAN_SUCCESS\fP was provided.
-.sp
-\fI\%gearman_continue()\fP returns true if any error related to non\-blocking IO
-occurred. This should be used for testing loops.
-.SS Possible values of \fI\%gearman_return_t\fP:
-.INDENT 0.0
-.TP
-.B GEARMAN_SUCCESS
-Success
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_PENDING_TASKS
-\fBgearman_client_run_tasks()\fP was called and it has completed all tasks assigned to the client.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_IO_WAIT
-Blocking IO was found. gearman_continue() can be used to test for this.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_ERRNO
-System error occurred. Use either \fBgearman_client_errno()\fP or \fBgearman_worker_errno()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_ACTIVE_FDS
-No active connections were available.  gearman_continue() can be used to test for this.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_GETADDRINFO
-Name resolution failed for a host.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_SERVERS
-No servers have been provided for the client/worker.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_LOST_CONNECTION
-Connection was lost to the given server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_MEMORY_ALLOCATION_FAILURE
-Memory allocation failed.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_SERVER_ERROR
-An error occurred on the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NOT_CONNECTED
-Client/Worker is not currently connected to the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_COULD_NOT_CONNECT
-Server name was valid, but a connection could not be made.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_ECHO_DATA_CORRUPTION
-Either \fBgearman_client_echo()\fP or \fBgearman_worker_echo()\fP echo
-was unsuccessful because the data was returned from \fBgearmand\fP
-corrupted.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_UNKNOWN_STATE
-The gearman_return_t was never set.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_FLUSH_DATA
-Internal state, should never be seen by either client or worker.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_SEND_BUFFER_TOO_SMALL
-Send buffer was too small.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_TIMEOUT
-A timeout occurred when making a request to the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_ARGUMENT_TOO_LARGE
-Argument was too large for the current buffer.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_ARGUMENT
-One of the arguments to the given API call was invalid. EINVAL will be set if \fBgearman_client_error()\fP or \fBgearman_worker_error()\fP were not settable. This can also be returned if \fBGEARMAN_CLIENT_UNBUFFERED_RESULT\fP was set, but the client is not handling the data correctly.
-.UNINDENT
-.SS CLIENT ONLY
-.INDENT 0.0
-.TP
-.B GEARMAN_NEED_WORKLOAD_FN
-A client was asked for work, but no \fBgearman_workload_fn\fP callback was specified. See \fBgearman_client_set_workload_fn()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_FAIL
-A task has failed, and the worker has exited with an error or it called \fBgearman_job_send_fail()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_IN_PROGRESS
-\fBgearman_client_job_status()\fP has been called for a \fBgearman_job_handle_t\fP and the Job is currently being run by a worker.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_JOB_EXISTS
-\fBgearman_client_job_status()\fP has been called for a \fBgearman_job_handle_t\fP and the Job is currently known by a server, but is not being run by a worker.
-.UNINDENT
-.SS WORKER ONLY
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_FUNCTION_NAME
-A worker was sent a request for a job that it did not have a valid function for.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_WORKER_FUNCTION
-No callback was provided by the worker for a given function.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_REGISTERED_FUNCTION
-A request for removing a given function from a worker was invalid since that function did not exist.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_REGISTERED_FUNCTIONS
-The worker has not registered any functions.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_JOBS
-No jobs were found for the worker.
-.UNINDENT
-.SS WORKER TO CLIENT
-.sp
-Client which have registed a custom \fBgearman_actions_t\fP may use these
-value as return values to the calling client.
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_DATA
-Worker has sent a chunked piece of data to the client via \fBgearman_job_send_data()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_WARNING
-Worker has issued a warning to the client via \fBgearman_job_send_warning()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_STATUS
-Status has been updated by the worker via \fBgearman_job_send_status()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_EXCEPTION
-Worker has sent an exception the client via \fBgearman_job_send_exception()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_FAIL
-A task has failed, and the worker has exited with an error or it called \fBgearman_job_send_fail()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_ERROR
-A task has had an error and will be retried.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_PAUSE
-Used only in custom application for client return based on \fI\%GEARMAN_WORK_DATA\fP, \fI\%GEARMAN_WORK_WARNING\fP, \fI\%GEARMAN_WORK_EXCEPTION\fP, \fI\%GEARMAN_WORK_FAIL\fP, or \fI\%GEARMAN_WORK_STATUS\fP. \fI\%gearman_continue()\fP can be used to check for this value.
-.UNINDENT
-.SS WORKER TO CLIENT
-.sp
-Any function defined by \fBgearman_worker_define_function()\fP may, and can only, return the following \fI\%gearman_return_t\fP values.
-.INDENT 0.0
-.TP
-.B GEARMAN_SUCCESS
-The function successfully completed the job.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_FATAL
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_FAIL
-The function failed to complete the job. \fI\%GEARMAN_FATAL\fP is the deprecated name for \fI\%GEARMAN_FAIL\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_ERROR
-A task has had an error and will be retried.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_SHUTDOWN
-\fI\%GEARMAN_SHUTDOWN\fP is a special case. If it is returned the client will be sent \fI\%GEARMAN_SUCCESS\fP, but \fBgearman_worker_work()\fP will exit with \fI\%GEARMAN_SHUTDOWN\fP.
-.UNINDENT
-.SS TASK ONLY
-.INDENT 0.0
-.TP
-.B GEARMAN_NOT_FLUSHING
-\fBgearman_task_send_workload()\fP failed, it was not in the correct state.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_DATA_TOO_LARGE
-\fBgearman_task_send_workload()\fP failed, the data was too large to be sent.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_UNKNOWN_OPTION
-Default state of task return value.
-.UNINDENT
-.SS PROTOCOL
-.sp
-If any of these errors occurred the connection will be dropped/reset.
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_MAGIC
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_COMMAND
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_PACKET
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_UNEXPECTED_PACKET
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_TOO_MANY_ARGS
-.UNINDENT
-.SS DEPRECATED
-.INDENT 0.0
-.TP
-.B GEARMAN_IGNORE_PACKET
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_MAX_RETURN
-.UNINDENT
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error()\fP or \fIgearman_worker_error()\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_string_t.3'
--- docs/man/gearman_string_t.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_string_t.3	1970-01-01 00:00:00 +0000
@@ -1,64 +0,0 @@
-.TH "GEARMAN_STRING_T" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_string_t \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_string_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_size(\fI\%gearman_string_t\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_c_str(\fI\%gearman_string_t\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-The \fI\%gearman_string_t\fP is a simple type representing a "string".
-Once created \fI\%gearman_string_t\fP are not mutable once created. They
-only point to the strings that define them and require no deallocation.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_success.3'
--- docs/man/gearman_success.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_success.3	1970-01-01 00:00:00 +0000
@@ -1,339 +0,0 @@
-.TH "GEARMAN_SUCCESS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_success \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_return_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_strerror(\fI\%gearman_return_t\fP\fI\ rc\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_success(\fI\%gearman_return_t\fP\fI\ rc\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_failed(\fI\%gearman_return_t\fP\fI\ rc\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_continue(\fI\%gearman_return_t\fP\fI\ rc\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_return_t\fP is used as a return/error type for all calls using \fBgearman_client_st\fP and \fBgearman_worker_st\fP.
-\fI\%GEARMAN_SUCCESS\fP is returned upon success, otherwise an error is returned. \fI\%gearman_failed()\fP can be used to see if the return value is a failing value.
-You can print a text version of the error message with \fI\%gearman_strerror()\fP.
-.sp
-\fI\%gearman_success()\fP return true if \fI\%GEARMAN_SUCCESS\fP or if
-\fI\%GEARMAN_NO_PENDING_TASKS\fP tests true.
-.sp
-\fI\%gearman_failed()\fP return true if any value other then \fI\%GEARMAN_SUCCESS\fP was provided.
-.sp
-\fI\%gearman_continue()\fP returns true if any error related to non\-blocking IO
-occurred. This should be used for testing loops.
-.SS Possible values of \fI\%gearman_return_t\fP:
-.INDENT 0.0
-.TP
-.B GEARMAN_SUCCESS
-Success
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_PENDING_TASKS
-\fBgearman_client_run_tasks()\fP was called and it has completed all tasks assigned to the client.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_IO_WAIT
-Blocking IO was found. gearman_continue() can be used to test for this.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_ERRNO
-System error occurred. Use either \fBgearman_client_errno()\fP or \fBgearman_worker_errno()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_ACTIVE_FDS
-No active connections were available.  gearman_continue() can be used to test for this.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_GETADDRINFO
-Name resolution failed for a host.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_SERVERS
-No servers have been provided for the client/worker.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_LOST_CONNECTION
-Connection was lost to the given server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_MEMORY_ALLOCATION_FAILURE
-Memory allocation failed.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_SERVER_ERROR
-An error occurred on the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NOT_CONNECTED
-Client/Worker is not currently connected to the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_COULD_NOT_CONNECT
-Server name was valid, but a connection could not be made.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_ECHO_DATA_CORRUPTION
-Either \fBgearman_client_echo()\fP or \fBgearman_worker_echo()\fP echo
-was unsuccessful because the data was returned from \fBgearmand\fP
-corrupted.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_UNKNOWN_STATE
-The gearman_return_t was never set.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_FLUSH_DATA
-Internal state, should never be seen by either client or worker.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_SEND_BUFFER_TOO_SMALL
-Send buffer was too small.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_TIMEOUT
-A timeout occurred when making a request to the server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_ARGUMENT_TOO_LARGE
-Argument was too large for the current buffer.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_ARGUMENT
-One of the arguments to the given API call was invalid. EINVAL will be set if \fBgearman_client_error()\fP or \fBgearman_worker_error()\fP were not settable. This can also be returned if \fBGEARMAN_CLIENT_UNBUFFERED_RESULT\fP was set, but the client is not handling the data correctly.
-.UNINDENT
-.SS CLIENT ONLY
-.INDENT 0.0
-.TP
-.B GEARMAN_NEED_WORKLOAD_FN
-A client was asked for work, but no \fBgearman_workload_fn\fP callback was specified. See \fBgearman_client_set_workload_fn()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_FAIL
-A task has failed, and the worker has exited with an error or it called \fBgearman_job_send_fail()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_IN_PROGRESS
-\fBgearman_client_job_status()\fP has been called for a \fBgearman_job_handle_t\fP and the Job is currently being run by a worker.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_JOB_EXISTS
-\fBgearman_client_job_status()\fP has been called for a \fBgearman_job_handle_t\fP and the Job is currently known by a server, but is not being run by a worker.
-.UNINDENT
-.SS WORKER ONLY
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_FUNCTION_NAME
-A worker was sent a request for a job that it did not have a valid function for.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_WORKER_FUNCTION
-No callback was provided by the worker for a given function.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_REGISTERED_FUNCTION
-A request for removing a given function from a worker was invalid since that function did not exist.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_REGISTERED_FUNCTIONS
-The worker has not registered any functions.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_NO_JOBS
-No jobs were found for the worker.
-.UNINDENT
-.SS WORKER TO CLIENT
-.sp
-Client which have registed a custom \fBgearman_actions_t\fP may use these
-value as return values to the calling client.
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_DATA
-Worker has sent a chunked piece of data to the client via \fBgearman_job_send_data()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_WARNING
-Worker has issued a warning to the client via \fBgearman_job_send_warning()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_STATUS
-Status has been updated by the worker via \fBgearman_job_send_status()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_EXCEPTION
-Worker has sent an exception the client via \fBgearman_job_send_exception()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_FAIL
-A task has failed, and the worker has exited with an error or it called \fBgearman_job_send_fail()\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_WORK_ERROR
-A task has had an error and will be retried.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_PAUSE
-Used only in custom application for client return based on \fI\%GEARMAN_WORK_DATA\fP, \fI\%GEARMAN_WORK_WARNING\fP, \fI\%GEARMAN_WORK_EXCEPTION\fP, \fI\%GEARMAN_WORK_FAIL\fP, or \fI\%GEARMAN_WORK_STATUS\fP. \fI\%gearman_continue()\fP can be used to check for this value.
-.UNINDENT
-.SS WORKER TO CLIENT
-.sp
-Any function defined by \fBgearman_worker_define_function()\fP may, and can only, return the following \fI\%gearman_return_t\fP values.
-.INDENT 0.0
-.TP
-.B GEARMAN_SUCCESS
-The function successfully completed the job.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_FATAL
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_FAIL
-The function failed to complete the job. \fI\%GEARMAN_FATAL\fP is the deprecated name for \fI\%GEARMAN_FAIL\fP
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_ERROR
-A task has had an error and will be retried.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_SHUTDOWN
-\fI\%GEARMAN_SHUTDOWN\fP is a special case. If it is returned the client will be sent \fI\%GEARMAN_SUCCESS\fP, but \fBgearman_worker_work()\fP will exit with \fI\%GEARMAN_SHUTDOWN\fP.
-.UNINDENT
-.SS TASK ONLY
-.INDENT 0.0
-.TP
-.B GEARMAN_NOT_FLUSHING
-\fBgearman_task_send_workload()\fP failed, it was not in the correct state.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_DATA_TOO_LARGE
-\fBgearman_task_send_workload()\fP failed, the data was too large to be sent.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_UNKNOWN_OPTION
-Default state of task return value.
-.UNINDENT
-.SS PROTOCOL
-.sp
-If any of these errors occurred the connection will be dropped/reset.
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_MAGIC
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_COMMAND
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_INVALID_PACKET
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_UNEXPECTED_PACKET
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_TOO_MANY_ARGS
-.UNINDENT
-.SS DEPRECATED
-.INDENT 0.0
-.TP
-.B GEARMAN_IGNORE_PACKET
-.UNINDENT
-.INDENT 0.0
-.TP
-.B GEARMAN_MAX_RETURN
-.UNINDENT
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_error()\fP or \fIgearman_worker_error()\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_attr_init.3'
--- docs/man/gearman_task_attr_init.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_attr_init.3	1970-01-01 00:00:00 +0000
@@ -1,76 +0,0 @@
-.TH "GEARMAN_TASK_ATTR_INIT" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_attr_init \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_work_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_job_priority_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_work_t\fP gearman_work(\fI\%gearman_job_priority_t\fP\fI\ priority\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_work_t\fP gearman_work_epoch(time_t\fI\ epoch\fP, \fI\%gearman_job_priority_t\fP\fI\ priority\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_work_t\fP gearman_work_background(\fI\%gearman_job_priority_t\fP\fI\ priority\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_work_t\fP describe work for \fBgearman_execute()\fP.
-.sp
-\fI\%gearman_work()\fP creates a \fI\%gearman_work_t\fP with a priority.
-.sp
-\fI\%gearman_work_epoch()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload at the time specified by epoch.
-.sp
-\fI\%gearman_work_background()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload as a background job.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_execute()\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_attr_init_background.3'
--- docs/man/gearman_task_attr_init_background.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_attr_init_background.3	1970-01-01 00:00:00 +0000
@@ -1,76 +0,0 @@
-.TH "GEARMAN_TASK_ATTR_INIT_BACKGROUND" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_attr_init_background \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_work_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_job_priority_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_work_t\fP gearman_work(\fI\%gearman_job_priority_t\fP\fI\ priority\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_work_t\fP gearman_work_epoch(time_t\fI\ epoch\fP, \fI\%gearman_job_priority_t\fP\fI\ priority\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_work_t\fP gearman_work_background(\fI\%gearman_job_priority_t\fP\fI\ priority\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_work_t\fP describe work for \fBgearman_execute()\fP.
-.sp
-\fI\%gearman_work()\fP creates a \fI\%gearman_work_t\fP with a priority.
-.sp
-\fI\%gearman_work_epoch()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload at the time specified by epoch.
-.sp
-\fI\%gearman_work_background()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload as a background job.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_execute()\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_attr_init_epoch.3'
--- docs/man/gearman_task_attr_init_epoch.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_attr_init_epoch.3	1970-01-01 00:00:00 +0000
@@ -1,76 +0,0 @@
-.TH "GEARMAN_TASK_ATTR_INIT_EPOCH" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_attr_init_epoch \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_work_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_job_priority_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_work_t\fP gearman_work(\fI\%gearman_job_priority_t\fP\fI\ priority\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_work_t\fP gearman_work_epoch(time_t\fI\ epoch\fP, \fI\%gearman_job_priority_t\fP\fI\ priority\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_work_t\fP gearman_work_background(\fI\%gearman_job_priority_t\fP\fI\ priority\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_work_t\fP describe work for \fBgearman_execute()\fP.
-.sp
-\fI\%gearman_work()\fP creates a \fI\%gearman_work_t\fP with a priority.
-.sp
-\fI\%gearman_work_epoch()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload at the time specified by epoch.
-.sp
-\fI\%gearman_work_background()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload as a background job.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_execute()\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_attr_t.3'
--- docs/man/gearman_task_attr_t.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_attr_t.3	1970-01-01 00:00:00 +0000
@@ -1,76 +0,0 @@
-.TH "GEARMAN_TASK_ATTR_T" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_attr_t \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_work_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_job_priority_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_work_t\fP gearman_work(\fI\%gearman_job_priority_t\fP\fI\ priority\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_work_t\fP gearman_work_epoch(time_t\fI\ epoch\fP, \fI\%gearman_job_priority_t\fP\fI\ priority\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_work_t\fP gearman_work_background(\fI\%gearman_job_priority_t\fP\fI\ priority\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_work_t\fP describe work for \fBgearman_execute()\fP.
-.sp
-\fI\%gearman_work()\fP creates a \fI\%gearman_work_t\fP with a priority.
-.sp
-\fI\%gearman_work_epoch()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload at the time specified by epoch.
-.sp
-\fI\%gearman_work_background()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload as a background job.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_execute()\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_context.3'
--- docs/man/gearman_task_context.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_context.3	1970-01-01 00:00:00 +0000
@@ -1,159 +0,0 @@
-.TH "GEARMAN_TASK_CONTEXT" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_context \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_free(\fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_context(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_set_context(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_function_name(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_unique(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_job_handle(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_known(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_running(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_numerator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_denominator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_give_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_send_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_task_data(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_data_size(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_take_data(\fI\%gearman_task_st\fP\fI\ *task\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_recv_data(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *data\fP, size_t\fI\ data_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_error(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_task_return(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-A \fI\%gearman_task_st\fP represents a \fItask\fP.  Work that is sent by a \fIclient\fP to a gearman server is seen as a task (a \fIworker\fP recieves a task in the form of a \fIjob\fP.
-.sp
-Tasks, i.e. \fI\%gearman_task_st\fP are created by calling either \fBgearman_execute()\fP, \fBgearman_client_add_task()\fP, or \fBgearman_client_add_task_background()\fP.
-.sp
-\fBgearman_client_add_task_status()\fP can also create \fI\%gearman_task_st\fP, these tasks will be used to
-monitor a previously created \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_free()\fP is used to free a task. This only needs to be
-done if a task was created with a preallocated structure or if you want to clean up the memory of a specific task.
-.sp
-\fI\%gearman_task_set_context()\fP sets the given context of the \fI\%gearman_task_st\fP. The context can be used to pass information to a \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_context()\fP returns the context that was used in the creation of the \fI\%gearman_task_st\fP (or that was set with \fI\%gearman_task_set_context()\fP.
-.sp
-\fI\%gearman_task_data()\fP returns the current data that has been returned to the task. \fI\%gearman_task_data_size()\fP will give you the size of the value. \fI\%gearman_task_take_data()\fP is the same as \fI\%gearman_task_data()\fP but the value that is returned must be freed by the client (\fIfree(3)\fP). \fI\%gearman_task_recv_data()\fP can be used with pre\-allocated buffers.
-.sp
-\fI\%gearman_task_is_known()\fP, \fI\%gearman_task_is_running()\fP, \fI\%gearman_task_numerator()\fP, and \fI\%gearman_task_denominator()\fP, return values related to the last status update that was made to the \fI\%gearman_task_st\fP. They do not cause the \fI\%gearman_task_st\fP to update itself.
-.sp
-\fI\%gearman_task_error()\fP return the last error message that the
-\fI\%gearman_task_st\fP encountered. \fI\%gearman_task_return()\fP
-return the last \fBgearman_return_t\fP stored. A value of
-\fBGEARMAN_UNKNOWN_STATE\fP means that the task has not been submitted to
-server yet, or that no function was available if the job has been submitted.
-.SH RETURN VALUE
-.sp
-Various. Values that are returned by \fI\%gearman_task_take_data()\fP must have \fIfree(3)\fP called on them.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_data.3'
--- docs/man/gearman_task_data.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_data.3	1970-01-01 00:00:00 +0000
@@ -1,159 +0,0 @@
-.TH "GEARMAN_TASK_DATA" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_data \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_free(\fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_context(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_set_context(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_function_name(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_unique(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_job_handle(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_known(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_running(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_numerator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_denominator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_give_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_send_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_task_data(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_data_size(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_take_data(\fI\%gearman_task_st\fP\fI\ *task\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_recv_data(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *data\fP, size_t\fI\ data_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_error(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_task_return(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-A \fI\%gearman_task_st\fP represents a \fItask\fP.  Work that is sent by a \fIclient\fP to a gearman server is seen as a task (a \fIworker\fP recieves a task in the form of a \fIjob\fP.
-.sp
-Tasks, i.e. \fI\%gearman_task_st\fP are created by calling either \fBgearman_execute()\fP, \fBgearman_client_add_task()\fP, or \fBgearman_client_add_task_background()\fP.
-.sp
-\fBgearman_client_add_task_status()\fP can also create \fI\%gearman_task_st\fP, these tasks will be used to
-monitor a previously created \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_free()\fP is used to free a task. This only needs to be
-done if a task was created with a preallocated structure or if you want to clean up the memory of a specific task.
-.sp
-\fI\%gearman_task_set_context()\fP sets the given context of the \fI\%gearman_task_st\fP. The context can be used to pass information to a \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_context()\fP returns the context that was used in the creation of the \fI\%gearman_task_st\fP (or that was set with \fI\%gearman_task_set_context()\fP.
-.sp
-\fI\%gearman_task_data()\fP returns the current data that has been returned to the task. \fI\%gearman_task_data_size()\fP will give you the size of the value. \fI\%gearman_task_take_data()\fP is the same as \fI\%gearman_task_data()\fP but the value that is returned must be freed by the client (\fIfree(3)\fP). \fI\%gearman_task_recv_data()\fP can be used with pre\-allocated buffers.
-.sp
-\fI\%gearman_task_is_known()\fP, \fI\%gearman_task_is_running()\fP, \fI\%gearman_task_numerator()\fP, and \fI\%gearman_task_denominator()\fP, return values related to the last status update that was made to the \fI\%gearman_task_st\fP. They do not cause the \fI\%gearman_task_st\fP to update itself.
-.sp
-\fI\%gearman_task_error()\fP return the last error message that the
-\fI\%gearman_task_st\fP encountered. \fI\%gearman_task_return()\fP
-return the last \fBgearman_return_t\fP stored. A value of
-\fBGEARMAN_UNKNOWN_STATE\fP means that the task has not been submitted to
-server yet, or that no function was available if the job has been submitted.
-.SH RETURN VALUE
-.sp
-Various. Values that are returned by \fI\%gearman_task_take_data()\fP must have \fIfree(3)\fP called on them.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_data_size.3'
--- docs/man/gearman_task_data_size.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_data_size.3	1970-01-01 00:00:00 +0000
@@ -1,159 +0,0 @@
-.TH "GEARMAN_TASK_DATA_SIZE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_data_size \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_free(\fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_context(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_set_context(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_function_name(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_unique(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_job_handle(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_known(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_running(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_numerator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_denominator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_give_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_send_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_task_data(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_data_size(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_take_data(\fI\%gearman_task_st\fP\fI\ *task\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_recv_data(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *data\fP, size_t\fI\ data_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_error(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_task_return(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-A \fI\%gearman_task_st\fP represents a \fItask\fP.  Work that is sent by a \fIclient\fP to a gearman server is seen as a task (a \fIworker\fP recieves a task in the form of a \fIjob\fP.
-.sp
-Tasks, i.e. \fI\%gearman_task_st\fP are created by calling either \fBgearman_execute()\fP, \fBgearman_client_add_task()\fP, or \fBgearman_client_add_task_background()\fP.
-.sp
-\fBgearman_client_add_task_status()\fP can also create \fI\%gearman_task_st\fP, these tasks will be used to
-monitor a previously created \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_free()\fP is used to free a task. This only needs to be
-done if a task was created with a preallocated structure or if you want to clean up the memory of a specific task.
-.sp
-\fI\%gearman_task_set_context()\fP sets the given context of the \fI\%gearman_task_st\fP. The context can be used to pass information to a \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_context()\fP returns the context that was used in the creation of the \fI\%gearman_task_st\fP (or that was set with \fI\%gearman_task_set_context()\fP.
-.sp
-\fI\%gearman_task_data()\fP returns the current data that has been returned to the task. \fI\%gearman_task_data_size()\fP will give you the size of the value. \fI\%gearman_task_take_data()\fP is the same as \fI\%gearman_task_data()\fP but the value that is returned must be freed by the client (\fIfree(3)\fP). \fI\%gearman_task_recv_data()\fP can be used with pre\-allocated buffers.
-.sp
-\fI\%gearman_task_is_known()\fP, \fI\%gearman_task_is_running()\fP, \fI\%gearman_task_numerator()\fP, and \fI\%gearman_task_denominator()\fP, return values related to the last status update that was made to the \fI\%gearman_task_st\fP. They do not cause the \fI\%gearman_task_st\fP to update itself.
-.sp
-\fI\%gearman_task_error()\fP return the last error message that the
-\fI\%gearman_task_st\fP encountered. \fI\%gearman_task_return()\fP
-return the last \fBgearman_return_t\fP stored. A value of
-\fBGEARMAN_UNKNOWN_STATE\fP means that the task has not been submitted to
-server yet, or that no function was available if the job has been submitted.
-.SH RETURN VALUE
-.sp
-Various. Values that are returned by \fI\%gearman_task_take_data()\fP must have \fIfree(3)\fP called on them.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_denominator.3'
--- docs/man/gearman_task_denominator.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_denominator.3	1970-01-01 00:00:00 +0000
@@ -1,159 +0,0 @@
-.TH "GEARMAN_TASK_DENOMINATOR" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_denominator \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_free(\fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_context(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_set_context(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_function_name(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_unique(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_job_handle(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_known(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_running(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_numerator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_denominator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_give_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_send_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_task_data(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_data_size(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_take_data(\fI\%gearman_task_st\fP\fI\ *task\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_recv_data(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *data\fP, size_t\fI\ data_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_error(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_task_return(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-A \fI\%gearman_task_st\fP represents a \fItask\fP.  Work that is sent by a \fIclient\fP to a gearman server is seen as a task (a \fIworker\fP recieves a task in the form of a \fIjob\fP.
-.sp
-Tasks, i.e. \fI\%gearman_task_st\fP are created by calling either \fBgearman_execute()\fP, \fBgearman_client_add_task()\fP, or \fBgearman_client_add_task_background()\fP.
-.sp
-\fBgearman_client_add_task_status()\fP can also create \fI\%gearman_task_st\fP, these tasks will be used to
-monitor a previously created \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_free()\fP is used to free a task. This only needs to be
-done if a task was created with a preallocated structure or if you want to clean up the memory of a specific task.
-.sp
-\fI\%gearman_task_set_context()\fP sets the given context of the \fI\%gearman_task_st\fP. The context can be used to pass information to a \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_context()\fP returns the context that was used in the creation of the \fI\%gearman_task_st\fP (or that was set with \fI\%gearman_task_set_context()\fP.
-.sp
-\fI\%gearman_task_data()\fP returns the current data that has been returned to the task. \fI\%gearman_task_data_size()\fP will give you the size of the value. \fI\%gearman_task_take_data()\fP is the same as \fI\%gearman_task_data()\fP but the value that is returned must be freed by the client (\fIfree(3)\fP). \fI\%gearman_task_recv_data()\fP can be used with pre\-allocated buffers.
-.sp
-\fI\%gearman_task_is_known()\fP, \fI\%gearman_task_is_running()\fP, \fI\%gearman_task_numerator()\fP, and \fI\%gearman_task_denominator()\fP, return values related to the last status update that was made to the \fI\%gearman_task_st\fP. They do not cause the \fI\%gearman_task_st\fP to update itself.
-.sp
-\fI\%gearman_task_error()\fP return the last error message that the
-\fI\%gearman_task_st\fP encountered. \fI\%gearman_task_return()\fP
-return the last \fBgearman_return_t\fP stored. A value of
-\fBGEARMAN_UNKNOWN_STATE\fP means that the task has not been submitted to
-server yet, or that no function was available if the job has been submitted.
-.SH RETURN VALUE
-.sp
-Various. Values that are returned by \fI\%gearman_task_take_data()\fP must have \fIfree(3)\fP called on them.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_error.3'
--- docs/man/gearman_task_error.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_error.3	1970-01-01 00:00:00 +0000
@@ -1,159 +0,0 @@
-.TH "GEARMAN_TASK_ERROR" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_error \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_free(\fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_context(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_set_context(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_function_name(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_unique(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_job_handle(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_known(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_running(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_numerator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_denominator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_give_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_send_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_task_data(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_data_size(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_take_data(\fI\%gearman_task_st\fP\fI\ *task\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_recv_data(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *data\fP, size_t\fI\ data_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_error(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_task_return(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-A \fI\%gearman_task_st\fP represents a \fItask\fP.  Work that is sent by a \fIclient\fP to a gearman server is seen as a task (a \fIworker\fP recieves a task in the form of a \fIjob\fP.
-.sp
-Tasks, i.e. \fI\%gearman_task_st\fP are created by calling either \fBgearman_execute()\fP, \fBgearman_client_add_task()\fP, or \fBgearman_client_add_task_background()\fP.
-.sp
-\fBgearman_client_add_task_status()\fP can also create \fI\%gearman_task_st\fP, these tasks will be used to
-monitor a previously created \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_free()\fP is used to free a task. This only needs to be
-done if a task was created with a preallocated structure or if you want to clean up the memory of a specific task.
-.sp
-\fI\%gearman_task_set_context()\fP sets the given context of the \fI\%gearman_task_st\fP. The context can be used to pass information to a \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_context()\fP returns the context that was used in the creation of the \fI\%gearman_task_st\fP (or that was set with \fI\%gearman_task_set_context()\fP.
-.sp
-\fI\%gearman_task_data()\fP returns the current data that has been returned to the task. \fI\%gearman_task_data_size()\fP will give you the size of the value. \fI\%gearman_task_take_data()\fP is the same as \fI\%gearman_task_data()\fP but the value that is returned must be freed by the client (\fIfree(3)\fP). \fI\%gearman_task_recv_data()\fP can be used with pre\-allocated buffers.
-.sp
-\fI\%gearman_task_is_known()\fP, \fI\%gearman_task_is_running()\fP, \fI\%gearman_task_numerator()\fP, and \fI\%gearman_task_denominator()\fP, return values related to the last status update that was made to the \fI\%gearman_task_st\fP. They do not cause the \fI\%gearman_task_st\fP to update itself.
-.sp
-\fI\%gearman_task_error()\fP return the last error message that the
-\fI\%gearman_task_st\fP encountered. \fI\%gearman_task_return()\fP
-return the last \fBgearman_return_t\fP stored. A value of
-\fBGEARMAN_UNKNOWN_STATE\fP means that the task has not been submitted to
-server yet, or that no function was available if the job has been submitted.
-.SH RETURN VALUE
-.sp
-Various. Values that are returned by \fI\%gearman_task_take_data()\fP must have \fIfree(3)\fP called on them.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_free.3'
--- docs/man/gearman_task_free.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_free.3	1970-01-01 00:00:00 +0000
@@ -1,159 +0,0 @@
-.TH "GEARMAN_TASK_FREE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_free \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_free(\fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_context(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_set_context(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_function_name(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_unique(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_job_handle(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_known(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_running(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_numerator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_denominator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_give_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_send_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_task_data(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_data_size(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_take_data(\fI\%gearman_task_st\fP\fI\ *task\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_recv_data(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *data\fP, size_t\fI\ data_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_error(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_task_return(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-A \fI\%gearman_task_st\fP represents a \fItask\fP.  Work that is sent by a \fIclient\fP to a gearman server is seen as a task (a \fIworker\fP recieves a task in the form of a \fIjob\fP.
-.sp
-Tasks, i.e. \fI\%gearman_task_st\fP are created by calling either \fBgearman_execute()\fP, \fBgearman_client_add_task()\fP, or \fBgearman_client_add_task_background()\fP.
-.sp
-\fBgearman_client_add_task_status()\fP can also create \fI\%gearman_task_st\fP, these tasks will be used to
-monitor a previously created \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_free()\fP is used to free a task. This only needs to be
-done if a task was created with a preallocated structure or if you want to clean up the memory of a specific task.
-.sp
-\fI\%gearman_task_set_context()\fP sets the given context of the \fI\%gearman_task_st\fP. The context can be used to pass information to a \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_context()\fP returns the context that was used in the creation of the \fI\%gearman_task_st\fP (or that was set with \fI\%gearman_task_set_context()\fP.
-.sp
-\fI\%gearman_task_data()\fP returns the current data that has been returned to the task. \fI\%gearman_task_data_size()\fP will give you the size of the value. \fI\%gearman_task_take_data()\fP is the same as \fI\%gearman_task_data()\fP but the value that is returned must be freed by the client (\fIfree(3)\fP). \fI\%gearman_task_recv_data()\fP can be used with pre\-allocated buffers.
-.sp
-\fI\%gearman_task_is_known()\fP, \fI\%gearman_task_is_running()\fP, \fI\%gearman_task_numerator()\fP, and \fI\%gearman_task_denominator()\fP, return values related to the last status update that was made to the \fI\%gearman_task_st\fP. They do not cause the \fI\%gearman_task_st\fP to update itself.
-.sp
-\fI\%gearman_task_error()\fP return the last error message that the
-\fI\%gearman_task_st\fP encountered. \fI\%gearman_task_return()\fP
-return the last \fBgearman_return_t\fP stored. A value of
-\fBGEARMAN_UNKNOWN_STATE\fP means that the task has not been submitted to
-server yet, or that no function was available if the job has been submitted.
-.SH RETURN VALUE
-.sp
-Various. Values that are returned by \fI\%gearman_task_take_data()\fP must have \fIfree(3)\fP called on them.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_function_name.3'
--- docs/man/gearman_task_function_name.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_function_name.3	1970-01-01 00:00:00 +0000
@@ -1,159 +0,0 @@
-.TH "GEARMAN_TASK_FUNCTION_NAME" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_function_name \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_free(\fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_context(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_set_context(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_function_name(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_unique(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_job_handle(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_known(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_running(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_numerator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_denominator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_give_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_send_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_task_data(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_data_size(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_take_data(\fI\%gearman_task_st\fP\fI\ *task\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_recv_data(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *data\fP, size_t\fI\ data_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_error(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_task_return(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-A \fI\%gearman_task_st\fP represents a \fItask\fP.  Work that is sent by a \fIclient\fP to a gearman server is seen as a task (a \fIworker\fP recieves a task in the form of a \fIjob\fP.
-.sp
-Tasks, i.e. \fI\%gearman_task_st\fP are created by calling either \fBgearman_execute()\fP, \fBgearman_client_add_task()\fP, or \fBgearman_client_add_task_background()\fP.
-.sp
-\fBgearman_client_add_task_status()\fP can also create \fI\%gearman_task_st\fP, these tasks will be used to
-monitor a previously created \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_free()\fP is used to free a task. This only needs to be
-done if a task was created with a preallocated structure or if you want to clean up the memory of a specific task.
-.sp
-\fI\%gearman_task_set_context()\fP sets the given context of the \fI\%gearman_task_st\fP. The context can be used to pass information to a \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_context()\fP returns the context that was used in the creation of the \fI\%gearman_task_st\fP (or that was set with \fI\%gearman_task_set_context()\fP.
-.sp
-\fI\%gearman_task_data()\fP returns the current data that has been returned to the task. \fI\%gearman_task_data_size()\fP will give you the size of the value. \fI\%gearman_task_take_data()\fP is the same as \fI\%gearman_task_data()\fP but the value that is returned must be freed by the client (\fIfree(3)\fP). \fI\%gearman_task_recv_data()\fP can be used with pre\-allocated buffers.
-.sp
-\fI\%gearman_task_is_known()\fP, \fI\%gearman_task_is_running()\fP, \fI\%gearman_task_numerator()\fP, and \fI\%gearman_task_denominator()\fP, return values related to the last status update that was made to the \fI\%gearman_task_st\fP. They do not cause the \fI\%gearman_task_st\fP to update itself.
-.sp
-\fI\%gearman_task_error()\fP return the last error message that the
-\fI\%gearman_task_st\fP encountered. \fI\%gearman_task_return()\fP
-return the last \fBgearman_return_t\fP stored. A value of
-\fBGEARMAN_UNKNOWN_STATE\fP means that the task has not been submitted to
-server yet, or that no function was available if the job has been submitted.
-.SH RETURN VALUE
-.sp
-Various. Values that are returned by \fI\%gearman_task_take_data()\fP must have \fIfree(3)\fP called on them.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_give_workload.3'
--- docs/man/gearman_task_give_workload.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_give_workload.3	1970-01-01 00:00:00 +0000
@@ -1,159 +0,0 @@
-.TH "GEARMAN_TASK_GIVE_WORKLOAD" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_give_workload \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_free(\fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_context(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_set_context(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_function_name(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_unique(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_job_handle(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_known(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_running(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_numerator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_denominator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_give_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_send_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_task_data(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_data_size(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_take_data(\fI\%gearman_task_st\fP\fI\ *task\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_recv_data(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *data\fP, size_t\fI\ data_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_error(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_task_return(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-A \fI\%gearman_task_st\fP represents a \fItask\fP.  Work that is sent by a \fIclient\fP to a gearman server is seen as a task (a \fIworker\fP recieves a task in the form of a \fIjob\fP.
-.sp
-Tasks, i.e. \fI\%gearman_task_st\fP are created by calling either \fBgearman_execute()\fP, \fBgearman_client_add_task()\fP, or \fBgearman_client_add_task_background()\fP.
-.sp
-\fBgearman_client_add_task_status()\fP can also create \fI\%gearman_task_st\fP, these tasks will be used to
-monitor a previously created \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_free()\fP is used to free a task. This only needs to be
-done if a task was created with a preallocated structure or if you want to clean up the memory of a specific task.
-.sp
-\fI\%gearman_task_set_context()\fP sets the given context of the \fI\%gearman_task_st\fP. The context can be used to pass information to a \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_context()\fP returns the context that was used in the creation of the \fI\%gearman_task_st\fP (or that was set with \fI\%gearman_task_set_context()\fP.
-.sp
-\fI\%gearman_task_data()\fP returns the current data that has been returned to the task. \fI\%gearman_task_data_size()\fP will give you the size of the value. \fI\%gearman_task_take_data()\fP is the same as \fI\%gearman_task_data()\fP but the value that is returned must be freed by the client (\fIfree(3)\fP). \fI\%gearman_task_recv_data()\fP can be used with pre\-allocated buffers.
-.sp
-\fI\%gearman_task_is_known()\fP, \fI\%gearman_task_is_running()\fP, \fI\%gearman_task_numerator()\fP, and \fI\%gearman_task_denominator()\fP, return values related to the last status update that was made to the \fI\%gearman_task_st\fP. They do not cause the \fI\%gearman_task_st\fP to update itself.
-.sp
-\fI\%gearman_task_error()\fP return the last error message that the
-\fI\%gearman_task_st\fP encountered. \fI\%gearman_task_return()\fP
-return the last \fBgearman_return_t\fP stored. A value of
-\fBGEARMAN_UNKNOWN_STATE\fP means that the task has not been submitted to
-server yet, or that no function was available if the job has been submitted.
-.SH RETURN VALUE
-.sp
-Various. Values that are returned by \fI\%gearman_task_take_data()\fP must have \fIfree(3)\fP called on them.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_is_known.3'
--- docs/man/gearman_task_is_known.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_is_known.3	1970-01-01 00:00:00 +0000
@@ -1,159 +0,0 @@
-.TH "GEARMAN_TASK_IS_KNOWN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_is_known \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_free(\fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_context(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_set_context(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_function_name(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_unique(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_job_handle(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_known(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_running(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_numerator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_denominator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_give_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_send_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_task_data(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_data_size(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_take_data(\fI\%gearman_task_st\fP\fI\ *task\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_recv_data(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *data\fP, size_t\fI\ data_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_error(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_task_return(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-A \fI\%gearman_task_st\fP represents a \fItask\fP.  Work that is sent by a \fIclient\fP to a gearman server is seen as a task (a \fIworker\fP recieves a task in the form of a \fIjob\fP.
-.sp
-Tasks, i.e. \fI\%gearman_task_st\fP are created by calling either \fBgearman_execute()\fP, \fBgearman_client_add_task()\fP, or \fBgearman_client_add_task_background()\fP.
-.sp
-\fBgearman_client_add_task_status()\fP can also create \fI\%gearman_task_st\fP, these tasks will be used to
-monitor a previously created \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_free()\fP is used to free a task. This only needs to be
-done if a task was created with a preallocated structure or if you want to clean up the memory of a specific task.
-.sp
-\fI\%gearman_task_set_context()\fP sets the given context of the \fI\%gearman_task_st\fP. The context can be used to pass information to a \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_context()\fP returns the context that was used in the creation of the \fI\%gearman_task_st\fP (or that was set with \fI\%gearman_task_set_context()\fP.
-.sp
-\fI\%gearman_task_data()\fP returns the current data that has been returned to the task. \fI\%gearman_task_data_size()\fP will give you the size of the value. \fI\%gearman_task_take_data()\fP is the same as \fI\%gearman_task_data()\fP but the value that is returned must be freed by the client (\fIfree(3)\fP). \fI\%gearman_task_recv_data()\fP can be used with pre\-allocated buffers.
-.sp
-\fI\%gearman_task_is_known()\fP, \fI\%gearman_task_is_running()\fP, \fI\%gearman_task_numerator()\fP, and \fI\%gearman_task_denominator()\fP, return values related to the last status update that was made to the \fI\%gearman_task_st\fP. They do not cause the \fI\%gearman_task_st\fP to update itself.
-.sp
-\fI\%gearman_task_error()\fP return the last error message that the
-\fI\%gearman_task_st\fP encountered. \fI\%gearman_task_return()\fP
-return the last \fBgearman_return_t\fP stored. A value of
-\fBGEARMAN_UNKNOWN_STATE\fP means that the task has not been submitted to
-server yet, or that no function was available if the job has been submitted.
-.SH RETURN VALUE
-.sp
-Various. Values that are returned by \fI\%gearman_task_take_data()\fP must have \fIfree(3)\fP called on them.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_is_running.3'
--- docs/man/gearman_task_is_running.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_is_running.3	1970-01-01 00:00:00 +0000
@@ -1,159 +0,0 @@
-.TH "GEARMAN_TASK_IS_RUNNING" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_is_running \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_free(\fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_context(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_set_context(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_function_name(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_unique(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_job_handle(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_known(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_running(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_numerator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_denominator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_give_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_send_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_task_data(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_data_size(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_take_data(\fI\%gearman_task_st\fP\fI\ *task\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_recv_data(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *data\fP, size_t\fI\ data_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_error(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_task_return(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-A \fI\%gearman_task_st\fP represents a \fItask\fP.  Work that is sent by a \fIclient\fP to a gearman server is seen as a task (a \fIworker\fP recieves a task in the form of a \fIjob\fP.
-.sp
-Tasks, i.e. \fI\%gearman_task_st\fP are created by calling either \fBgearman_execute()\fP, \fBgearman_client_add_task()\fP, or \fBgearman_client_add_task_background()\fP.
-.sp
-\fBgearman_client_add_task_status()\fP can also create \fI\%gearman_task_st\fP, these tasks will be used to
-monitor a previously created \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_free()\fP is used to free a task. This only needs to be
-done if a task was created with a preallocated structure or if you want to clean up the memory of a specific task.
-.sp
-\fI\%gearman_task_set_context()\fP sets the given context of the \fI\%gearman_task_st\fP. The context can be used to pass information to a \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_context()\fP returns the context that was used in the creation of the \fI\%gearman_task_st\fP (or that was set with \fI\%gearman_task_set_context()\fP.
-.sp
-\fI\%gearman_task_data()\fP returns the current data that has been returned to the task. \fI\%gearman_task_data_size()\fP will give you the size of the value. \fI\%gearman_task_take_data()\fP is the same as \fI\%gearman_task_data()\fP but the value that is returned must be freed by the client (\fIfree(3)\fP). \fI\%gearman_task_recv_data()\fP can be used with pre\-allocated buffers.
-.sp
-\fI\%gearman_task_is_known()\fP, \fI\%gearman_task_is_running()\fP, \fI\%gearman_task_numerator()\fP, and \fI\%gearman_task_denominator()\fP, return values related to the last status update that was made to the \fI\%gearman_task_st\fP. They do not cause the \fI\%gearman_task_st\fP to update itself.
-.sp
-\fI\%gearman_task_error()\fP return the last error message that the
-\fI\%gearman_task_st\fP encountered. \fI\%gearman_task_return()\fP
-return the last \fBgearman_return_t\fP stored. A value of
-\fBGEARMAN_UNKNOWN_STATE\fP means that the task has not been submitted to
-server yet, or that no function was available if the job has been submitted.
-.SH RETURN VALUE
-.sp
-Various. Values that are returned by \fI\%gearman_task_take_data()\fP must have \fIfree(3)\fP called on them.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_job_handle.3'
--- docs/man/gearman_task_job_handle.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_job_handle.3	1970-01-01 00:00:00 +0000
@@ -1,159 +0,0 @@
-.TH "GEARMAN_TASK_JOB_HANDLE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_job_handle \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_free(\fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_context(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_set_context(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_function_name(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_unique(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_job_handle(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_known(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_running(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_numerator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_denominator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_give_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_send_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_task_data(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_data_size(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_take_data(\fI\%gearman_task_st\fP\fI\ *task\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_recv_data(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *data\fP, size_t\fI\ data_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_error(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_task_return(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-A \fI\%gearman_task_st\fP represents a \fItask\fP.  Work that is sent by a \fIclient\fP to a gearman server is seen as a task (a \fIworker\fP recieves a task in the form of a \fIjob\fP.
-.sp
-Tasks, i.e. \fI\%gearman_task_st\fP are created by calling either \fBgearman_execute()\fP, \fBgearman_client_add_task()\fP, or \fBgearman_client_add_task_background()\fP.
-.sp
-\fBgearman_client_add_task_status()\fP can also create \fI\%gearman_task_st\fP, these tasks will be used to
-monitor a previously created \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_free()\fP is used to free a task. This only needs to be
-done if a task was created with a preallocated structure or if you want to clean up the memory of a specific task.
-.sp
-\fI\%gearman_task_set_context()\fP sets the given context of the \fI\%gearman_task_st\fP. The context can be used to pass information to a \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_context()\fP returns the context that was used in the creation of the \fI\%gearman_task_st\fP (or that was set with \fI\%gearman_task_set_context()\fP.
-.sp
-\fI\%gearman_task_data()\fP returns the current data that has been returned to the task. \fI\%gearman_task_data_size()\fP will give you the size of the value. \fI\%gearman_task_take_data()\fP is the same as \fI\%gearman_task_data()\fP but the value that is returned must be freed by the client (\fIfree(3)\fP). \fI\%gearman_task_recv_data()\fP can be used with pre\-allocated buffers.
-.sp
-\fI\%gearman_task_is_known()\fP, \fI\%gearman_task_is_running()\fP, \fI\%gearman_task_numerator()\fP, and \fI\%gearman_task_denominator()\fP, return values related to the last status update that was made to the \fI\%gearman_task_st\fP. They do not cause the \fI\%gearman_task_st\fP to update itself.
-.sp
-\fI\%gearman_task_error()\fP return the last error message that the
-\fI\%gearman_task_st\fP encountered. \fI\%gearman_task_return()\fP
-return the last \fBgearman_return_t\fP stored. A value of
-\fBGEARMAN_UNKNOWN_STATE\fP means that the task has not been submitted to
-server yet, or that no function was available if the job has been submitted.
-.SH RETURN VALUE
-.sp
-Various. Values that are returned by \fI\%gearman_task_take_data()\fP must have \fIfree(3)\fP called on them.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_numerator.3'
--- docs/man/gearman_task_numerator.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_numerator.3	1970-01-01 00:00:00 +0000
@@ -1,159 +0,0 @@
-.TH "GEARMAN_TASK_NUMERATOR" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_numerator \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_free(\fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_context(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_set_context(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_function_name(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_unique(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_job_handle(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_known(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_running(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_numerator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_denominator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_give_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_send_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_task_data(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_data_size(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_take_data(\fI\%gearman_task_st\fP\fI\ *task\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_recv_data(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *data\fP, size_t\fI\ data_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_error(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_task_return(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-A \fI\%gearman_task_st\fP represents a \fItask\fP.  Work that is sent by a \fIclient\fP to a gearman server is seen as a task (a \fIworker\fP recieves a task in the form of a \fIjob\fP.
-.sp
-Tasks, i.e. \fI\%gearman_task_st\fP are created by calling either \fBgearman_execute()\fP, \fBgearman_client_add_task()\fP, or \fBgearman_client_add_task_background()\fP.
-.sp
-\fBgearman_client_add_task_status()\fP can also create \fI\%gearman_task_st\fP, these tasks will be used to
-monitor a previously created \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_free()\fP is used to free a task. This only needs to be
-done if a task was created with a preallocated structure or if you want to clean up the memory of a specific task.
-.sp
-\fI\%gearman_task_set_context()\fP sets the given context of the \fI\%gearman_task_st\fP. The context can be used to pass information to a \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_context()\fP returns the context that was used in the creation of the \fI\%gearman_task_st\fP (or that was set with \fI\%gearman_task_set_context()\fP.
-.sp
-\fI\%gearman_task_data()\fP returns the current data that has been returned to the task. \fI\%gearman_task_data_size()\fP will give you the size of the value. \fI\%gearman_task_take_data()\fP is the same as \fI\%gearman_task_data()\fP but the value that is returned must be freed by the client (\fIfree(3)\fP). \fI\%gearman_task_recv_data()\fP can be used with pre\-allocated buffers.
-.sp
-\fI\%gearman_task_is_known()\fP, \fI\%gearman_task_is_running()\fP, \fI\%gearman_task_numerator()\fP, and \fI\%gearman_task_denominator()\fP, return values related to the last status update that was made to the \fI\%gearman_task_st\fP. They do not cause the \fI\%gearman_task_st\fP to update itself.
-.sp
-\fI\%gearman_task_error()\fP return the last error message that the
-\fI\%gearman_task_st\fP encountered. \fI\%gearman_task_return()\fP
-return the last \fBgearman_return_t\fP stored. A value of
-\fBGEARMAN_UNKNOWN_STATE\fP means that the task has not been submitted to
-server yet, or that no function was available if the job has been submitted.
-.SH RETURN VALUE
-.sp
-Various. Values that are returned by \fI\%gearman_task_take_data()\fP must have \fIfree(3)\fP called on them.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_recv_data.3'
--- docs/man/gearman_task_recv_data.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_recv_data.3	1970-01-01 00:00:00 +0000
@@ -1,159 +0,0 @@
-.TH "GEARMAN_TASK_RECV_DATA" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_recv_data \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_free(\fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_context(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_set_context(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_function_name(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_unique(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_job_handle(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_known(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_running(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_numerator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_denominator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_give_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_send_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_task_data(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_data_size(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_take_data(\fI\%gearman_task_st\fP\fI\ *task\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_recv_data(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *data\fP, size_t\fI\ data_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_error(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_task_return(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-A \fI\%gearman_task_st\fP represents a \fItask\fP.  Work that is sent by a \fIclient\fP to a gearman server is seen as a task (a \fIworker\fP recieves a task in the form of a \fIjob\fP.
-.sp
-Tasks, i.e. \fI\%gearman_task_st\fP are created by calling either \fBgearman_execute()\fP, \fBgearman_client_add_task()\fP, or \fBgearman_client_add_task_background()\fP.
-.sp
-\fBgearman_client_add_task_status()\fP can also create \fI\%gearman_task_st\fP, these tasks will be used to
-monitor a previously created \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_free()\fP is used to free a task. This only needs to be
-done if a task was created with a preallocated structure or if you want to clean up the memory of a specific task.
-.sp
-\fI\%gearman_task_set_context()\fP sets the given context of the \fI\%gearman_task_st\fP. The context can be used to pass information to a \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_context()\fP returns the context that was used in the creation of the \fI\%gearman_task_st\fP (or that was set with \fI\%gearman_task_set_context()\fP.
-.sp
-\fI\%gearman_task_data()\fP returns the current data that has been returned to the task. \fI\%gearman_task_data_size()\fP will give you the size of the value. \fI\%gearman_task_take_data()\fP is the same as \fI\%gearman_task_data()\fP but the value that is returned must be freed by the client (\fIfree(3)\fP). \fI\%gearman_task_recv_data()\fP can be used with pre\-allocated buffers.
-.sp
-\fI\%gearman_task_is_known()\fP, \fI\%gearman_task_is_running()\fP, \fI\%gearman_task_numerator()\fP, and \fI\%gearman_task_denominator()\fP, return values related to the last status update that was made to the \fI\%gearman_task_st\fP. They do not cause the \fI\%gearman_task_st\fP to update itself.
-.sp
-\fI\%gearman_task_error()\fP return the last error message that the
-\fI\%gearman_task_st\fP encountered. \fI\%gearman_task_return()\fP
-return the last \fBgearman_return_t\fP stored. A value of
-\fBGEARMAN_UNKNOWN_STATE\fP means that the task has not been submitted to
-server yet, or that no function was available if the job has been submitted.
-.SH RETURN VALUE
-.sp
-Various. Values that are returned by \fI\%gearman_task_take_data()\fP must have \fIfree(3)\fP called on them.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_return.3'
--- docs/man/gearman_task_return.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_return.3	1970-01-01 00:00:00 +0000
@@ -1,159 +0,0 @@
-.TH "GEARMAN_TASK_RETURN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_return \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_free(\fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_context(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_set_context(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_function_name(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_unique(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_job_handle(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_known(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_running(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_numerator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_denominator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_give_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_send_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_task_data(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_data_size(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_take_data(\fI\%gearman_task_st\fP\fI\ *task\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_recv_data(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *data\fP, size_t\fI\ data_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_error(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_task_return(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-A \fI\%gearman_task_st\fP represents a \fItask\fP.  Work that is sent by a \fIclient\fP to a gearman server is seen as a task (a \fIworker\fP recieves a task in the form of a \fIjob\fP.
-.sp
-Tasks, i.e. \fI\%gearman_task_st\fP are created by calling either \fBgearman_execute()\fP, \fBgearman_client_add_task()\fP, or \fBgearman_client_add_task_background()\fP.
-.sp
-\fBgearman_client_add_task_status()\fP can also create \fI\%gearman_task_st\fP, these tasks will be used to
-monitor a previously created \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_free()\fP is used to free a task. This only needs to be
-done if a task was created with a preallocated structure or if you want to clean up the memory of a specific task.
-.sp
-\fI\%gearman_task_set_context()\fP sets the given context of the \fI\%gearman_task_st\fP. The context can be used to pass information to a \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_context()\fP returns the context that was used in the creation of the \fI\%gearman_task_st\fP (or that was set with \fI\%gearman_task_set_context()\fP.
-.sp
-\fI\%gearman_task_data()\fP returns the current data that has been returned to the task. \fI\%gearman_task_data_size()\fP will give you the size of the value. \fI\%gearman_task_take_data()\fP is the same as \fI\%gearman_task_data()\fP but the value that is returned must be freed by the client (\fIfree(3)\fP). \fI\%gearman_task_recv_data()\fP can be used with pre\-allocated buffers.
-.sp
-\fI\%gearman_task_is_known()\fP, \fI\%gearman_task_is_running()\fP, \fI\%gearman_task_numerator()\fP, and \fI\%gearman_task_denominator()\fP, return values related to the last status update that was made to the \fI\%gearman_task_st\fP. They do not cause the \fI\%gearman_task_st\fP to update itself.
-.sp
-\fI\%gearman_task_error()\fP return the last error message that the
-\fI\%gearman_task_st\fP encountered. \fI\%gearman_task_return()\fP
-return the last \fBgearman_return_t\fP stored. A value of
-\fBGEARMAN_UNKNOWN_STATE\fP means that the task has not been submitted to
-server yet, or that no function was available if the job has been submitted.
-.SH RETURN VALUE
-.sp
-Various. Values that are returned by \fI\%gearman_task_take_data()\fP must have \fIfree(3)\fP called on them.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_send_workload.3'
--- docs/man/gearman_task_send_workload.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_send_workload.3	1970-01-01 00:00:00 +0000
@@ -1,159 +0,0 @@
-.TH "GEARMAN_TASK_SEND_WORKLOAD" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_send_workload \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_free(\fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_context(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_set_context(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_function_name(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_unique(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_job_handle(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_known(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_running(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_numerator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_denominator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_give_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_send_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_task_data(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_data_size(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_take_data(\fI\%gearman_task_st\fP\fI\ *task\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_recv_data(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *data\fP, size_t\fI\ data_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_error(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_task_return(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-A \fI\%gearman_task_st\fP represents a \fItask\fP.  Work that is sent by a \fIclient\fP to a gearman server is seen as a task (a \fIworker\fP recieves a task in the form of a \fIjob\fP.
-.sp
-Tasks, i.e. \fI\%gearman_task_st\fP are created by calling either \fBgearman_execute()\fP, \fBgearman_client_add_task()\fP, or \fBgearman_client_add_task_background()\fP.
-.sp
-\fBgearman_client_add_task_status()\fP can also create \fI\%gearman_task_st\fP, these tasks will be used to
-monitor a previously created \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_free()\fP is used to free a task. This only needs to be
-done if a task was created with a preallocated structure or if you want to clean up the memory of a specific task.
-.sp
-\fI\%gearman_task_set_context()\fP sets the given context of the \fI\%gearman_task_st\fP. The context can be used to pass information to a \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_context()\fP returns the context that was used in the creation of the \fI\%gearman_task_st\fP (or that was set with \fI\%gearman_task_set_context()\fP.
-.sp
-\fI\%gearman_task_data()\fP returns the current data that has been returned to the task. \fI\%gearman_task_data_size()\fP will give you the size of the value. \fI\%gearman_task_take_data()\fP is the same as \fI\%gearman_task_data()\fP but the value that is returned must be freed by the client (\fIfree(3)\fP). \fI\%gearman_task_recv_data()\fP can be used with pre\-allocated buffers.
-.sp
-\fI\%gearman_task_is_known()\fP, \fI\%gearman_task_is_running()\fP, \fI\%gearman_task_numerator()\fP, and \fI\%gearman_task_denominator()\fP, return values related to the last status update that was made to the \fI\%gearman_task_st\fP. They do not cause the \fI\%gearman_task_st\fP to update itself.
-.sp
-\fI\%gearman_task_error()\fP return the last error message that the
-\fI\%gearman_task_st\fP encountered. \fI\%gearman_task_return()\fP
-return the last \fBgearman_return_t\fP stored. A value of
-\fBGEARMAN_UNKNOWN_STATE\fP means that the task has not been submitted to
-server yet, or that no function was available if the job has been submitted.
-.SH RETURN VALUE
-.sp
-Various. Values that are returned by \fI\%gearman_task_take_data()\fP must have \fIfree(3)\fP called on them.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_set_context.3'
--- docs/man/gearman_task_set_context.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_set_context.3	1970-01-01 00:00:00 +0000
@@ -1,159 +0,0 @@
-.TH "GEARMAN_TASK_SET_CONTEXT" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_set_context \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_free(\fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_context(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_set_context(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_function_name(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_unique(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_job_handle(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_known(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_running(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_numerator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_denominator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_give_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_send_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_task_data(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_data_size(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_take_data(\fI\%gearman_task_st\fP\fI\ *task\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_recv_data(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *data\fP, size_t\fI\ data_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_error(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_task_return(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-A \fI\%gearman_task_st\fP represents a \fItask\fP.  Work that is sent by a \fIclient\fP to a gearman server is seen as a task (a \fIworker\fP recieves a task in the form of a \fIjob\fP.
-.sp
-Tasks, i.e. \fI\%gearman_task_st\fP are created by calling either \fBgearman_execute()\fP, \fBgearman_client_add_task()\fP, or \fBgearman_client_add_task_background()\fP.
-.sp
-\fBgearman_client_add_task_status()\fP can also create \fI\%gearman_task_st\fP, these tasks will be used to
-monitor a previously created \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_free()\fP is used to free a task. This only needs to be
-done if a task was created with a preallocated structure or if you want to clean up the memory of a specific task.
-.sp
-\fI\%gearman_task_set_context()\fP sets the given context of the \fI\%gearman_task_st\fP. The context can be used to pass information to a \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_context()\fP returns the context that was used in the creation of the \fI\%gearman_task_st\fP (or that was set with \fI\%gearman_task_set_context()\fP.
-.sp
-\fI\%gearman_task_data()\fP returns the current data that has been returned to the task. \fI\%gearman_task_data_size()\fP will give you the size of the value. \fI\%gearman_task_take_data()\fP is the same as \fI\%gearman_task_data()\fP but the value that is returned must be freed by the client (\fIfree(3)\fP). \fI\%gearman_task_recv_data()\fP can be used with pre\-allocated buffers.
-.sp
-\fI\%gearman_task_is_known()\fP, \fI\%gearman_task_is_running()\fP, \fI\%gearman_task_numerator()\fP, and \fI\%gearman_task_denominator()\fP, return values related to the last status update that was made to the \fI\%gearman_task_st\fP. They do not cause the \fI\%gearman_task_st\fP to update itself.
-.sp
-\fI\%gearman_task_error()\fP return the last error message that the
-\fI\%gearman_task_st\fP encountered. \fI\%gearman_task_return()\fP
-return the last \fBgearman_return_t\fP stored. A value of
-\fBGEARMAN_UNKNOWN_STATE\fP means that the task has not been submitted to
-server yet, or that no function was available if the job has been submitted.
-.SH RETURN VALUE
-.sp
-Various. Values that are returned by \fI\%gearman_task_take_data()\fP must have \fIfree(3)\fP called on them.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_st.3'
--- docs/man/gearman_task_st.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_st.3	1970-01-01 00:00:00 +0000
@@ -1,159 +0,0 @@
-.TH "GEARMAN_TASK_ST" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_st \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_free(\fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_context(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_set_context(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_function_name(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_unique(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_job_handle(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_known(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_running(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_numerator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_denominator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_give_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_send_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_task_data(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_data_size(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_take_data(\fI\%gearman_task_st\fP\fI\ *task\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_recv_data(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *data\fP, size_t\fI\ data_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_error(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_task_return(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-A \fI\%gearman_task_st\fP represents a \fItask\fP.  Work that is sent by a \fIclient\fP to a gearman server is seen as a task (a \fIworker\fP recieves a task in the form of a \fIjob\fP.
-.sp
-Tasks, i.e. \fI\%gearman_task_st\fP are created by calling either \fBgearman_execute()\fP, \fBgearman_client_add_task()\fP, or \fBgearman_client_add_task_background()\fP.
-.sp
-\fBgearman_client_add_task_status()\fP can also create \fI\%gearman_task_st\fP, these tasks will be used to
-monitor a previously created \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_free()\fP is used to free a task. This only needs to be
-done if a task was created with a preallocated structure or if you want to clean up the memory of a specific task.
-.sp
-\fI\%gearman_task_set_context()\fP sets the given context of the \fI\%gearman_task_st\fP. The context can be used to pass information to a \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_context()\fP returns the context that was used in the creation of the \fI\%gearman_task_st\fP (or that was set with \fI\%gearman_task_set_context()\fP.
-.sp
-\fI\%gearman_task_data()\fP returns the current data that has been returned to the task. \fI\%gearman_task_data_size()\fP will give you the size of the value. \fI\%gearman_task_take_data()\fP is the same as \fI\%gearman_task_data()\fP but the value that is returned must be freed by the client (\fIfree(3)\fP). \fI\%gearman_task_recv_data()\fP can be used with pre\-allocated buffers.
-.sp
-\fI\%gearman_task_is_known()\fP, \fI\%gearman_task_is_running()\fP, \fI\%gearman_task_numerator()\fP, and \fI\%gearman_task_denominator()\fP, return values related to the last status update that was made to the \fI\%gearman_task_st\fP. They do not cause the \fI\%gearman_task_st\fP to update itself.
-.sp
-\fI\%gearman_task_error()\fP return the last error message that the
-\fI\%gearman_task_st\fP encountered. \fI\%gearman_task_return()\fP
-return the last \fBgearman_return_t\fP stored. A value of
-\fBGEARMAN_UNKNOWN_STATE\fP means that the task has not been submitted to
-server yet, or that no function was available if the job has been submitted.
-.SH RETURN VALUE
-.sp
-Various. Values that are returned by \fI\%gearman_task_take_data()\fP must have \fIfree(3)\fP called on them.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_take_data.3'
--- docs/man/gearman_task_take_data.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_take_data.3	1970-01-01 00:00:00 +0000
@@ -1,159 +0,0 @@
-.TH "GEARMAN_TASK_TAKE_DATA" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_take_data \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_free(\fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_context(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_set_context(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_function_name(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_unique(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_job_handle(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_known(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_running(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_numerator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_denominator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_give_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_send_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_task_data(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_data_size(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_take_data(\fI\%gearman_task_st\fP\fI\ *task\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_recv_data(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *data\fP, size_t\fI\ data_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_error(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_task_return(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-A \fI\%gearman_task_st\fP represents a \fItask\fP.  Work that is sent by a \fIclient\fP to a gearman server is seen as a task (a \fIworker\fP recieves a task in the form of a \fIjob\fP.
-.sp
-Tasks, i.e. \fI\%gearman_task_st\fP are created by calling either \fBgearman_execute()\fP, \fBgearman_client_add_task()\fP, or \fBgearman_client_add_task_background()\fP.
-.sp
-\fBgearman_client_add_task_status()\fP can also create \fI\%gearman_task_st\fP, these tasks will be used to
-monitor a previously created \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_free()\fP is used to free a task. This only needs to be
-done if a task was created with a preallocated structure or if you want to clean up the memory of a specific task.
-.sp
-\fI\%gearman_task_set_context()\fP sets the given context of the \fI\%gearman_task_st\fP. The context can be used to pass information to a \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_context()\fP returns the context that was used in the creation of the \fI\%gearman_task_st\fP (or that was set with \fI\%gearman_task_set_context()\fP.
-.sp
-\fI\%gearman_task_data()\fP returns the current data that has been returned to the task. \fI\%gearman_task_data_size()\fP will give you the size of the value. \fI\%gearman_task_take_data()\fP is the same as \fI\%gearman_task_data()\fP but the value that is returned must be freed by the client (\fIfree(3)\fP). \fI\%gearman_task_recv_data()\fP can be used with pre\-allocated buffers.
-.sp
-\fI\%gearman_task_is_known()\fP, \fI\%gearman_task_is_running()\fP, \fI\%gearman_task_numerator()\fP, and \fI\%gearman_task_denominator()\fP, return values related to the last status update that was made to the \fI\%gearman_task_st\fP. They do not cause the \fI\%gearman_task_st\fP to update itself.
-.sp
-\fI\%gearman_task_error()\fP return the last error message that the
-\fI\%gearman_task_st\fP encountered. \fI\%gearman_task_return()\fP
-return the last \fBgearman_return_t\fP stored. A value of
-\fBGEARMAN_UNKNOWN_STATE\fP means that the task has not been submitted to
-server yet, or that no function was available if the job has been submitted.
-.SH RETURN VALUE
-.sp
-Various. Values that are returned by \fI\%gearman_task_take_data()\fP must have \fIfree(3)\fP called on them.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_task_unique.3'
--- docs/man/gearman_task_unique.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_task_unique.3	1970-01-01 00:00:00 +0000
@@ -1,159 +0,0 @@
-.TH "GEARMAN_TASK_UNIQUE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_task_unique \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_task_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_free(\fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_context(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_set_context(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_function_name(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_unique(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_job_handle(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_known(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_task_is_running(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_numerator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B uint32_t gearman_task_denominator(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_task_give_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_send_workload(\fI\%gearman_task_st\fP\fI\ *task\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const void *gearman_task_data(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_data_size(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_task_take_data(\fI\%gearman_task_st\fP\fI\ *task\fP, size_t\fI\ *data_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B size_t gearman_task_recv_data(\fI\%gearman_task_st\fP\fI\ *task\fP, void\fI\ *data\fP, size_t\fI\ data_size\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_task_error(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_task_return(const \fI\%gearman_task_st\fP\fI\ *task\fP)
-.UNINDENT
-.sp
-New in version 0.21.
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-A \fI\%gearman_task_st\fP represents a \fItask\fP.  Work that is sent by a \fIclient\fP to a gearman server is seen as a task (a \fIworker\fP recieves a task in the form of a \fIjob\fP.
-.sp
-Tasks, i.e. \fI\%gearman_task_st\fP are created by calling either \fBgearman_execute()\fP, \fBgearman_client_add_task()\fP, or \fBgearman_client_add_task_background()\fP.
-.sp
-\fBgearman_client_add_task_status()\fP can also create \fI\%gearman_task_st\fP, these tasks will be used to
-monitor a previously created \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_free()\fP is used to free a task. This only needs to be
-done if a task was created with a preallocated structure or if you want to clean up the memory of a specific task.
-.sp
-\fI\%gearman_task_set_context()\fP sets the given context of the \fI\%gearman_task_st\fP. The context can be used to pass information to a \fI\%gearman_task_st\fP.
-.sp
-\fI\%gearman_task_context()\fP returns the context that was used in the creation of the \fI\%gearman_task_st\fP (or that was set with \fI\%gearman_task_set_context()\fP.
-.sp
-\fI\%gearman_task_data()\fP returns the current data that has been returned to the task. \fI\%gearman_task_data_size()\fP will give you the size of the value. \fI\%gearman_task_take_data()\fP is the same as \fI\%gearman_task_data()\fP but the value that is returned must be freed by the client (\fIfree(3)\fP). \fI\%gearman_task_recv_data()\fP can be used with pre\-allocated buffers.
-.sp
-\fI\%gearman_task_is_known()\fP, \fI\%gearman_task_is_running()\fP, \fI\%gearman_task_numerator()\fP, and \fI\%gearman_task_denominator()\fP, return values related to the last status update that was made to the \fI\%gearman_task_st\fP. They do not cause the \fI\%gearman_task_st\fP to update itself.
-.sp
-\fI\%gearman_task_error()\fP return the last error message that the
-\fI\%gearman_task_st\fP encountered. \fI\%gearman_task_return()\fP
-return the last \fBgearman_return_t\fP stored. A value of
-\fBGEARMAN_UNKNOWN_STATE\fP means that the task has not been submitted to
-server yet, or that no function was available if the job has been submitted.
-.SH RETURN VALUE
-.sp
-Various. Values that are returned by \fI\%gearman_task_take_data()\fP must have \fIfree(3)\fP called on them.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_verbose_name.3'
--- docs/man/gearman_verbose_name.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_verbose_name.3	1970-01-01 00:00:00 +0000
@@ -1,91 +0,0 @@
-.TH "GEARMAN_VERBOSE_NAME" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_verbose_name \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_verbose_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_verbose_name(\fI\%gearman_verbose_t\fP\fI\ verbose\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_verbose_name()\fP takes a \fI\%gearman_verbose_t\fP and returns a character representation of it.
-.sp
-Possible values of \fI\%gearman_verbose_t\fP:
-.INDENT 0.0
-.TP
-.B GEARMAN_VERBOSE_FATAL
-.UNINDENT
-.sp
-Fatal errors.
-.INDENT 0.0
-.TP
-.B GEARMAN_VERBOSE_ERROR
-.UNINDENT
-.sp
-All errors.
-.INDENT 0.0
-.TP
-.B GEARMAN_VERBOSE_INFO
-.UNINDENT
-.sp
-General information state about any events.
-.INDENT 0.0
-.TP
-.B GEARMAN_VERBOSE_DEBUG
-.UNINDENT
-.sp
-Information calls left in the code for debugging events.
-.SH RETURN VALUE
-.sp
-A character string representing the verbose leval.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_verbose_t.3'
--- docs/man/gearman_verbose_t.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_verbose_t.3	1970-01-01 00:00:00 +0000
@@ -1,91 +0,0 @@
-.TH "GEARMAN_VERBOSE_T" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_verbose_t \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_verbose_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B const char *gearman_verbose_name(\fI\%gearman_verbose_t\fP\fI\ verbose\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_verbose_name()\fP takes a \fI\%gearman_verbose_t\fP and returns a character representation of it.
-.sp
-Possible values of \fI\%gearman_verbose_t\fP:
-.INDENT 0.0
-.TP
-.B GEARMAN_VERBOSE_FATAL
-.UNINDENT
-.sp
-Fatal errors.
-.INDENT 0.0
-.TP
-.B GEARMAN_VERBOSE_ERROR
-.UNINDENT
-.sp
-All errors.
-.INDENT 0.0
-.TP
-.B GEARMAN_VERBOSE_INFO
-.UNINDENT
-.sp
-General information state about any events.
-.INDENT 0.0
-.TP
-.B GEARMAN_VERBOSE_DEBUG
-.UNINDENT
-.sp
-Information calls left in the code for debugging events.
-.SH RETURN VALUE
-.sp
-A character string representing the verbose leval.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_version.3'
--- docs/man/gearman_version.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_version.3	1970-01-01 00:00:00 +0000
@@ -1,61 +0,0 @@
-.TH "GEARMAN_VERSION" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_version \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B const char *gearman_version(gearman_verbose_t\fI\ verbose\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-Return the version of the library.
-.SH RETURN VALUE
-.sp
-A constant C style string. No deallocation is required.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_work.3'
--- docs/man/gearman_work.3	2011-06-17 07:35:26 +0000
+++ docs/man/gearman_work.3	1970-01-01 00:00:00 +0000
@@ -1,90 +0,0 @@
-.TH "GEARMAN_WORK" "3" "June 17, 2011" "0.22" "Gearmand"
-.SH NAME
-gearman_work \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_work_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work(gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_epoch(time_t epoch, gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_background(gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_map(const char *name, size_t name_length, gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_epoch_with_map(time_t epoch, gearman_job_priority_t priority, const char *name, size_t name_length);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_background_with_map(gearman_job_priority_t priority, const char *name, size_t name_length);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_work_set_context(gearman_work_t *, void *);
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_work_t\fP describe work for \fBgearman_execute()\fP.
-.sp
-\fBgearman_work()\fP creates a \fI\%gearman_work_t\fP with a priority.
-.sp
-\fBgearman_work_epoch()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload at the time specified by epoch.
-.sp
-\fBgearman_work_background()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload as a background job.
-.sp
-\fBgearman_work_map()\fP, \fBgearman_work_map()\fP, and \fBgearman_work_map()\fP, do the same as there non\-map counterparts but specify a map function that will be executed on the result of the function specified for \fBgearman_execute()\fP.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_execute()\fP
-.SH AUTHOR
-Data Differential http://datadifferential.com/
-.SH COPYRIGHT
-2011, Data Differential, http://datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_work_background.3'
--- docs/man/gearman_work_background.3	2011-06-17 07:35:26 +0000
+++ docs/man/gearman_work_background.3	1970-01-01 00:00:00 +0000
@@ -1,90 +0,0 @@
-.TH "GEARMAN_WORK_BACKGROUND" "3" "June 17, 2011" "0.22" "Gearmand"
-.SH NAME
-gearman_work_background \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_work_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work(gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_epoch(time_t epoch, gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_background(gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_map(const char *name, size_t name_length, gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_epoch_with_map(time_t epoch, gearman_job_priority_t priority, const char *name, size_t name_length);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_background_with_map(gearman_job_priority_t priority, const char *name, size_t name_length);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_work_set_context(gearman_work_t *, void *);
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_work_t\fP describe work for \fBgearman_execute()\fP.
-.sp
-\fBgearman_work()\fP creates a \fI\%gearman_work_t\fP with a priority.
-.sp
-\fBgearman_work_epoch()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload at the time specified by epoch.
-.sp
-\fBgearman_work_background()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload as a background job.
-.sp
-\fBgearman_work_map()\fP, \fBgearman_work_map()\fP, and \fBgearman_work_map()\fP, do the same as there non\-map counterparts but specify a map function that will be executed on the result of the function specified for \fBgearman_execute()\fP.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_execute()\fP
-.SH AUTHOR
-Data Differential http://datadifferential.com/
-.SH COPYRIGHT
-2011, Data Differential, http://datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_work_background_with_map.3'
--- docs/man/gearman_work_background_with_map.3	2011-06-17 07:35:26 +0000
+++ docs/man/gearman_work_background_with_map.3	1970-01-01 00:00:00 +0000
@@ -1,90 +0,0 @@
-.TH "GEARMAN_WORK_BACKGROUND_WITH_MAP" "3" "June 17, 2011" "0.22" "Gearmand"
-.SH NAME
-gearman_work_background_with_map \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_work_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work(gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_epoch(time_t epoch, gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_background(gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_map(const char *name, size_t name_length, gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_epoch_with_map(time_t epoch, gearman_job_priority_t priority, const char *name, size_t name_length);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_background_with_map(gearman_job_priority_t priority, const char *name, size_t name_length);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_work_set_context(gearman_work_t *, void *);
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_work_t\fP describe work for \fBgearman_execute()\fP.
-.sp
-\fBgearman_work()\fP creates a \fI\%gearman_work_t\fP with a priority.
-.sp
-\fBgearman_work_epoch()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload at the time specified by epoch.
-.sp
-\fBgearman_work_background()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload as a background job.
-.sp
-\fBgearman_work_map()\fP, \fBgearman_work_map()\fP, and \fBgearman_work_map()\fP, do the same as there non\-map counterparts but specify a map function that will be executed on the result of the function specified for \fBgearman_execute()\fP.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_execute()\fP
-.SH AUTHOR
-Data Differential http://datadifferential.com/
-.SH COPYRIGHT
-2011, Data Differential, http://datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_work_epoch.3'
--- docs/man/gearman_work_epoch.3	2011-06-17 07:35:26 +0000
+++ docs/man/gearman_work_epoch.3	1970-01-01 00:00:00 +0000
@@ -1,90 +0,0 @@
-.TH "GEARMAN_WORK_EPOCH" "3" "June 17, 2011" "0.22" "Gearmand"
-.SH NAME
-gearman_work_epoch \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_work_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work(gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_epoch(time_t epoch, gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_background(gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_map(const char *name, size_t name_length, gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_epoch_with_map(time_t epoch, gearman_job_priority_t priority, const char *name, size_t name_length);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_background_with_map(gearman_job_priority_t priority, const char *name, size_t name_length);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_work_set_context(gearman_work_t *, void *);
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_work_t\fP describe work for \fBgearman_execute()\fP.
-.sp
-\fBgearman_work()\fP creates a \fI\%gearman_work_t\fP with a priority.
-.sp
-\fBgearman_work_epoch()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload at the time specified by epoch.
-.sp
-\fBgearman_work_background()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload as a background job.
-.sp
-\fBgearman_work_map()\fP, \fBgearman_work_map()\fP, and \fBgearman_work_map()\fP, do the same as there non\-map counterparts but specify a map function that will be executed on the result of the function specified for \fBgearman_execute()\fP.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_execute()\fP
-.SH AUTHOR
-Data Differential http://datadifferential.com/
-.SH COPYRIGHT
-2011, Data Differential, http://datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_work_epoch_with_map.3'
--- docs/man/gearman_work_epoch_with_map.3	2011-06-17 07:35:26 +0000
+++ docs/man/gearman_work_epoch_with_map.3	1970-01-01 00:00:00 +0000
@@ -1,90 +0,0 @@
-.TH "GEARMAN_WORK_EPOCH_WITH_MAP" "3" "June 17, 2011" "0.22" "Gearmand"
-.SH NAME
-gearman_work_epoch_with_map \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_work_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work(gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_epoch(time_t epoch, gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_background(gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_map(const char *name, size_t name_length, gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_epoch_with_map(time_t epoch, gearman_job_priority_t priority, const char *name, size_t name_length);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_background_with_map(gearman_job_priority_t priority, const char *name, size_t name_length);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_work_set_context(gearman_work_t *, void *);
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_work_t\fP describe work for \fBgearman_execute()\fP.
-.sp
-\fBgearman_work()\fP creates a \fI\%gearman_work_t\fP with a priority.
-.sp
-\fBgearman_work_epoch()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload at the time specified by epoch.
-.sp
-\fBgearman_work_background()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload as a background job.
-.sp
-\fBgearman_work_map()\fP, \fBgearman_work_map()\fP, and \fBgearman_work_map()\fP, do the same as there non\-map counterparts but specify a map function that will be executed on the result of the function specified for \fBgearman_execute()\fP.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_execute()\fP
-.SH AUTHOR
-Data Differential http://datadifferential.com/
-.SH COPYRIGHT
-2011, Data Differential, http://datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_work_map.3'
--- docs/man/gearman_work_map.3	2011-06-17 07:35:26 +0000
+++ docs/man/gearman_work_map.3	1970-01-01 00:00:00 +0000
@@ -1,90 +0,0 @@
-.TH "GEARMAN_WORK_MAP" "3" "June 17, 2011" "0.22" "Gearmand"
-.SH NAME
-gearman_work_map \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_work_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work(gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_epoch(time_t epoch, gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_background(gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_map(const char *name, size_t name_length, gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_epoch_with_map(time_t epoch, gearman_job_priority_t priority, const char *name, size_t name_length);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_background_with_map(gearman_job_priority_t priority, const char *name, size_t name_length);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_work_set_context(gearman_work_t *, void *);
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_work_t\fP describe work for \fBgearman_execute()\fP.
-.sp
-\fBgearman_work()\fP creates a \fI\%gearman_work_t\fP with a priority.
-.sp
-\fBgearman_work_epoch()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload at the time specified by epoch.
-.sp
-\fBgearman_work_background()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload as a background job.
-.sp
-\fBgearman_work_map()\fP, \fBgearman_work_map()\fP, and \fBgearman_work_map()\fP, do the same as there non\-map counterparts but specify a map function that will be executed on the result of the function specified for \fBgearman_execute()\fP.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_execute()\fP
-.SH AUTHOR
-Data Differential http://datadifferential.com/
-.SH COPYRIGHT
-2011, Data Differential, http://datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_work_t.3'
--- docs/man/gearman_work_t.3	2011-06-17 07:35:26 +0000
+++ docs/man/gearman_work_t.3	1970-01-01 00:00:00 +0000
@@ -1,90 +0,0 @@
-.TH "GEARMAN_WORK_T" "3" "June 17, 2011" "0.22" "Gearmand"
-.SH NAME
-gearman_work_t \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_work_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work(gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_epoch(time_t epoch, gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_background(gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_map(const char *name, size_t name_length, gearman_job_priority_t priority);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_epoch_with_map(time_t epoch, gearman_job_priority_t priority, const char *name, size_t name_length);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_work_t gearman_work_background_with_map(gearman_job_priority_t priority, const char *name, size_t name_length);
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_work_set_context(gearman_work_t *, void *);
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_work_t\fP describe work for \fBgearman_execute()\fP.
-.sp
-\fBgearman_work()\fP creates a \fI\%gearman_work_t\fP with a priority.
-.sp
-\fBgearman_work_epoch()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload at the time specified by epoch.
-.sp
-\fBgearman_work_background()\fP creates a \fI\%gearman_work_t\fP which tells \fBgearman_execute()\fP to execute the workload as a background job.
-.sp
-\fBgearman_work_map()\fP, \fBgearman_work_map()\fP, and \fBgearman_work_map()\fP, do the same as there non\-map counterparts but specify a map function that will be executed on the result of the function specified for \fBgearman_execute()\fP.
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_execute()\fP
-.SH AUTHOR
-Data Differential http://datadifferential.com/
-.SH COPYRIGHT
-2011, Data Differential, http://datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_add_function.3'
--- docs/man/gearman_worker_add_function.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_add_function.3	1970-01-01 00:00:00 +0000
@@ -1,133 +0,0 @@
-.TH "GEARMAN_WORKER_ADD_FUNCTION" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_add_function \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_worker_set_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_worker_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_worker_context(const \fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_context(\fI\%gearman_worker_st\fP\fI\ *worker\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_malloc_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_free_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_wait(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_register(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, uint32_t\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_job_st *gearman_worker_grab_job(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_job_st\fI\ *job\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_worker_function_exist(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, size_t\fI\ function_length\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_work(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_st\fP is used for worker communication with the server.
-.sp
-\fI\%gearman_worker_context()\fP and \fI\%gearman_worker_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_worker_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_worker_timeout()\fP and \fI\%gearman_worker_set_timeout()\fP get and set the current timeout value, in milliseconds, for the worker.
-.sp
-\fI\%gearman_worker_function_exist()\fP is used to determine if a given worker has a specific function.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_worker_set_workload_malloc_fn()\fP and \fI\%gearman_worker_set_workload_free_fn()\fP can be used to replace these with custom functions.
-.sp
-If you need to remove a function from the server you can call either \fI\%gearman_worker_unregister_all()\fP to remove all functions that the worker has told the \fBgearmand\fP server about, or you can use \fI\%gearman_worker_unregister()\fP to remove just a single function.
-.SH RETURN
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_add_options.3'
--- docs/man/gearman_worker_add_options.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_add_options.3	1970-01-01 00:00:00 +0000
@@ -1,94 +0,0 @@
-.TH "GEARMAN_WORKER_ADD_OPTIONS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_add_options \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_options_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_worker_options_t\fP gearman_worker_options(const gearman_worker_st\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_add_options(gearman_worker_st\fI\ *worker\fP, \fI\%gearman_worker_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_remove_options(gearman_worker_st\fI\ *worker\fP, \fI\%gearman_worker_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_options(gearman_worker_st\fI\ *worker\fP, \fI\%gearman_worker_options_t\fP\fI\ options\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.21.
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_options()\fP returns the \fI\%gearman_worker_options_t\fP for \fBgearman_worker_st\fP. You enable options via \fI\%gearman_worker_add_options()\fP and disable options via \fI\%gearman_worker_remove_options()\fP.
-.sp
-The currently supported options are:
-.sp
-Enable non\-block IO for the worker.
-.INDENT 0.0
-.TP
-.B GEARMAN_WORKER_GRAB_UNIQ
-.UNINDENT
-.sp
-Only grab jobs that have been assigned unique values. This is useful for workers who only want to worker with background jobs.
-.INDENT 0.0
-.TP
-.B GEARMAN_WORKER_TIMEOUT_RETURN
-.UNINDENT
-.sp
-Has a return timeout been set for the worker.
-.SH RETURN VALUE
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_add_server.3'
--- docs/man/gearman_worker_add_server.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_add_server.3	1970-01-01 00:00:00 +0000
@@ -1,83 +0,0 @@
-.TH "GEARMAN_WORKER_ADD_SERVER" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_add_server \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_add_server(gearman_worker_st\fI\ *worker\fP, const char\fI\ *host\fP, in_port_t\fI\ port\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_add_servers(gearman_worker_st\fI\ *worker\fP, const char\fI\ *servers\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_remove_servers(gearman_worker_st\fI\ *worker\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_add_server()\fP will add an additional \fBgearmand\fP server to the list of servers that the worker will take work from.
-.sp
-\fI\%gearman_worker_remove_servers()\fP will remove all servers from the \fBgearman_worker_st\fP.
-.sp
-\fI\%gearman_worker_add_servers()\fP takes a list of \fBgearmand\fP servers that will be parsed to provide servers for the worker. The format for this is SERVER[:PORT][,SERVER[:PORT]]...
-.sp
-Examples of this are:
-.sp
-.nf
-.ft C
-10.0.0.1,10.0.0.2,10.0.0.3
-localhost234,jobserver2.domain.com:7003,10.0.0.3
-.ft P
-.fi
-.SH RETURN VALUE
-.sp
-\fI\%gearman_worker_add_server()\fP and \fI\%gearman_worker_remove_servers()\fP return \fBgearman_return_t\fP.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fBgearmand\fP \fB../libgearman\fP  \fBgearman_worker_st\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_add_servers.3'
--- docs/man/gearman_worker_add_servers.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_add_servers.3	1970-01-01 00:00:00 +0000
@@ -1,83 +0,0 @@
-.TH "GEARMAN_WORKER_ADD_SERVERS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_add_servers \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_add_server(gearman_worker_st\fI\ *worker\fP, const char\fI\ *host\fP, in_port_t\fI\ port\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_add_servers(gearman_worker_st\fI\ *worker\fP, const char\fI\ *servers\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_remove_servers(gearman_worker_st\fI\ *worker\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_add_server()\fP will add an additional \fBgearmand\fP server to the list of servers that the worker will take work from.
-.sp
-\fI\%gearman_worker_remove_servers()\fP will remove all servers from the \fBgearman_worker_st\fP.
-.sp
-\fI\%gearman_worker_add_servers()\fP takes a list of \fBgearmand\fP servers that will be parsed to provide servers for the worker. The format for this is SERVER[:PORT][,SERVER[:PORT]]...
-.sp
-Examples of this are:
-.sp
-.nf
-.ft C
-10.0.0.1,10.0.0.2,10.0.0.3
-localhost234,jobserver2.domain.com:7003,10.0.0.3
-.ft P
-.fi
-.SH RETURN VALUE
-.sp
-\fI\%gearman_worker_add_server()\fP and \fI\%gearman_worker_remove_servers()\fP return \fBgearman_return_t\fP.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fBgearmand\fP \fB../libgearman\fP  \fBgearman_worker_st\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_clone.3'
--- docs/man/gearman_worker_clone.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_clone.3	1970-01-01 00:00:00 +0000
@@ -1,91 +0,0 @@
-.TH "GEARMAN_WORKER_CLONE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_clone \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_st *gearman_worker_create(gearman_worker_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_worker_st *gearman_worker_clone(gearman_worker_st\fI\ *client\fP, const gearman_worker_st\fI\ *from\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_free(gearman_worker_st\fI\ *client\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-gearman_worker_create() is used to create a \fBgearman_worker_st\fP  structure that will then
-be used by other libgearman(3) client functions to communicate with the server. You
-should either pass a statically declared \fBgearman_worker_st\fP  to gearman_worker_create) or
-a NULL. If a NULL passed in then a structure is allocated for you.
-.sp
-\fI\%gearman_worker_clone()\fP is similar to \fI\%gearman_worker_create()\fP but it copies the
-defaults and list of servers from the source \fBgearman_worker_st\fP. If you pass a null as
-the argument for the source to clone, it is the same as a call to gearman_worker_create().
-If the destination argument is NULL a \fBgearman_worker_st\fP  will be allocated for you.
-.sp
-To clean up memory associated with a \fBgearman_worker_st\fP  structure you should pass
-it to \fI\%gearman_worker_free()\fP when you are finished using it. \fI\%gearman_worker_free\fP is
-the only way to make sure all memory is deallocated when you finish using
-the structure.
-.sp
-You may wish to avoid using \fI\%gearman_worker_create()\fP or \fI\%gearman_worker_clone()\fP with a
-stack based allocation, ie the first parameter. The most common issues related to ABI safety involve
-heap allocated structures.
-.SH RETURN VALUE
-.sp
-\fI\%gearman_worker_create()\fP returns a pointer to the \fBgearman_worker_st\fP that was created
-(or initialized). On an allocation failure, it returns NULL.
-.sp
-\fI\%gearman_worker_clone()\fP returns a pointer to the \fBgearman_worker_st\fP that was created
-(or initialized). On an allocation failure, it returns NULL.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_strerror(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_context.3'
--- docs/man/gearman_worker_context.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_context.3	1970-01-01 00:00:00 +0000
@@ -1,133 +0,0 @@
-.TH "GEARMAN_WORKER_CONTEXT" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_context \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_worker_set_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_worker_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_worker_context(const \fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_context(\fI\%gearman_worker_st\fP\fI\ *worker\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_malloc_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_free_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_wait(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_register(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, uint32_t\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_job_st *gearman_worker_grab_job(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_job_st\fI\ *job\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_worker_function_exist(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, size_t\fI\ function_length\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_work(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_st\fP is used for worker communication with the server.
-.sp
-\fI\%gearman_worker_context()\fP and \fI\%gearman_worker_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_worker_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_worker_timeout()\fP and \fI\%gearman_worker_set_timeout()\fP get and set the current timeout value, in milliseconds, for the worker.
-.sp
-\fI\%gearman_worker_function_exist()\fP is used to determine if a given worker has a specific function.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_worker_set_workload_malloc_fn()\fP and \fI\%gearman_worker_set_workload_free_fn()\fP can be used to replace these with custom functions.
-.sp
-If you need to remove a function from the server you can call either \fI\%gearman_worker_unregister_all()\fP to remove all functions that the worker has told the \fBgearmand\fP server about, or you can use \fI\%gearman_worker_unregister()\fP to remove just a single function.
-.SH RETURN
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_create.3'
--- docs/man/gearman_worker_create.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_create.3	1970-01-01 00:00:00 +0000
@@ -1,91 +0,0 @@
-.TH "GEARMAN_WORKER_CREATE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_create \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_st *gearman_worker_create(gearman_worker_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_worker_st *gearman_worker_clone(gearman_worker_st\fI\ *client\fP, const gearman_worker_st\fI\ *from\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_free(gearman_worker_st\fI\ *client\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-gearman_worker_create() is used to create a \fBgearman_worker_st\fP  structure that will then
-be used by other libgearman(3) client functions to communicate with the server. You
-should either pass a statically declared \fBgearman_worker_st\fP  to gearman_worker_create) or
-a NULL. If a NULL passed in then a structure is allocated for you.
-.sp
-\fI\%gearman_worker_clone()\fP is similar to \fI\%gearman_worker_create()\fP but it copies the
-defaults and list of servers from the source \fBgearman_worker_st\fP. If you pass a null as
-the argument for the source to clone, it is the same as a call to gearman_worker_create().
-If the destination argument is NULL a \fBgearman_worker_st\fP  will be allocated for you.
-.sp
-To clean up memory associated with a \fBgearman_worker_st\fP  structure you should pass
-it to \fI\%gearman_worker_free()\fP when you are finished using it. \fI\%gearman_worker_free\fP is
-the only way to make sure all memory is deallocated when you finish using
-the structure.
-.sp
-You may wish to avoid using \fI\%gearman_worker_create()\fP or \fI\%gearman_worker_clone()\fP with a
-stack based allocation, ie the first parameter. The most common issues related to ABI safety involve
-heap allocated structures.
-.SH RETURN VALUE
-.sp
-\fI\%gearman_worker_create()\fP returns a pointer to the \fBgearman_worker_st\fP that was created
-(or initialized). On an allocation failure, it returns NULL.
-.sp
-\fI\%gearman_worker_clone()\fP returns a pointer to the \fBgearman_worker_st\fP that was created
-(or initialized). On an allocation failure, it returns NULL.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_strerror(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_define_function.3'
--- docs/man/gearman_worker_define_function.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_define_function.3	1970-01-01 00:00:00 +0000
@@ -1,101 +0,0 @@
-.TH "GEARMAN_WORKER_DEFINE_FUNCTION" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_define_function \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_function_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_define_function(gearman_worker_st\fI\ *worker\fP, const char\fI\ *function_name\fP, const size_t\fI\ function_name_length\fP, const \fI\%gearman_function_t\fP\fI\ function\fP, const uint32_t\fI\ timeout\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_function_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_aggregator_fn
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_define_function()\fP defines functions for a worker.
-.sp
-The interface is callback by design. When the server has a job for the worker, \fI\%gearman_function_fn\fP is evoked with a \fBgearman_job_st\fP representing the job, and the context that was defined originally when the function was defined.
-.sp
-Results are sent back to the client by invoking \fBgearman_job_send_data()\fP.
-.sp
-If the client specified an reducer function, then the output of the \fI\%gearman_function_fn\fP will be sent to that function. You can split the work out to the reducer function by sending data multiple times with \fBgearman_job_send_data()\fP.
-.sp
-If any errors are detected then the entire job is cancelled.  The \fI\%gearman_aggregator_fn\fP will
-be called when all mapped jobs have completed. The result of this function
-will be what is returned to the client.
-.sp
-The callback function needs to return one of the following errors:
-.sp
-\fBGEARMAN_SUCCESS\fP
-.sp
-The function was successful.
-.sp
-\fBGEARMAN_FAIL\fP
-.sp
-An error has occurred, the job we not processed, and the worker cannot continue.
-.sp
-\fBGEARMAN_ERROR\fP
-.sp
-A transient error has occurred, like a network failure, and the job can be restarted.
-.sp
-If a value other then the above are returned it is converted to a \fBGEARMAN_FAIL\fP and \fBgearman_worker_work()\fP returns \fBGEARMAN_INVALID_ARGUMENT\fP.
-.sp
-\fBgearman_job_send_complete()\fP and \fBgearman_job_send_fail()\fP cannot be used with any functions created with \fI\%gearman_worker_define_function()\fP.
-.SH RETURN VALUE
-.sp
-\fBgearman_return_t\fP
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_strerror(3)\fP \fIgearman_client_error\fP \fIgearman_client_execute_reduce\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_echo.3'
--- docs/man/gearman_worker_echo.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_echo.3	1970-01-01 00:00:00 +0000
@@ -1,64 +0,0 @@
-.TH "GEARMAN_WORKER_ECHO" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_echo \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_echo(gearman_client_st\fI\ *client\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_echo(gearman_worker_st\fI\ *worker\fP, const void\fI\ *workload\fP, size_t\fI\ workload_size\fP)
-.UNINDENT
-.SH DESCRIPTION
-.sp
-\fI\%gearman_client_echo()\fP and \fI\%gearman_worker_echo()\fP send a message to a \fBgearmand\fP server. The server will then respond with the message that it sent. These commands are just for testing the connection to the servers that were configure for the \fBgearman_client_st\fP and the \fBgearman_worker_st\fP that were used.
-.SH RETURN VALUE
-.sp
-\fBgearman_return_t\fP
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_errno.3'
--- docs/man/gearman_worker_errno.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_errno.3	1970-01-01 00:00:00 +0000
@@ -1,66 +0,0 @@
-.TH "GEARMAN_WORKER_ERRNO" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_errno \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B const char *gearman_worker_error(const gearman_worker_st\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_worker_errno(gearman_worker_st\fI\ *worker\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_error()\fP and \fI\%gearman_worker_errno()\fP report on the last errors that the worker reported/stored in \fBgearman_worker_st\fP. If you are interested in recording all errors please see \fBgearman_worker_set_log_fn()\fP.
-.SH RETURN VALUE
-.sp
-\fI\%gearman_worker_errno()\fP returns the last \fIerrno\fP that the worker recorded.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_error.3'
--- docs/man/gearman_worker_error.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_error.3	1970-01-01 00:00:00 +0000
@@ -1,66 +0,0 @@
-.TH "GEARMAN_WORKER_ERROR" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_error \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B const char *gearman_worker_error(const gearman_worker_st\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_worker_errno(gearman_worker_st\fI\ *worker\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_error()\fP and \fI\%gearman_worker_errno()\fP report on the last errors that the worker reported/stored in \fBgearman_worker_st\fP. If you are interested in recording all errors please see \fBgearman_worker_set_log_fn()\fP.
-.SH RETURN VALUE
-.sp
-\fI\%gearman_worker_errno()\fP returns the last \fIerrno\fP that the worker recorded.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_free.3'
--- docs/man/gearman_worker_free.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_free.3	1970-01-01 00:00:00 +0000
@@ -1,91 +0,0 @@
-.TH "GEARMAN_WORKER_FREE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_free \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_st *gearman_worker_create(gearman_worker_st\fI\ *client\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_worker_st *gearman_worker_clone(gearman_worker_st\fI\ *client\fP, const gearman_worker_st\fI\ *from\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_free(gearman_worker_st\fI\ *client\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-gearman_worker_create() is used to create a \fBgearman_worker_st\fP  structure that will then
-be used by other libgearman(3) client functions to communicate with the server. You
-should either pass a statically declared \fBgearman_worker_st\fP  to gearman_worker_create) or
-a NULL. If a NULL passed in then a structure is allocated for you.
-.sp
-\fI\%gearman_worker_clone()\fP is similar to \fI\%gearman_worker_create()\fP but it copies the
-defaults and list of servers from the source \fBgearman_worker_st\fP. If you pass a null as
-the argument for the source to clone, it is the same as a call to gearman_worker_create().
-If the destination argument is NULL a \fBgearman_worker_st\fP  will be allocated for you.
-.sp
-To clean up memory associated with a \fBgearman_worker_st\fP  structure you should pass
-it to \fI\%gearman_worker_free()\fP when you are finished using it. \fI\%gearman_worker_free\fP is
-the only way to make sure all memory is deallocated when you finish using
-the structure.
-.sp
-You may wish to avoid using \fI\%gearman_worker_create()\fP or \fI\%gearman_worker_clone()\fP with a
-stack based allocation, ie the first parameter. The most common issues related to ABI safety involve
-heap allocated structures.
-.SH RETURN VALUE
-.sp
-\fI\%gearman_worker_create()\fP returns a pointer to the \fBgearman_worker_st\fP that was created
-(or initialized). On an allocation failure, it returns NULL.
-.sp
-\fI\%gearman_worker_clone()\fP returns a pointer to the \fBgearman_worker_st\fP that was created
-(or initialized). On an allocation failure, it returns NULL.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_strerror(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_function_exist.3'
--- docs/man/gearman_worker_function_exist.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_function_exist.3	1970-01-01 00:00:00 +0000
@@ -1,133 +0,0 @@
-.TH "GEARMAN_WORKER_FUNCTION_EXIST" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_function_exist \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_worker_set_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_worker_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_worker_context(const \fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_context(\fI\%gearman_worker_st\fP\fI\ *worker\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_malloc_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_free_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_wait(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_register(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, uint32_t\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_job_st *gearman_worker_grab_job(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_job_st\fI\ *job\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_worker_function_exist(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, size_t\fI\ function_length\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_work(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_st\fP is used for worker communication with the server.
-.sp
-\fI\%gearman_worker_context()\fP and \fI\%gearman_worker_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_worker_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_worker_timeout()\fP and \fI\%gearman_worker_set_timeout()\fP get and set the current timeout value, in milliseconds, for the worker.
-.sp
-\fI\%gearman_worker_function_exist()\fP is used to determine if a given worker has a specific function.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_worker_set_workload_malloc_fn()\fP and \fI\%gearman_worker_set_workload_free_fn()\fP can be used to replace these with custom functions.
-.sp
-If you need to remove a function from the server you can call either \fI\%gearman_worker_unregister_all()\fP to remove all functions that the worker has told the \fBgearmand\fP server about, or you can use \fI\%gearman_worker_unregister()\fP to remove just a single function.
-.SH RETURN
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_grab_job.3'
--- docs/man/gearman_worker_grab_job.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_grab_job.3	1970-01-01 00:00:00 +0000
@@ -1,133 +0,0 @@
-.TH "GEARMAN_WORKER_GRAB_JOB" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_grab_job \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_worker_set_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_worker_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_worker_context(const \fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_context(\fI\%gearman_worker_st\fP\fI\ *worker\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_malloc_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_free_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_wait(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_register(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, uint32_t\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_job_st *gearman_worker_grab_job(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_job_st\fI\ *job\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_worker_function_exist(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, size_t\fI\ function_length\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_work(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_st\fP is used for worker communication with the server.
-.sp
-\fI\%gearman_worker_context()\fP and \fI\%gearman_worker_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_worker_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_worker_timeout()\fP and \fI\%gearman_worker_set_timeout()\fP get and set the current timeout value, in milliseconds, for the worker.
-.sp
-\fI\%gearman_worker_function_exist()\fP is used to determine if a given worker has a specific function.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_worker_set_workload_malloc_fn()\fP and \fI\%gearman_worker_set_workload_free_fn()\fP can be used to replace these with custom functions.
-.sp
-If you need to remove a function from the server you can call either \fI\%gearman_worker_unregister_all()\fP to remove all functions that the worker has told the \fBgearmand\fP server about, or you can use \fI\%gearman_worker_unregister()\fP to remove just a single function.
-.SH RETURN
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_options.3'
--- docs/man/gearman_worker_options.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_options.3	1970-01-01 00:00:00 +0000
@@ -1,94 +0,0 @@
-.TH "GEARMAN_WORKER_OPTIONS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_options \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_options_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_worker_options_t\fP gearman_worker_options(const gearman_worker_st\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_add_options(gearman_worker_st\fI\ *worker\fP, \fI\%gearman_worker_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_remove_options(gearman_worker_st\fI\ *worker\fP, \fI\%gearman_worker_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_options(gearman_worker_st\fI\ *worker\fP, \fI\%gearman_worker_options_t\fP\fI\ options\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.21.
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_options()\fP returns the \fI\%gearman_worker_options_t\fP for \fBgearman_worker_st\fP. You enable options via \fI\%gearman_worker_add_options()\fP and disable options via \fI\%gearman_worker_remove_options()\fP.
-.sp
-The currently supported options are:
-.sp
-Enable non\-block IO for the worker.
-.INDENT 0.0
-.TP
-.B GEARMAN_WORKER_GRAB_UNIQ
-.UNINDENT
-.sp
-Only grab jobs that have been assigned unique values. This is useful for workers who only want to worker with background jobs.
-.INDENT 0.0
-.TP
-.B GEARMAN_WORKER_TIMEOUT_RETURN
-.UNINDENT
-.sp
-Has a return timeout been set for the worker.
-.SH RETURN VALUE
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_options_t.3'
--- docs/man/gearman_worker_options_t.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_options_t.3	1970-01-01 00:00:00 +0000
@@ -1,94 +0,0 @@
-.TH "GEARMAN_WORKER_OPTIONS_T" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_options_t \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_options_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_worker_options_t\fP gearman_worker_options(const gearman_worker_st\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_add_options(gearman_worker_st\fI\ *worker\fP, \fI\%gearman_worker_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_remove_options(gearman_worker_st\fI\ *worker\fP, \fI\%gearman_worker_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_options(gearman_worker_st\fI\ *worker\fP, \fI\%gearman_worker_options_t\fP\fI\ options\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.21.
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_options()\fP returns the \fI\%gearman_worker_options_t\fP for \fBgearman_worker_st\fP. You enable options via \fI\%gearman_worker_add_options()\fP and disable options via \fI\%gearman_worker_remove_options()\fP.
-.sp
-The currently supported options are:
-.sp
-Enable non\-block IO for the worker.
-.INDENT 0.0
-.TP
-.B GEARMAN_WORKER_GRAB_UNIQ
-.UNINDENT
-.sp
-Only grab jobs that have been assigned unique values. This is useful for workers who only want to worker with background jobs.
-.INDENT 0.0
-.TP
-.B GEARMAN_WORKER_TIMEOUT_RETURN
-.UNINDENT
-.sp
-Has a return timeout been set for the worker.
-.SH RETURN VALUE
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_register.3'
--- docs/man/gearman_worker_register.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_register.3	1970-01-01 00:00:00 +0000
@@ -1,133 +0,0 @@
-.TH "GEARMAN_WORKER_REGISTER" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_register \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_worker_set_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_worker_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_worker_context(const \fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_context(\fI\%gearman_worker_st\fP\fI\ *worker\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_malloc_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_free_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_wait(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_register(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, uint32_t\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_job_st *gearman_worker_grab_job(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_job_st\fI\ *job\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_worker_function_exist(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, size_t\fI\ function_length\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_work(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_st\fP is used for worker communication with the server.
-.sp
-\fI\%gearman_worker_context()\fP and \fI\%gearman_worker_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_worker_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_worker_timeout()\fP and \fI\%gearman_worker_set_timeout()\fP get and set the current timeout value, in milliseconds, for the worker.
-.sp
-\fI\%gearman_worker_function_exist()\fP is used to determine if a given worker has a specific function.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_worker_set_workload_malloc_fn()\fP and \fI\%gearman_worker_set_workload_free_fn()\fP can be used to replace these with custom functions.
-.sp
-If you need to remove a function from the server you can call either \fI\%gearman_worker_unregister_all()\fP to remove all functions that the worker has told the \fBgearmand\fP server about, or you can use \fI\%gearman_worker_unregister()\fP to remove just a single function.
-.SH RETURN
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_remove_options.3'
--- docs/man/gearman_worker_remove_options.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_remove_options.3	1970-01-01 00:00:00 +0000
@@ -1,94 +0,0 @@
-.TH "GEARMAN_WORKER_REMOVE_OPTIONS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_remove_options \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_options_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_worker_options_t\fP gearman_worker_options(const gearman_worker_st\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_add_options(gearman_worker_st\fI\ *worker\fP, \fI\%gearman_worker_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_remove_options(gearman_worker_st\fI\ *worker\fP, \fI\%gearman_worker_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_options(gearman_worker_st\fI\ *worker\fP, \fI\%gearman_worker_options_t\fP\fI\ options\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.21.
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_options()\fP returns the \fI\%gearman_worker_options_t\fP for \fBgearman_worker_st\fP. You enable options via \fI\%gearman_worker_add_options()\fP and disable options via \fI\%gearman_worker_remove_options()\fP.
-.sp
-The currently supported options are:
-.sp
-Enable non\-block IO for the worker.
-.INDENT 0.0
-.TP
-.B GEARMAN_WORKER_GRAB_UNIQ
-.UNINDENT
-.sp
-Only grab jobs that have been assigned unique values. This is useful for workers who only want to worker with background jobs.
-.INDENT 0.0
-.TP
-.B GEARMAN_WORKER_TIMEOUT_RETURN
-.UNINDENT
-.sp
-Has a return timeout been set for the worker.
-.SH RETURN VALUE
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_remove_servers.3'
--- docs/man/gearman_worker_remove_servers.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_remove_servers.3	1970-01-01 00:00:00 +0000
@@ -1,83 +0,0 @@
-.TH "GEARMAN_WORKER_REMOVE_SERVERS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_remove_servers \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_add_server(gearman_worker_st\fI\ *worker\fP, const char\fI\ *host\fP, in_port_t\fI\ port\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_add_servers(gearman_worker_st\fI\ *worker\fP, const char\fI\ *servers\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_remove_servers(gearman_worker_st\fI\ *worker\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_add_server()\fP will add an additional \fBgearmand\fP server to the list of servers that the worker will take work from.
-.sp
-\fI\%gearman_worker_remove_servers()\fP will remove all servers from the \fBgearman_worker_st\fP.
-.sp
-\fI\%gearman_worker_add_servers()\fP takes a list of \fBgearmand\fP servers that will be parsed to provide servers for the worker. The format for this is SERVER[:PORT][,SERVER[:PORT]]...
-.sp
-Examples of this are:
-.sp
-.nf
-.ft C
-10.0.0.1,10.0.0.2,10.0.0.3
-localhost234,jobserver2.domain.com:7003,10.0.0.3
-.ft P
-.fi
-.SH RETURN VALUE
-.sp
-\fI\%gearman_worker_add_server()\fP and \fI\%gearman_worker_remove_servers()\fP return \fBgearman_return_t\fP.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fBgearmand\fP \fB../libgearman\fP  \fBgearman_worker_st\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_set_context.3'
--- docs/man/gearman_worker_set_context.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_set_context.3	1970-01-01 00:00:00 +0000
@@ -1,133 +0,0 @@
-.TH "GEARMAN_WORKER_SET_CONTEXT" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_set_context \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_worker_set_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_worker_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_worker_context(const \fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_context(\fI\%gearman_worker_st\fP\fI\ *worker\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_malloc_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_free_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_wait(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_register(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, uint32_t\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_job_st *gearman_worker_grab_job(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_job_st\fI\ *job\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_worker_function_exist(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, size_t\fI\ function_length\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_work(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_st\fP is used for worker communication with the server.
-.sp
-\fI\%gearman_worker_context()\fP and \fI\%gearman_worker_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_worker_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_worker_timeout()\fP and \fI\%gearman_worker_set_timeout()\fP get and set the current timeout value, in milliseconds, for the worker.
-.sp
-\fI\%gearman_worker_function_exist()\fP is used to determine if a given worker has a specific function.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_worker_set_workload_malloc_fn()\fP and \fI\%gearman_worker_set_workload_free_fn()\fP can be used to replace these with custom functions.
-.sp
-If you need to remove a function from the server you can call either \fI\%gearman_worker_unregister_all()\fP to remove all functions that the worker has told the \fBgearmand\fP server about, or you can use \fI\%gearman_worker_unregister()\fP to remove just a single function.
-.SH RETURN
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_set_log_fn.3'
--- docs/man/gearman_worker_set_log_fn.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_set_log_fn.3	1970-01-01 00:00:00 +0000
@@ -1,64 +0,0 @@
-.TH "GEARMAN_WORKER_SET_LOG_FN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_set_log_fn \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_log_fn(gearman_worker_st\fI\ *worker\fP, gearman_log_fn\fI\ *function\fP, void\fI\ *context\fP, gearman_verbose_t\fI\ verbose\fP)
-.UNINDENT
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_set_log_fn()\fP is similar to \fBgearman_client_set_log_fn()\fP but it used with workers, aka, \fBgearman_worker_st\fP.
-\fI\%gearman_worker_set_log_fn()\fP allows you to register a callback that will be passed all error messages that are givin to the worker.
-.sp
-See \fBgearman_log_fn\fP for a description of the callback.
-.sp
-See \fBgearman_verbose_t\fP for more information on logging levels.
-.SH RETURN VALUE
-.sp
-None
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_set_log_fn(3)\fP \fIgearman_log_fn\fP  \fIgearman_verbose_t\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_set_memory_allocators.3'
--- docs/man/gearman_worker_set_memory_allocators.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_set_memory_allocators.3	1970-01-01 00:00:00 +0000
@@ -1,84 +0,0 @@
-.TH "GEARMAN_WORKER_SET_MEMORY_ALLOCATORS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_set_memory_allocators \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_allocator_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_malloc_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_realloc_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_calloc_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_client_set_memory_allocators(gearman_client_st\fI\ *\fP, \fI\%gearman_malloc_fn\fP\fI\ *malloc_fn\fP, \fI\%gearman_free_fn\fP\fI\ *free_fn\fP, \fI\%gearman_realloc_fn\fP\fI\ *realloc_fn\fP, \fI\%gearman_calloc_fn\fP\fI\ *calloc_fn\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_set_memory_allocators(gearman_worker_st\fI\ *\fP, \fI\%gearman_malloc_fn\fP\fI\ *malloc_fn\fP, \fI\%gearman_free_fn\fP\fI\ *free_fn\fP, \fI\%gearman_realloc_fn\fP\fI\ *realloc_fn\fP, \fI\%gearman_calloc_fn\fP\fI\ *calloc_fn\fP, void\fI\ *context\fP)
-.UNINDENT
-.sp
-Link to \-lgearman
-.SH DESCRIPTION
-.sp
-Install callbacks for custom allocation.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. You can use \fI\%gearman_client_set_memory_allocators()\fP and \fI\%gearman_worker_set_memory_allocators()\fP to set your own custom allocators.
-.SH RETURN VALUE
-.sp
-None
-.IP "See also"
-.RE
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP \fIgearman_client_st(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_set_namespace.3'
--- docs/man/gearman_worker_set_namespace.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_set_namespace.3	1970-01-01 00:00:00 +0000
@@ -1,69 +0,0 @@
-.TH "GEARMAN_WORKER_SET_NAMESPACE" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_set_namespace \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B void gearman_client_set_namespace(gearman_client_st\fI\ *self\fP, const char\fI\ *namespace_key\fP, size_t\fI\ namespace_key_size\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_namespace(gearman_worker_st\fI\ *self\fP, const char\fI\ *namespace_key\fP, size_t\fI\ namespace_key_size\fP)
-.UNINDENT
-.sp
-Compile and link with \-lgearman
-.SH DESCRIPTION
-.sp
-gearman_client_set_namespace() and gearman_worker_set_namespace() set
-a "namespace" for a given set of functions. Only clients and workers sharing
-a namespace_key can see one anothers workloads and functions.
-.sp
-By setting namespace_key to NULL you can disable the namespace.
-.SH RETURN
-.sp
-None
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_set_options.3'
--- docs/man/gearman_worker_set_options.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_set_options.3	1970-01-01 00:00:00 +0000
@@ -1,94 +0,0 @@
-.TH "GEARMAN_WORKER_SET_OPTIONS" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_set_options \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_options_t
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \fI\%gearman_worker_options_t\fP gearman_worker_options(const gearman_worker_st\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_add_options(gearman_worker_st\fI\ *worker\fP, \fI\%gearman_worker_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_remove_options(gearman_worker_st\fI\ *worker\fP, \fI\%gearman_worker_options_t\fP\fI\ options\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_options(gearman_worker_st\fI\ *worker\fP, \fI\%gearman_worker_options_t\fP\fI\ options\fP)
-.UNINDENT
-.sp
-Deprecated since version 0.21.
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_options()\fP returns the \fI\%gearman_worker_options_t\fP for \fBgearman_worker_st\fP. You enable options via \fI\%gearman_worker_add_options()\fP and disable options via \fI\%gearman_worker_remove_options()\fP.
-.sp
-The currently supported options are:
-.sp
-Enable non\-block IO for the worker.
-.INDENT 0.0
-.TP
-.B GEARMAN_WORKER_GRAB_UNIQ
-.UNINDENT
-.sp
-Only grab jobs that have been assigned unique values. This is useful for workers who only want to worker with background jobs.
-.INDENT 0.0
-.TP
-.B GEARMAN_WORKER_TIMEOUT_RETURN
-.UNINDENT
-.sp
-Has a return timeout been set for the worker.
-.SH RETURN VALUE
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.IP "See also"
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.RE
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_set_timeout.3'
--- docs/man/gearman_worker_set_timeout.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_set_timeout.3	1970-01-01 00:00:00 +0000
@@ -1,133 +0,0 @@
-.TH "GEARMAN_WORKER_SET_TIMEOUT" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_set_timeout \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_worker_set_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_worker_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_worker_context(const \fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_context(\fI\%gearman_worker_st\fP\fI\ *worker\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_malloc_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_free_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_wait(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_register(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, uint32_t\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_job_st *gearman_worker_grab_job(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_job_st\fI\ *job\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_worker_function_exist(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, size_t\fI\ function_length\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_work(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_st\fP is used for worker communication with the server.
-.sp
-\fI\%gearman_worker_context()\fP and \fI\%gearman_worker_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_worker_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_worker_timeout()\fP and \fI\%gearman_worker_set_timeout()\fP get and set the current timeout value, in milliseconds, for the worker.
-.sp
-\fI\%gearman_worker_function_exist()\fP is used to determine if a given worker has a specific function.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_worker_set_workload_malloc_fn()\fP and \fI\%gearman_worker_set_workload_free_fn()\fP can be used to replace these with custom functions.
-.sp
-If you need to remove a function from the server you can call either \fI\%gearman_worker_unregister_all()\fP to remove all functions that the worker has told the \fBgearmand\fP server about, or you can use \fI\%gearman_worker_unregister()\fP to remove just a single function.
-.SH RETURN
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_set_workload_free_fn.3'
--- docs/man/gearman_worker_set_workload_free_fn.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_set_workload_free_fn.3	1970-01-01 00:00:00 +0000
@@ -1,133 +0,0 @@
-.TH "GEARMAN_WORKER_SET_WORKLOAD_FREE_FN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_set_workload_free_fn \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_worker_set_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_worker_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_worker_context(const \fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_context(\fI\%gearman_worker_st\fP\fI\ *worker\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_malloc_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_free_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_wait(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_register(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, uint32_t\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_job_st *gearman_worker_grab_job(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_job_st\fI\ *job\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_worker_function_exist(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, size_t\fI\ function_length\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_work(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_st\fP is used for worker communication with the server.
-.sp
-\fI\%gearman_worker_context()\fP and \fI\%gearman_worker_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_worker_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_worker_timeout()\fP and \fI\%gearman_worker_set_timeout()\fP get and set the current timeout value, in milliseconds, for the worker.
-.sp
-\fI\%gearman_worker_function_exist()\fP is used to determine if a given worker has a specific function.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_worker_set_workload_malloc_fn()\fP and \fI\%gearman_worker_set_workload_free_fn()\fP can be used to replace these with custom functions.
-.sp
-If you need to remove a function from the server you can call either \fI\%gearman_worker_unregister_all()\fP to remove all functions that the worker has told the \fBgearmand\fP server about, or you can use \fI\%gearman_worker_unregister()\fP to remove just a single function.
-.SH RETURN
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_set_workload_malloc_fn.3'
--- docs/man/gearman_worker_set_workload_malloc_fn.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_set_workload_malloc_fn.3	1970-01-01 00:00:00 +0000
@@ -1,133 +0,0 @@
-.TH "GEARMAN_WORKER_SET_WORKLOAD_MALLOC_FN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_set_workload_malloc_fn \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_worker_set_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_worker_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_worker_context(const \fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_context(\fI\%gearman_worker_st\fP\fI\ *worker\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_malloc_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_free_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_wait(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_register(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, uint32_t\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_job_st *gearman_worker_grab_job(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_job_st\fI\ *job\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_worker_function_exist(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, size_t\fI\ function_length\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_work(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_st\fP is used for worker communication with the server.
-.sp
-\fI\%gearman_worker_context()\fP and \fI\%gearman_worker_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_worker_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_worker_timeout()\fP and \fI\%gearman_worker_set_timeout()\fP get and set the current timeout value, in milliseconds, for the worker.
-.sp
-\fI\%gearman_worker_function_exist()\fP is used to determine if a given worker has a specific function.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_worker_set_workload_malloc_fn()\fP and \fI\%gearman_worker_set_workload_free_fn()\fP can be used to replace these with custom functions.
-.sp
-If you need to remove a function from the server you can call either \fI\%gearman_worker_unregister_all()\fP to remove all functions that the worker has told the \fBgearmand\fP server about, or you can use \fI\%gearman_worker_unregister()\fP to remove just a single function.
-.SH RETURN
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_st.3'
--- docs/man/gearman_worker_st.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_st.3	1970-01-01 00:00:00 +0000
@@ -1,133 +0,0 @@
-.TH "GEARMAN_WORKER_ST" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_st \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_worker_set_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_worker_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_worker_context(const \fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_context(\fI\%gearman_worker_st\fP\fI\ *worker\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_malloc_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_free_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_wait(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_register(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, uint32_t\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_job_st *gearman_worker_grab_job(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_job_st\fI\ *job\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_worker_function_exist(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, size_t\fI\ function_length\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_work(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_st\fP is used for worker communication with the server.
-.sp
-\fI\%gearman_worker_context()\fP and \fI\%gearman_worker_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_worker_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_worker_timeout()\fP and \fI\%gearman_worker_set_timeout()\fP get and set the current timeout value, in milliseconds, for the worker.
-.sp
-\fI\%gearman_worker_function_exist()\fP is used to determine if a given worker has a specific function.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_worker_set_workload_malloc_fn()\fP and \fI\%gearman_worker_set_workload_free_fn()\fP can be used to replace these with custom functions.
-.sp
-If you need to remove a function from the server you can call either \fI\%gearman_worker_unregister_all()\fP to remove all functions that the worker has told the \fBgearmand\fP server about, or you can use \fI\%gearman_worker_unregister()\fP to remove just a single function.
-.SH RETURN
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_timeout.3'
--- docs/man/gearman_worker_timeout.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_timeout.3	1970-01-01 00:00:00 +0000
@@ -1,133 +0,0 @@
-.TH "GEARMAN_WORKER_TIMEOUT" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_timeout \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_worker_set_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_worker_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_worker_context(const \fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_context(\fI\%gearman_worker_st\fP\fI\ *worker\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_malloc_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_free_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_wait(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_register(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, uint32_t\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_job_st *gearman_worker_grab_job(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_job_st\fI\ *job\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_worker_function_exist(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, size_t\fI\ function_length\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_work(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_st\fP is used for worker communication with the server.
-.sp
-\fI\%gearman_worker_context()\fP and \fI\%gearman_worker_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_worker_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_worker_timeout()\fP and \fI\%gearman_worker_set_timeout()\fP get and set the current timeout value, in milliseconds, for the worker.
-.sp
-\fI\%gearman_worker_function_exist()\fP is used to determine if a given worker has a specific function.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_worker_set_workload_malloc_fn()\fP and \fI\%gearman_worker_set_workload_free_fn()\fP can be used to replace these with custom functions.
-.sp
-If you need to remove a function from the server you can call either \fI\%gearman_worker_unregister_all()\fP to remove all functions that the worker has told the \fBgearmand\fP server about, or you can use \fI\%gearman_worker_unregister()\fP to remove just a single function.
-.SH RETURN
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_unregister.3'
--- docs/man/gearman_worker_unregister.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_unregister.3	1970-01-01 00:00:00 +0000
@@ -1,133 +0,0 @@
-.TH "GEARMAN_WORKER_UNREGISTER" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_unregister \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_worker_set_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_worker_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_worker_context(const \fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_context(\fI\%gearman_worker_st\fP\fI\ *worker\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_malloc_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_free_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_wait(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_register(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, uint32_t\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_job_st *gearman_worker_grab_job(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_job_st\fI\ *job\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_worker_function_exist(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, size_t\fI\ function_length\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_work(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_st\fP is used for worker communication with the server.
-.sp
-\fI\%gearman_worker_context()\fP and \fI\%gearman_worker_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_worker_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_worker_timeout()\fP and \fI\%gearman_worker_set_timeout()\fP get and set the current timeout value, in milliseconds, for the worker.
-.sp
-\fI\%gearman_worker_function_exist()\fP is used to determine if a given worker has a specific function.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_worker_set_workload_malloc_fn()\fP and \fI\%gearman_worker_set_workload_free_fn()\fP can be used to replace these with custom functions.
-.sp
-If you need to remove a function from the server you can call either \fI\%gearman_worker_unregister_all()\fP to remove all functions that the worker has told the \fBgearmand\fP server about, or you can use \fI\%gearman_worker_unregister()\fP to remove just a single function.
-.SH RETURN
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_unregister_all.3'
--- docs/man/gearman_worker_unregister_all.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_unregister_all.3	1970-01-01 00:00:00 +0000
@@ -1,133 +0,0 @@
-.TH "GEARMAN_WORKER_UNREGISTER_ALL" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_unregister_all \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_worker_set_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_worker_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_worker_context(const \fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_context(\fI\%gearman_worker_st\fP\fI\ *worker\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_malloc_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_free_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_wait(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_register(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, uint32_t\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_job_st *gearman_worker_grab_job(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_job_st\fI\ *job\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_worker_function_exist(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, size_t\fI\ function_length\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_work(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_st\fP is used for worker communication with the server.
-.sp
-\fI\%gearman_worker_context()\fP and \fI\%gearman_worker_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_worker_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_worker_timeout()\fP and \fI\%gearman_worker_set_timeout()\fP get and set the current timeout value, in milliseconds, for the worker.
-.sp
-\fI\%gearman_worker_function_exist()\fP is used to determine if a given worker has a specific function.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_worker_set_workload_malloc_fn()\fP and \fI\%gearman_worker_set_workload_free_fn()\fP can be used to replace these with custom functions.
-.sp
-If you need to remove a function from the server you can call either \fI\%gearman_worker_unregister_all()\fP to remove all functions that the worker has told the \fBgearmand\fP server about, or you can use \fI\%gearman_worker_unregister()\fP to remove just a single function.
-.SH RETURN
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_wait.3'
--- docs/man/gearman_worker_wait.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_wait.3	1970-01-01 00:00:00 +0000
@@ -1,133 +0,0 @@
-.TH "GEARMAN_WORKER_WAIT" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_wait \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_worker_set_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_worker_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_worker_context(const \fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_context(\fI\%gearman_worker_st\fP\fI\ *worker\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_malloc_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_free_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_wait(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_register(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, uint32_t\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_job_st *gearman_worker_grab_job(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_job_st\fI\ *job\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_worker_function_exist(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, size_t\fI\ function_length\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_work(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_st\fP is used for worker communication with the server.
-.sp
-\fI\%gearman_worker_context()\fP and \fI\%gearman_worker_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_worker_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_worker_timeout()\fP and \fI\%gearman_worker_set_timeout()\fP get and set the current timeout value, in milliseconds, for the worker.
-.sp
-\fI\%gearman_worker_function_exist()\fP is used to determine if a given worker has a specific function.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_worker_set_workload_malloc_fn()\fP and \fI\%gearman_worker_set_workload_free_fn()\fP can be used to replace these with custom functions.
-.sp
-If you need to remove a function from the server you can call either \fI\%gearman_worker_unregister_all()\fP to remove all functions that the worker has told the \fBgearmand\fP server about, or you can use \fI\%gearman_worker_unregister()\fP to remove just a single function.
-.SH RETURN
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearman_worker_work.3'
--- docs/man/gearman_worker_work.3	2012-09-14 06:18:21 +0000
+++ docs/man/gearman_worker_work.3	1970-01-01 00:00:00 +0000
@@ -1,133 +0,0 @@
-.TH "GEARMAN_WORKER_WORK" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearman_worker_work \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.INDENT 0.0
-.TP
-.B gearman_worker_st
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_worker_set_task_context_free_fn
-.UNINDENT
-.INDENT 0.0
-.TP
-.B int gearman_worker_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_timeout(\fI\%gearman_worker_st\fP\fI\ *worker\fP, int\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void *gearman_worker_context(const \fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_context(\fI\%gearman_worker_st\fP\fI\ *worker\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_malloc_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_malloc_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_worker_set_workload_free_fn(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_free_fn\fI\ *function\fP, void\fI\ *context\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_wait(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_register(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, uint32_t\fI\ timeout\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_unregister_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_job_st *gearman_worker_grab_job(\fI\%gearman_worker_st\fP\fI\ *worker\fP, gearman_job_st\fI\ *job\fP, gearman_return_t\fI\ *ret_ptr\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B void gearman_job_free_all(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B bool gearman_worker_function_exist(\fI\%gearman_worker_st\fP\fI\ *worker\fP, const char\fI\ *function_name\fP, size_t\fI\ function_length\fP)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B gearman_return_t gearman_worker_work(\fI\%gearman_worker_st\fP\fI\ *worker\fP)
-.UNINDENT
-.sp
-Link with \-lgearman
-.SH DESCRIPTION
-.sp
-\fI\%gearman_worker_st\fP is used for worker communication with the server.
-.sp
-\fI\%gearman_worker_context()\fP and \fI\%gearman_worker_set_context()\fP can be used to store an arbitrary object for the user.
-.sp
-\fI\%gearman_worker_set_task_context_free_fn()\fP sets a trigger that will be called when a \fBgearman_task_st\fP is released.
-.sp
-\fI\%gearman_worker_timeout()\fP and \fI\%gearman_worker_set_timeout()\fP get and set the current timeout value, in milliseconds, for the worker.
-.sp
-\fI\%gearman_worker_function_exist()\fP is used to determine if a given worker has a specific function.
-.sp
-Normally \fImalloc(3)\fP and \fIfree(3)\fP are used for allocation and releasing workloads. \fI\%gearman_worker_set_workload_malloc_fn()\fP and \fI\%gearman_worker_set_workload_free_fn()\fP can be used to replace these with custom functions.
-.sp
-If you need to remove a function from the server you can call either \fI\%gearman_worker_unregister_all()\fP to remove all functions that the worker has told the \fBgearmand\fP server about, or you can use \fI\%gearman_worker_unregister()\fP to remove just a single function.
-.SH RETURN
-.sp
-Various
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/gearmand.8'
--- docs/man/gearmand.8	2012-09-14 06:18:21 +0000
+++ docs/man/gearmand.8	1970-01-01 00:00:00 +0000
@@ -1,340 +0,0 @@
-.TH "GEARMAND" "8" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-gearmand \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-\fBGeneral options\fP
-.INDENT 0.0
-.TP
-.B \-b [ \-\-backlog ] arg (=32)
-Number of backlog connections for listen.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-\-check\-args
-Check command line and configuration file argments and then exit.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-d [ \-\-daemon ]
-Daemon, detach and run in the background.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-f [ \-\-file\-descriptors ] arg
-Number of file descriptors to allow for the process (total connections will be slightly less). Default is max allowed for user.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-h [ \-\-help ]
-Print this help menu.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-j [ \-\-job\-retries ] arg (=0)
-Number of attempts to run the job before the job server removes it. This is helpful to ensure a bad job does not crash all available workers. Default is no limit.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-l [ \-\-log\-file ] arg
-Log file to write errors and information to.  Turning this option on also forces the first verbose level to be enabled.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-L [ \-\-listen ] arg
-Address the server should listen on. Default is INADDR_ANY.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-p [ \-\-port ] arg (=4730)
-Port the server should listen on.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-P [ \-\-pid\-file ] arg
-File to write process ID out to.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-r [ \-\-protocol ] arg
-Load protocol module.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-R [ \-\-round\-robin ]
-Assign work in round\-robin order per worker connection. The default is to assign work in the order of functions added by the worker.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-q [ \-\-queue\-type ] arg
-Persistent queue type to use.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-t [ \-\-threads ] arg (=4)
-Number of I/O threads to use. Default=4.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-u [ \-\-user ] arg
-Switch to given user after startup.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-v [ \-\-verbose ] arg (=v)
-Increase verbosity level by one.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-V [ \-\-version ]
-Display the version of gearmand and exit.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-w [ \-\-worker\-wakeup ] arg (=0)
-Number of workers to wakeup for each job received. The default is to wakeup all available workers.
-.UNINDENT
-.sp
-\fBHTTP:\fP
-.INDENT 0.0
-.TP
-.B \-\-http\-port arg (=8080)
-Port to listen on.
-.UNINDENT
-.sp
-\fBsqlite\fP
-.INDENT 0.0
-.TP
-.B \-\-libsqlite3\-db arg
-Database file to use.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-\-libsqlite3\-table arg (=gearman_queue)
-Table to use.
-.UNINDENT
-.sp
-\fBMemcached(libmemcached)\fP
-.INDENT 0.0
-.TP
-.B \-\-libmemcached\-servers arg
-List of Memcached servers to use.
-.UNINDENT
-.sp
-\fBDrizzle/MySQL(libdrizzle)\fP
-.INDENT 0.0
-.TP
-.B \-host arg
-Host of server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-port arg
-Port of server. (by default Drizzle)
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-uds arg
-Unix domain socket for server.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-user arg
-User name for authentication.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-password arg
-Password for authentication.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-db arg
-Schema/Database to use.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-table arg
-Table to use.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-mysql arg
-Use MySQL protocol.
-.UNINDENT
-.sp
-\fBPostgres\fP
-.INDENT 0.0
-.TP
-.B \-\-libpq\-conninfo arg
-PostgreSQL connection information string.
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-\-libpq\-table arg (=queue)
-Table to use.
-.UNINDENT
-.sp
-\fBtokyocabinet\fP
-.INDENT 0.0
-.TP
-.B \-\-libtokyocabinet\-file arg
-File name of the database. [see: man tcadb, tcadbopen() for name guidelines]
-.UNINDENT
-.INDENT 0.0
-.TP
-.B \-\-libtokyocabinet\-optimize
-Optimize database on open. [default=true]
-.UNINDENT
-.SH DESCRIPTION
-.sp
-Gearman provides a generic application framework to farm out work to other machines or processes that are better suited to do the work. It allows you to do work in parallel, to load balance processing, and to call functions between languages. It can be used in a variety of applications, from high\-availability web sites to the transport of database replication events. In other words, it is the nervous system for how distributed processing communicates. A few strong points about Gearman:
-.INDENT 0.0
-.IP \(bu 2
-Open Source \- It\(aqs free! (in both meanings of the word) Gearman has an active open source community that is easy to get involved with if you need help or want to contribute.
-.IP \(bu 2
-Multi\-language \- There are interfaces for a number of languages, and this list is growing. You also have the option to write heterogeneous applications with clients submitting work in one language and workers performing that work in another.
-.IP \(bu 2
-Flexible \- You are not tied to any specific design pattern. You can quickly put together distributed applications using any model you choose, one of those options being Map/Reduce.
-.IP \(bu 2
-Fast \- Gearman has a simple protocol and interface with a new optimized server in C to minimize your application overhead.
-.IP \(bu 2
-Embeddable \- Since Gearman is fast and lightweight, it is great for applications of all sizes. It is also easy to introduce into existing applications with minimal overhead.
-.IP \(bu 2
-No single point of failure \- Gearman can not only help scale systems, but can do it in a fault tolerant way.
-.UNINDENT
-.SS Thread Model
-.sp
-The \-t option to gearmand allows you to specify multiple I/O threads, this is enabled by default. There are currently three types of threads in the job server:
-.sp
-Listening and management thread \- only one
-I/O thread \- can have many
-Processing thread \- only one
-.sp
-When no \-t option is given or \-t 0 is given, all of three thread types happen within a single thread. When \-t 1 is given, there is a thread for listening/management and a thread for I/O and processing. When \-t 2 is given, there is a thread for each type of thread above. For all \-t option values above 2, more I/O threads are created.
-.sp
-The listening and management thread is mainly responsible for accepting new connections and assigning those connections to an I/O thread (if there are many). It also coordinates startup and shutdown within the server. This thread will have an instance of libevent for managing socket events and signals on an internal pipe. This pipe is used to wakeup the thread or to coordinate shutdown.
-.sp
-The I/O thread is responsible for doing the read and write system calls on the sockets and initial packet parsing. Once the packet has been parsed it it put into an asynchronous queue for the processing thread (each thread has it\(aqs own queue so there is very little contention). Each I/O thread has it\(aqs own instance of libevent for managing socket events and signals on an internal pipe like the listening thread.
-.sp
-The processing thread should have no system calls within it (except for the occasional brk() for more memory), and manages the various lists and hash tables used for tracking unique keys, job handles, functions, and job queues. All packets that need to be sent back to connections are put into an asynchronous queue for the I/O thread. The I/O thread will pick these up and send them back over the connected socket. All packets flow through the processing thread since it contains the information needed to process the packets. This is due to the complex nature of the various lists and hash tables. If multiple threads were modifying them the locking overhead would most likely cause worse performance than having it in a single thread (and would also complicate the code). In the future more work may be pushed to the I/O threads, and the processing thread can retain minimal functionality to manage those tables and lists. So far this has not been a significant bottleneck, a 16 core Intel machine is able to process upwards of 50k jobs per second.
-.sp
-For thread safety to work when UUID are generated, you must be running the uuidd daemon.
-.SS Persistent Queues
-.sp
-Inside the Gearman job server, all job queues are stored in memory. This means if a server restarts or crashes with pending jobs, they will be lost and are never run by a worker. Persistent queues were added to allow background jobs to be stored in an external durable queue so they may live between server restarts and crashes. The persistent queue is only enabled for background jobs because foreground jobs have an attached client. If a job server goes away, the client can detect this and restart the foreground job somewhere else (or report an error back to the original caller). Background jobs on the other hand have no attached client and are simply expected to be run when submitted.
-.sp
-The persistent queue works by calling a module callback function right before putting a new job in the internal queue for pending jobs to be run. This allows the module to store the job about to be run in some persistent way so that it can later be replayed during a restart. Once it is stored through the module, the job is put onto the active runnable queue, waking up available workers if needed. Once the job has been successfully completed by a worker, another module callback function is called to notify the module the job is done and can be removed. If a job server crashes or is restarted between these two calls for a job, the jobs are reloaded during the next job server start. When the job server starts up, it will call a replay callback function in the module to provide a list of all jobs that were not complete. This is used to populate the internal memory queue of jobs to be run. Once this replay is complete, the job server finishes its initialization and the jobs are now runnable once workers connect (the queue should be in the same state as when it crashed). These jobs are removed from the persistent queue when completed as normal. NOTE: Deleting jobs from the persistent queue storage will not remove them from the in\-memory queue while the server is running.
-.sp
-The queues are implemented using a modular interface so it is easy to add new data stores for the persistent queue.
-.sp
-A persistent queue module is enabled by passing the \-q or –queue\-type option to gearmand. Run gearmand –help to see which queue modules are supported on your system. If you are missing options for one you would like to use, you will need to install any dependencies and then recompile the gearmand package.
-.SS Extended Protocols
-.sp
-The protocol plugin interface allows you to take over the packet send and recieve functions, allowing you to pack the buffers as required by the protocol. The core read and write functions can (and should) be used by the protocol plugin.
-.SS HTTP
-.sp
-This protocol plugin allows you to map HTTP requests to Gearman jobs. It only provides client job submission currently, but it may be extended to support other request types in the future. The plugin can handle both GET and POST data, the latter being used to send a workload to the job server. The URL being requested is translated into the function being called.
-.sp
-For example, the request:
-.sp
-.nf
-.ft C
-POST /reverse HTTP/1.1
-Content\-Length: 12
-
-Hello world!
-.ft P
-.fi
-.sp
-Is translated into a job submission request for the function “reverse” and workload “Hello world!”. This will respond with:
-.sp
-.nf
-.ft C
-HTTP/1.0 200 OK
-X\-Gearman\-Job\-Handle: H:lap:4
-Content\-Length: 12
-Server: Gearman/0.8
-
-!dlrow olleH
-.ft P
-.fi
-.sp
-The following headers can be passed to change the behavior of the job:
-.sp
-.nf
-.ft C
-* X\-Gearman\-Unique: <unique key>
-* X\-Gearman\-Background: true
-* X\-Gearman\-Priority: <high|low>
-.ft P
-.fi
-.sp
-For example, to run a low priority background job, the following request can be sent:
-.sp
-.nf
-.ft C
-POST /reverse HTTP/1.1
-Content\-Length: 12
-X\-Gearman\-Background: true
-X\-Gearman\-Priority: low
-
-Hello world!
-.ft P
-.fi
-.sp
-The response for this request will not have any data associated with it since it was a background job:
-.sp
-.nf
-.ft C
-HTTP/1.0 200 OK
-X\-Gearman\-Job\-Handle: H:lap:6
-Content\-Length: 0
-Server: Gearman/0.8
-.ft P
-.fi
-.sp
-The HTTP protocol should be considered experimental.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%http://gearman.info/\fP
-.SH SEE ALSO
-.sp
-\fIgearman(1)\fP \fIgearadmin(1)\fP \fIlibgearmand(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== removed file 'docs/man/libgearman.3'
--- docs/man/libgearman.3	2012-09-14 06:18:21 +0000
+++ docs/man/libgearman.3	1970-01-01 00:00:00 +0000
@@ -1,131 +0,0 @@
-.TH "LIBGEARMAN" "3" "September 14, 2012" "0.38" "Gearmand"
-.SH NAME
-libgearman \- Gearmand Documentation, http://gearman.info/
-.
-.nr rst2man-indent-level 0
-.
-.de1 rstReportMargin
-\\$1 \\n[an-margin]
-level \\n[rst2man-indent-level]
-level margin: \\n[rst2man-indent\\n[rst2man-indent-level]]
--
-\\n[rst2man-indent0]
-\\n[rst2man-indent1]
-\\n[rst2man-indent2]
-..
-.de1 INDENT
-.\" .rstReportMargin pre:
-. RS \\$1
-. nr rst2man-indent\\n[rst2man-indent-level] \\n[an-margin]
-. nr rst2man-indent-level +1
-.\" .rstReportMargin post:
-..
-.de UNINDENT
-. RE
-.\" indent \\n[an-margin]
-.\" old: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.nr rst2man-indent-level -1
-.\" new: \\n[rst2man-indent\\n[rst2man-indent-level]]
-.in \\n[rst2man-indent\\n[rst2man-indent-level]]u
-..
-.\" Man page generated from reStructeredText.
-.
-.SH SYNOPSIS
-.sp
-#include <libgearman/gearman.h>
-.sp
-Link \-lgearman
-.SH DESCRIPTION
-.sp
-\fBlibgearman\fP is a small, thread\-safe client library for the
-gearman protocol. The code has all been written with an eye to allow
-for both web and embedded usage. It handles the work behind routing
-particular keys to specific servers that you specify (and values are
-matched based on server order as supplied by you). It implements both
-the \fIclient\fP and \fIworker\fP interfaces.
-.sp
-All operations are performed against either a client, ie \fBgearman_client_st\fP
-or worker, ie \fBgearman_worker_st\fP.
-.sp
-Client and Worker structures can either be dynamically allocated or statically
-allocated. They must then b initialized by \fBgearman_client_create()\fP or \fBgearman_worker_create()\fP.
-.sp
-Functions have been written in order to encapsulate all structures in the library. It is
-recommended that you do not operate directly against the structure.
-.sp
-Nearly all functions return a \fBgearman_return_t\fP value.
-This value can be translated to a printable string with \fBgearman_strerror()\fP.
-.sp
-\fBgearman_client_st\fP and \fBgearman_worker_st\fP structures are thread\-safe, but each thread must
-contain its own structure (that is, if you want to share these among
-threads you must provide your own locking). No global variables are
-used in this library.
-.sp
-If you are working with GNU autotools you will want to add the following to
-your configure.ac to properly include libgearman in your application.
-.sp
-PKG_CHECK_MODULES(DEPS, libgearman >= 0.8.0)
-AC_SUBST(DEPS_CFLAGS)
-AC_SUBST(DEPS_LIBS)
-.sp
-Hope you enjoy it!
-.SH CONSTANTS
-.sp
-A number of constants have been provided for in the library.
-.INDENT 0.0
-.TP
-.B GEARMAN_DEFAULT_TCP_PORT
-.UNINDENT
-.sp
-The default port used by gearmand(3).
-.INDENT 0.0
-.TP
-.B GEARMAN_DEFAULT_TCP_PORT
-.UNINDENT
-.sp
-The default service used by gearmand(3).
-.INDENT 0.0
-.TP
-.B LIBGEARMAN_VERSION_STRING
-.UNINDENT
-.sp
-String value of the libgearman version such as "0.20.4"
-.INDENT 0.0
-.TP
-.B LIBGEARMAN_VERSION_HEX
-.UNINDENT
-.sp
-Hex value of the version number. "0x00048000" This can be used for comparing versions based on number.
-.INDENT 0.0
-.TP
-.B GEARMAN_UNIQUE_SIZE
-.UNINDENT
-.sp
-Largest number of characters that can be used for a unique value.
-.INDENT 0.0
-.TP
-.B GEARMAN_JOB_HANDLE_SIZE
-.UNINDENT
-.sp
-Largest number of characters that can will be used for a job handle. Please
-see \fBgearman_job_handle_t\fP for additional information.
-.SH THREADS AND PROCESSES
-.sp
-When using threads or forked processes it is important to keep an instance
-of \fBgearman_client_st\fP or \fBgearman_worker_st\fP  per process
-or thread.  Without creating your own locking structures you can not share
-a single \fBgearman_client_st\fP or \fBgearman_worker_st\fP.
-.SH HOME
-.sp
-To find out more information please check:
-\fI\%https://launchpad.net/libgearman\fP
-.SH SEE ALSO
-.sp
-\fIgearmand(8)\fP \fIlibgearman_examples(3)\fP
-.SH AUTHOR
-Data Differential http://www.datadifferential.com/
-.SH COPYRIGHT
-2012, Data Differential, http://www.datadifferential.com/
-.\" Generated by docutils manpage writer.
-.\" 
-.

=== added directory 'man'
=== added file 'man/include.am'
--- man/include.am	1970-01-01 00:00:00 +0000
+++ man/include.am	2012-09-30 23:55:03 +0000
@@ -0,0 +1,160 @@
+# vim:ft=automake
+# included from Top Level Makefile.am
+# All paths should be given relative to the root
+
+man1_MANS+= man/gearadmin.1
+man1_MANS+= man/gearman.1
+
+man8_MANS+= man/gearmand.8
+
+man3_MANS+= man/gearman_allocator_t.3
+man3_MANS+= man/gearman_client_set_memory_allocators.3
+man3_MANS+= man/gearman_worker_set_memory_allocators.3
+man3_MANS+= man/gearman_actions_t.3
+man3_MANS+= man/gearman_argument_make.3
+man3_MANS+= man/gearman_argument_t.3
+man3_MANS+= man/gearman_bugreport.3
+man3_MANS+= man/gearman_client_add_options.3
+man3_MANS+= man/gearman_client_add_server.3
+man3_MANS+= man/gearman_client_add_servers.3
+man3_MANS+= man/gearman_client_add_task.3
+man3_MANS+= man/gearman_client_add_task_background.3
+man3_MANS+= man/gearman_client_add_task_high.3
+man3_MANS+= man/gearman_client_add_task_high_background.3
+man3_MANS+= man/gearman_client_add_task_low.3
+man3_MANS+= man/gearman_client_add_task_low_background.3
+man3_MANS+= man/gearman_client_add_task_status.3
+man3_MANS+= man/gearman_client_clear_fn.3
+man3_MANS+= man/gearman_client_clone.3
+man3_MANS+= man/gearman_client_context.3
+man3_MANS+= man/gearman_client_create.3
+man3_MANS+= man/gearman_client_do.3
+man3_MANS+= man/gearman_client_do_background.3
+man3_MANS+= man/gearman_client_do_high.3
+man3_MANS+= man/gearman_client_do_high_background.3
+man3_MANS+= man/gearman_client_do_job_handle.3
+man3_MANS+= man/gearman_client_do_low.3
+man3_MANS+= man/gearman_client_do_low_background.3
+man3_MANS+= man/gearman_client_do_status.3
+man3_MANS+= man/gearman_client_echo.3
+man3_MANS+= man/gearman_client_errno.3
+man3_MANS+= man/gearman_client_error.3
+man3_MANS+= man/gearman_client_free.3
+man3_MANS+= man/gearman_client_job_status.3
+man3_MANS+= man/gearman_client_options.3
+man3_MANS+= man/gearman_client_remove_options.3
+man3_MANS+= man/gearman_client_remove_servers.3
+man3_MANS+= man/gearman_client_run_tasks.3
+man3_MANS+= man/gearman_client_set_complete_fn.3
+man3_MANS+= man/gearman_client_set_context.3
+man3_MANS+= man/gearman_client_set_created_fn.3
+man3_MANS+= man/gearman_client_set_data_fn.3
+man3_MANS+= man/gearman_client_set_exception_fn.3
+man3_MANS+= man/gearman_client_set_fail_fn.3
+man3_MANS+= man/gearman_client_set_log_fn.3
+man3_MANS+= man/gearman_client_set_namespace.3
+man3_MANS+= man/gearman_client_set_options.3
+man3_MANS+= man/gearman_client_set_status_fn.3
+man3_MANS+= man/gearman_client_set_task_context_free_fn.3
+man3_MANS+= man/gearman_client_set_timeout.3
+man3_MANS+= man/gearman_client_set_warning_fn.3
+man3_MANS+= man/gearman_client_set_workload_fn.3
+man3_MANS+= man/gearman_client_set_workload_free_fn.3
+man3_MANS+= man/gearman_client_set_workload_malloc_fn.3
+man3_MANS+= man/gearman_client_st.3
+man3_MANS+= man/gearman_client_task_free_all.3
+man3_MANS+= man/gearman_client_timeout.3
+man3_MANS+= man/gearman_client_wait.3
+man3_MANS+= man/gearman_continue.3
+man3_MANS+= man/gearman_execute.3
+man3_MANS+= man/gearman_failed.3
+man3_MANS+= man/gearman_job_free.3
+man3_MANS+= man/gearman_job_free_all.3
+man3_MANS+= man/gearman_job_function_name.3
+man3_MANS+= man/gearman_job_handle.3
+man3_MANS+= man/gearman_job_handle_t.3
+man3_MANS+= man/gearman_job_send_complete.3
+man3_MANS+= man/gearman_job_send_data.3
+man3_MANS+= man/gearman_job_send_exception.3
+man3_MANS+= man/gearman_job_send_fail.3
+man3_MANS+= man/gearman_job_send_status.3
+man3_MANS+= man/gearman_job_send_warning.3
+man3_MANS+= man/gearman_job_st.3
+man3_MANS+= man/gearman_job_take_workload.3
+man3_MANS+= man/gearman_job_unique.3
+man3_MANS+= man/gearman_job_workload.3
+man3_MANS+= man/gearman_job_workload_size.3
+man3_MANS+= man/gearman_log_fn.3
+man3_MANS+= man/gearman_parse_servers.3
+man3_MANS+= man/gearman_result_boolean.3
+man3_MANS+= man/gearman_result_integer.3
+man3_MANS+= man/gearman_result_is_null.3
+man3_MANS+= man/gearman_result_size.3
+man3_MANS+= man/gearman_result_store_integer.3
+man3_MANS+= man/gearman_result_store_string.3
+man3_MANS+= man/gearman_result_store_value.3
+man3_MANS+= man/gearman_result_string.3
+man3_MANS+= man/gearman_return_t.3
+man3_MANS+= man/gearman_strerror.3
+man3_MANS+= man/gearman_string_t.3
+man3_MANS+= man/gearman_success.3
+man3_MANS+= man/gearman_task_context.3
+man3_MANS+= man/gearman_task_data.3
+man3_MANS+= man/gearman_task_data_size.3
+man3_MANS+= man/gearman_task_denominator.3
+man3_MANS+= man/gearman_task_error.3
+man3_MANS+= man/gearman_task_free.3
+man3_MANS+= man/gearman_task_function_name.3
+man3_MANS+= man/gearman_task_give_workload.3
+man3_MANS+= man/gearman_task_is_known.3
+man3_MANS+= man/gearman_task_is_running.3
+man3_MANS+= man/gearman_task_job_handle.3
+man3_MANS+= man/gearman_task_numerator.3
+man3_MANS+= man/gearman_task_recv_data.3
+man3_MANS+= man/gearman_task_return.3
+man3_MANS+= man/gearman_task_send_workload.3
+man3_MANS+= man/gearman_task_set_context.3
+man3_MANS+= man/gearman_task_st.3
+man3_MANS+= man/gearman_task_take_data.3
+man3_MANS+= man/gearman_task_unique.3
+man3_MANS+= man/gearman_verbose_name.3
+man3_MANS+= man/gearman_verbose_t.3
+man3_MANS+= man/gearman_version.3
+man3_MANS+= man/gearman_worker_add_function.3
+man3_MANS+= man/gearman_worker_add_options.3
+man3_MANS+= man/gearman_worker_add_server.3
+man3_MANS+= man/gearman_worker_add_servers.3
+man3_MANS+= man/gearman_worker_clone.3
+man3_MANS+= man/gearman_worker_context.3
+man3_MANS+= man/gearman_worker_create.3
+man3_MANS+= man/gearman_worker_define_function.3
+man3_MANS+= man/gearman_worker_echo.3
+man3_MANS+= man/gearman_worker_errno.3
+man3_MANS+= man/gearman_worker_error.3
+man3_MANS+= man/gearman_worker_free.3
+man3_MANS+= man/gearman_worker_function_exist.3
+man3_MANS+= man/gearman_worker_grab_job.3
+man3_MANS+= man/gearman_worker_options.3
+man3_MANS+= man/gearman_worker_register.3
+man3_MANS+= man/gearman_worker_remove_options.3
+man3_MANS+= man/gearman_worker_remove_servers.3
+man3_MANS+= man/gearman_worker_set_context.3
+man3_MANS+= man/gearman_worker_set_log_fn.3
+man3_MANS+= man/gearman_worker_set_namespace.3
+man3_MANS+= man/gearman_worker_set_options.3
+man3_MANS+= man/gearman_worker_set_timeout.3
+man3_MANS+= man/gearman_worker_set_workload_free_fn.3
+man3_MANS+= man/gearman_worker_set_workload_malloc_fn.3
+man3_MANS+= man/gearman_worker_st.3
+man3_MANS+= man/gearman_worker_timeout.3
+man3_MANS+= man/gearman_worker_unregister.3
+man3_MANS+= man/gearman_worker_unregister_all.3
+man3_MANS+= man/gearman_worker_wait.3
+man3_MANS+= man/gearman_worker_work.3
+man3_MANS+= man/gearman_task_attr_init.3
+man3_MANS+= man/gearman_task_attr_init_background.3
+man3_MANS+= man/gearman_task_attr_init_epoch.3
+man3_MANS+= man/gearman_task_attr_t.3
+man3_MANS+= man/gearman_client_options_t.3
+man3_MANS+= man/gearman_client_has_option.3
+man3_MANS+= man/libgearman.3

=== modified file 'rpm.am'
--- rpm.am	2012-08-13 03:41:25 +0000
+++ rpm.am	2012-09-30 23:55:03 +0000
@@ -1,6 +1,6 @@
 # vim:ft=automake
 
-rpm-build: support/$(PACKAGE).spec
+rpm-build: support/$(PACKAGE).spec dist
 	@rm -f *.rpm
 	@rm -f ~/rpmbuild/RPMS/x86_64/$(PACKAGE)-$(VERSION)*.rpm
 	@rm -f ~/rpmbuild/SRPMS/$(PACKAGE)-$(VERSION)*.rpm
@@ -30,7 +30,7 @@
 	@rm -f *.src.rpm
 	@rm -f *.rpm
 
-rpm: clean-rpm support/$(PACKAGE).spec man dist rpm-build
+rpm: clean-rpm support/$(PACKAGE).spec rpm-build
 
 release: rpm rpm-sign
 

